/*
    SPDX-FileCopyrightText: 2026 Igor Mironchik <igor.mironchik@gmail.com>
    SPDX-License-Identifier: MIT
*/

// This file is autogenerated.

#include "entities_map.h"

namespace MD
{

const QHash<QString, QString> s_entityMap = {
    {QStringLiteral("&AElig"), QString::fromUtf16(u"\x00C6")},
    {QStringLiteral("&AElig;"), QString::fromUtf16(u"\x00C6")},
    {QStringLiteral("&AMP"), QString::fromUtf16(u"\x0026")},
    {QStringLiteral("&AMP;"), QString::fromUtf16(u"\x0026")},
    {QStringLiteral("&Aacute"), QString::fromUtf16(u"\x00C1")},
    {QStringLiteral("&Aacute;"), QString::fromUtf16(u"\x00C1")},
    {QStringLiteral("&Abreve;"), QString::fromUtf16(u"\x0102")},
    {QStringLiteral("&Acirc"), QString::fromUtf16(u"\x00C2")},
    {QStringLiteral("&Acirc;"), QString::fromUtf16(u"\x00C2")},
    {QStringLiteral("&Acy;"), QString::fromUtf16(u"\x0410")},
    {QStringLiteral("&Afr;"), QString::fromUtf16(u"\xD835\xDD04")},
    {QStringLiteral("&Agrave"), QString::fromUtf16(u"\x00C0")},
    {QStringLiteral("&Agrave;"), QString::fromUtf16(u"\x00C0")},
    {QStringLiteral("&Alpha;"), QString::fromUtf16(u"\x0391")},
    {QStringLiteral("&Amacr;"), QString::fromUtf16(u"\x0100")},
    {QStringLiteral("&And;"), QString::fromUtf16(u"\x2A53")},
    {QStringLiteral("&Aogon;"), QString::fromUtf16(u"\x0104")},
    {QStringLiteral("&Aopf;"), QString::fromUtf16(u"\xD835\xDD38")},
    {QStringLiteral("&ApplyFunction;"), QString::fromUtf16(u"\x2061")},
    {QStringLiteral("&Aring"), QString::fromUtf16(u"\x00C5")},
    {QStringLiteral("&Aring;"), QString::fromUtf16(u"\x00C5")},
    {QStringLiteral("&Ascr;"), QString::fromUtf16(u"\xD835\xDC9C")},
    {QStringLiteral("&Assign;"), QString::fromUtf16(u"\x2254")},
    {QStringLiteral("&Atilde"), QString::fromUtf16(u"\x00C3")},
    {QStringLiteral("&Atilde;"), QString::fromUtf16(u"\x00C3")},
    {QStringLiteral("&Auml"), QString::fromUtf16(u"\x00C4")},
    {QStringLiteral("&Auml;"), QString::fromUtf16(u"\x00C4")},
    {QStringLiteral("&Backslash;"), QString::fromUtf16(u"\x2216")},
    {QStringLiteral("&Barv;"), QString::fromUtf16(u"\x2AE7")},
    {QStringLiteral("&Barwed;"), QString::fromUtf16(u"\x2306")},
    {QStringLiteral("&Bcy;"), QString::fromUtf16(u"\x0411")},
    {QStringLiteral("&Because;"), QString::fromUtf16(u"\x2235")},
    {QStringLiteral("&Bernoullis;"), QString::fromUtf16(u"\x212C")},
    {QStringLiteral("&Beta;"), QString::fromUtf16(u"\x0392")},
    {QStringLiteral("&Bfr;"), QString::fromUtf16(u"\xD835\xDD05")},
    {QStringLiteral("&Bopf;"), QString::fromUtf16(u"\xD835\xDD39")},
    {QStringLiteral("&Breve;"), QString::fromUtf16(u"\x02D8")},
    {QStringLiteral("&Bscr;"), QString::fromUtf16(u"\x212C")},
    {QStringLiteral("&Bumpeq;"), QString::fromUtf16(u"\x224E")},
    {QStringLiteral("&CHcy;"), QString::fromUtf16(u"\x0427")},
    {QStringLiteral("&COPY"), QString::fromUtf16(u"\x00A9")},
    {QStringLiteral("&COPY;"), QString::fromUtf16(u"\x00A9")},
    {QStringLiteral("&Cacute;"), QString::fromUtf16(u"\x0106")},
    {QStringLiteral("&Cap;"), QString::fromUtf16(u"\x22D2")},
    {QStringLiteral("&CapitalDifferentialD;"), QString::fromUtf16(u"\x2145")},
    {QStringLiteral("&Cayleys;"), QString::fromUtf16(u"\x212D")},
    {QStringLiteral("&Ccaron;"), QString::fromUtf16(u"\x010C")},
    {QStringLiteral("&Ccedil"), QString::fromUtf16(u"\x00C7")},
    {QStringLiteral("&Ccedil;"), QString::fromUtf16(u"\x00C7")},
    {QStringLiteral("&Ccirc;"), QString::fromUtf16(u"\x0108")},
    {QStringLiteral("&Cconint;"), QString::fromUtf16(u"\x2230")},
    {QStringLiteral("&Cdot;"), QString::fromUtf16(u"\x010A")},
    {QStringLiteral("&Cedilla;"), QString::fromUtf16(u"\x00B8")},
    {QStringLiteral("&CenterDot;"), QString::fromUtf16(u"\x00B7")},
    {QStringLiteral("&Cfr;"), QString::fromUtf16(u"\x212D")},
    {QStringLiteral("&Chi;"), QString::fromUtf16(u"\x03A7")},
    {QStringLiteral("&CircleDot;"), QString::fromUtf16(u"\x2299")},
    {QStringLiteral("&CircleMinus;"), QString::fromUtf16(u"\x2296")},
    {QStringLiteral("&CirclePlus;"), QString::fromUtf16(u"\x2295")},
    {QStringLiteral("&CircleTimes;"), QString::fromUtf16(u"\x2297")},
    {QStringLiteral("&ClockwiseContourIntegral;"), QString::fromUtf16(u"\x2232")},
    {QStringLiteral("&CloseCurlyDoubleQuote;"), QString::fromUtf16(u"\x201D")},
    {QStringLiteral("&CloseCurlyQuote;"), QString::fromUtf16(u"\x2019")},
    {QStringLiteral("&Colon;"), QString::fromUtf16(u"\x2237")},
    {QStringLiteral("&Colone;"), QString::fromUtf16(u"\x2A74")},
    {QStringLiteral("&Congruent;"), QString::fromUtf16(u"\x2261")},
    {QStringLiteral("&Conint;"), QString::fromUtf16(u"\x222F")},
    {QStringLiteral("&ContourIntegral;"), QString::fromUtf16(u"\x222E")},
    {QStringLiteral("&Copf;"), QString::fromUtf16(u"\x2102")},
    {QStringLiteral("&Coproduct;"), QString::fromUtf16(u"\x2210")},
    {QStringLiteral("&CounterClockwiseContourIntegral;"), QString::fromUtf16(u"\x2233")},
    {QStringLiteral("&Cross;"), QString::fromUtf16(u"\x2A2F")},
    {QStringLiteral("&Cscr;"), QString::fromUtf16(u"\xD835\xDC9E")},
    {QStringLiteral("&Cup;"), QString::fromUtf16(u"\x22D3")},
    {QStringLiteral("&CupCap;"), QString::fromUtf16(u"\x224D")},
    {QStringLiteral("&DD;"), QString::fromUtf16(u"\x2145")},
    {QStringLiteral("&DDotrahd;"), QString::fromUtf16(u"\x2911")},
    {QStringLiteral("&DJcy;"), QString::fromUtf16(u"\x0402")},
    {QStringLiteral("&DScy;"), QString::fromUtf16(u"\x0405")},
    {QStringLiteral("&DZcy;"), QString::fromUtf16(u"\x040F")},
    {QStringLiteral("&Dagger;"), QString::fromUtf16(u"\x2021")},
    {QStringLiteral("&Darr;"), QString::fromUtf16(u"\x21A1")},
    {QStringLiteral("&Dashv;"), QString::fromUtf16(u"\x2AE4")},
    {QStringLiteral("&Dcaron;"), QString::fromUtf16(u"\x010E")},
    {QStringLiteral("&Dcy;"), QString::fromUtf16(u"\x0414")},
    {QStringLiteral("&Del;"), QString::fromUtf16(u"\x2207")},
    {QStringLiteral("&Delta;"), QString::fromUtf16(u"\x0394")},
    {QStringLiteral("&Dfr;"), QString::fromUtf16(u"\xD835\xDD07")},
    {QStringLiteral("&DiacriticalAcute;"), QString::fromUtf16(u"\x00B4")},
    {QStringLiteral("&DiacriticalDot;"), QString::fromUtf16(u"\x02D9")},
    {QStringLiteral("&DiacriticalDoubleAcute;"), QString::fromUtf16(u"\x02DD")},
    {QStringLiteral("&DiacriticalGrave;"), QString::fromUtf16(u"\x0060")},
    {QStringLiteral("&DiacriticalTilde;"), QString::fromUtf16(u"\x02DC")},
    {QStringLiteral("&Diamond;"), QString::fromUtf16(u"\x22C4")},
    {QStringLiteral("&DifferentialD;"), QString::fromUtf16(u"\x2146")},
    {QStringLiteral("&Dopf;"), QString::fromUtf16(u"\xD835\xDD3B")},
    {QStringLiteral("&Dot;"), QString::fromUtf16(u"\x00A8")},
    {QStringLiteral("&DotDot;"), QString::fromUtf16(u"\x20DC")},
    {QStringLiteral("&DotEqual;"), QString::fromUtf16(u"\x2250")},
    {QStringLiteral("&DoubleContourIntegral;"), QString::fromUtf16(u"\x222F")},
    {QStringLiteral("&DoubleDot;"), QString::fromUtf16(u"\x00A8")},
    {QStringLiteral("&DoubleDownArrow;"), QString::fromUtf16(u"\x21D3")},
    {QStringLiteral("&DoubleLeftArrow;"), QString::fromUtf16(u"\x21D0")},
    {QStringLiteral("&DoubleLeftRightArrow;"), QString::fromUtf16(u"\x21D4")},
    {QStringLiteral("&DoubleLeftTee;"), QString::fromUtf16(u"\x2AE4")},
    {QStringLiteral("&DoubleLongLeftArrow;"), QString::fromUtf16(u"\x27F8")},
    {QStringLiteral("&DoubleLongLeftRightArrow;"), QString::fromUtf16(u"\x27FA")},
    {QStringLiteral("&DoubleLongRightArrow;"), QString::fromUtf16(u"\x27F9")},
    {QStringLiteral("&DoubleRightArrow;"), QString::fromUtf16(u"\x21D2")},
    {QStringLiteral("&DoubleRightTee;"), QString::fromUtf16(u"\x22A8")},
    {QStringLiteral("&DoubleUpArrow;"), QString::fromUtf16(u"\x21D1")},
    {QStringLiteral("&DoubleUpDownArrow;"), QString::fromUtf16(u"\x21D5")},
    {QStringLiteral("&DoubleVerticalBar;"), QString::fromUtf16(u"\x2225")},
    {QStringLiteral("&DownArrow;"), QString::fromUtf16(u"\x2193")},
    {QStringLiteral("&DownArrowBar;"), QString::fromUtf16(u"\x2913")},
    {QStringLiteral("&DownArrowUpArrow;"), QString::fromUtf16(u"\x21F5")},
    {QStringLiteral("&DownBreve;"), QString::fromUtf16(u"\x0311")},
    {QStringLiteral("&DownLeftRightVector;"), QString::fromUtf16(u"\x2950")},
    {QStringLiteral("&DownLeftTeeVector;"), QString::fromUtf16(u"\x295E")},
    {QStringLiteral("&DownLeftVector;"), QString::fromUtf16(u"\x21BD")},
    {QStringLiteral("&DownLeftVectorBar;"), QString::fromUtf16(u"\x2956")},
    {QStringLiteral("&DownRightTeeVector;"), QString::fromUtf16(u"\x295F")},
    {QStringLiteral("&DownRightVector;"), QString::fromUtf16(u"\x21C1")},
    {QStringLiteral("&DownRightVectorBar;"), QString::fromUtf16(u"\x2957")},
    {QStringLiteral("&DownTee;"), QString::fromUtf16(u"\x22A4")},
    {QStringLiteral("&DownTeeArrow;"), QString::fromUtf16(u"\x21A7")},
    {QStringLiteral("&Downarrow;"), QString::fromUtf16(u"\x21D3")},
    {QStringLiteral("&Dscr;"), QString::fromUtf16(u"\xD835\xDC9F")},
    {QStringLiteral("&Dstrok;"), QString::fromUtf16(u"\x0110")},
    {QStringLiteral("&ENG;"), QString::fromUtf16(u"\x014A")},
    {QStringLiteral("&ETH"), QString::fromUtf16(u"\x00D0")},
    {QStringLiteral("&ETH;"), QString::fromUtf16(u"\x00D0")},
    {QStringLiteral("&Eacute"), QString::fromUtf16(u"\x00C9")},
    {QStringLiteral("&Eacute;"), QString::fromUtf16(u"\x00C9")},
    {QStringLiteral("&Ecaron;"), QString::fromUtf16(u"\x011A")},
    {QStringLiteral("&Ecirc"), QString::fromUtf16(u"\x00CA")},
    {QStringLiteral("&Ecirc;"), QString::fromUtf16(u"\x00CA")},
    {QStringLiteral("&Ecy;"), QString::fromUtf16(u"\x042D")},
    {QStringLiteral("&Edot;"), QString::fromUtf16(u"\x0116")},
    {QStringLiteral("&Efr;"), QString::fromUtf16(u"\xD835\xDD08")},
    {QStringLiteral("&Egrave"), QString::fromUtf16(u"\x00C8")},
    {QStringLiteral("&Egrave;"), QString::fromUtf16(u"\x00C8")},
    {QStringLiteral("&Element;"), QString::fromUtf16(u"\x2208")},
    {QStringLiteral("&Emacr;"), QString::fromUtf16(u"\x0112")},
    {QStringLiteral("&EmptySmallSquare;"), QString::fromUtf16(u"\x25FB")},
    {QStringLiteral("&EmptyVerySmallSquare;"), QString::fromUtf16(u"\x25AB")},
    {QStringLiteral("&Eogon;"), QString::fromUtf16(u"\x0118")},
    {QStringLiteral("&Eopf;"), QString::fromUtf16(u"\xD835\xDD3C")},
    {QStringLiteral("&Epsilon;"), QString::fromUtf16(u"\x0395")},
    {QStringLiteral("&Equal;"), QString::fromUtf16(u"\x2A75")},
    {QStringLiteral("&EqualTilde;"), QString::fromUtf16(u"\x2242")},
    {QStringLiteral("&Equilibrium;"), QString::fromUtf16(u"\x21CC")},
    {QStringLiteral("&Escr;"), QString::fromUtf16(u"\x2130")},
    {QStringLiteral("&Esim;"), QString::fromUtf16(u"\x2A73")},
    {QStringLiteral("&Eta;"), QString::fromUtf16(u"\x0397")},
    {QStringLiteral("&Euml"), QString::fromUtf16(u"\x00CB")},
    {QStringLiteral("&Euml;"), QString::fromUtf16(u"\x00CB")},
    {QStringLiteral("&Exists;"), QString::fromUtf16(u"\x2203")},
    {QStringLiteral("&ExponentialE;"), QString::fromUtf16(u"\x2147")},
    {QStringLiteral("&Fcy;"), QString::fromUtf16(u"\x0424")},
    {QStringLiteral("&Ffr;"), QString::fromUtf16(u"\xD835\xDD09")},
    {QStringLiteral("&FilledSmallSquare;"), QString::fromUtf16(u"\x25FC")},
    {QStringLiteral("&FilledVerySmallSquare;"), QString::fromUtf16(u"\x25AA")},
    {QStringLiteral("&Fopf;"), QString::fromUtf16(u"\xD835\xDD3D")},
    {QStringLiteral("&ForAll;"), QString::fromUtf16(u"\x2200")},
    {QStringLiteral("&Fouriertrf;"), QString::fromUtf16(u"\x2131")},
    {QStringLiteral("&Fscr;"), QString::fromUtf16(u"\x2131")},
    {QStringLiteral("&GJcy;"), QString::fromUtf16(u"\x0403")},
    {QStringLiteral("&GT"), QString::fromUtf16(u"\x003E")},
    {QStringLiteral("&GT;"), QString::fromUtf16(u"\x003E")},
    {QStringLiteral("&Gamma;"), QString::fromUtf16(u"\x0393")},
    {QStringLiteral("&Gammad;"), QString::fromUtf16(u"\x03DC")},
    {QStringLiteral("&Gbreve;"), QString::fromUtf16(u"\x011E")},
    {QStringLiteral("&Gcedil;"), QString::fromUtf16(u"\x0122")},
    {QStringLiteral("&Gcirc;"), QString::fromUtf16(u"\x011C")},
    {QStringLiteral("&Gcy;"), QString::fromUtf16(u"\x0413")},
    {QStringLiteral("&Gdot;"), QString::fromUtf16(u"\x0120")},
    {QStringLiteral("&Gfr;"), QString::fromUtf16(u"\xD835\xDD0A")},
    {QStringLiteral("&Gg;"), QString::fromUtf16(u"\x22D9")},
    {QStringLiteral("&Gopf;"), QString::fromUtf16(u"\xD835\xDD3E")},
    {QStringLiteral("&GreaterEqual;"), QString::fromUtf16(u"\x2265")},
    {QStringLiteral("&GreaterEqualLess;"), QString::fromUtf16(u"\x22DB")},
    {QStringLiteral("&GreaterFullEqual;"), QString::fromUtf16(u"\x2267")},
    {QStringLiteral("&GreaterGreater;"), QString::fromUtf16(u"\x2AA2")},
    {QStringLiteral("&GreaterLess;"), QString::fromUtf16(u"\x2277")},
    {QStringLiteral("&GreaterSlantEqual;"), QString::fromUtf16(u"\x2A7E")},
    {QStringLiteral("&GreaterTilde;"), QString::fromUtf16(u"\x2273")},
    {QStringLiteral("&Gscr;"), QString::fromUtf16(u"\xD835\xDCA2")},
    {QStringLiteral("&Gt;"), QString::fromUtf16(u"\x226B")},
    {QStringLiteral("&HARDcy;"), QString::fromUtf16(u"\x042A")},
    {QStringLiteral("&Hacek;"), QString::fromUtf16(u"\x02C7")},
    {QStringLiteral("&Hat;"), QString::fromUtf16(u"\x005E")},
    {QStringLiteral("&Hcirc;"), QString::fromUtf16(u"\x0124")},
    {QStringLiteral("&Hfr;"), QString::fromUtf16(u"\x210C")},
    {QStringLiteral("&HilbertSpace;"), QString::fromUtf16(u"\x210B")},
    {QStringLiteral("&Hopf;"), QString::fromUtf16(u"\x210D")},
    {QStringLiteral("&HorizontalLine;"), QString::fromUtf16(u"\x2500")},
    {QStringLiteral("&Hscr;"), QString::fromUtf16(u"\x210B")},
    {QStringLiteral("&Hstrok;"), QString::fromUtf16(u"\x0126")},
    {QStringLiteral("&HumpDownHump;"), QString::fromUtf16(u"\x224E")},
    {QStringLiteral("&HumpEqual;"), QString::fromUtf16(u"\x224F")},
    {QStringLiteral("&IEcy;"), QString::fromUtf16(u"\x0415")},
    {QStringLiteral("&IJlig;"), QString::fromUtf16(u"\x0132")},
    {QStringLiteral("&IOcy;"), QString::fromUtf16(u"\x0401")},
    {QStringLiteral("&Iacute"), QString::fromUtf16(u"\x00CD")},
    {QStringLiteral("&Iacute;"), QString::fromUtf16(u"\x00CD")},
    {QStringLiteral("&Icirc"), QString::fromUtf16(u"\x00CE")},
    {QStringLiteral("&Icirc;"), QString::fromUtf16(u"\x00CE")},
    {QStringLiteral("&Icy;"), QString::fromUtf16(u"\x0418")},
    {QStringLiteral("&Idot;"), QString::fromUtf16(u"\x0130")},
    {QStringLiteral("&Ifr;"), QString::fromUtf16(u"\x2111")},
    {QStringLiteral("&Igrave"), QString::fromUtf16(u"\x00CC")},
    {QStringLiteral("&Igrave;"), QString::fromUtf16(u"\x00CC")},
    {QStringLiteral("&Im;"), QString::fromUtf16(u"\x2111")},
    {QStringLiteral("&Imacr;"), QString::fromUtf16(u"\x012A")},
    {QStringLiteral("&ImaginaryI;"), QString::fromUtf16(u"\x2148")},
    {QStringLiteral("&Implies;"), QString::fromUtf16(u"\x21D2")},
    {QStringLiteral("&Int;"), QString::fromUtf16(u"\x222C")},
    {QStringLiteral("&Integral;"), QString::fromUtf16(u"\x222B")},
    {QStringLiteral("&Intersection;"), QString::fromUtf16(u"\x22C2")},
    {QStringLiteral("&InvisibleComma;"), QString::fromUtf16(u"\x2063")},
    {QStringLiteral("&InvisibleTimes;"), QString::fromUtf16(u"\x2062")},
    {QStringLiteral("&Iogon;"), QString::fromUtf16(u"\x012E")},
    {QStringLiteral("&Iopf;"), QString::fromUtf16(u"\xD835\xDD40")},
    {QStringLiteral("&Iota;"), QString::fromUtf16(u"\x0399")},
    {QStringLiteral("&Iscr;"), QString::fromUtf16(u"\x2110")},
    {QStringLiteral("&Itilde;"), QString::fromUtf16(u"\x0128")},
    {QStringLiteral("&Iukcy;"), QString::fromUtf16(u"\x0406")},
    {QStringLiteral("&Iuml"), QString::fromUtf16(u"\x00CF")},
    {QStringLiteral("&Iuml;"), QString::fromUtf16(u"\x00CF")},
    {QStringLiteral("&Jcirc;"), QString::fromUtf16(u"\x0134")},
    {QStringLiteral("&Jcy;"), QString::fromUtf16(u"\x0419")},
    {QStringLiteral("&Jfr;"), QString::fromUtf16(u"\xD835\xDD0D")},
    {QStringLiteral("&Jopf;"), QString::fromUtf16(u"\xD835\xDD41")},
    {QStringLiteral("&Jscr;"), QString::fromUtf16(u"\xD835\xDCA5")},
    {QStringLiteral("&Jsercy;"), QString::fromUtf16(u"\x0408")},
    {QStringLiteral("&Jukcy;"), QString::fromUtf16(u"\x0404")},
    {QStringLiteral("&KHcy;"), QString::fromUtf16(u"\x0425")},
    {QStringLiteral("&KJcy;"), QString::fromUtf16(u"\x040C")},
    {QStringLiteral("&Kappa;"), QString::fromUtf16(u"\x039A")},
    {QStringLiteral("&Kcedil;"), QString::fromUtf16(u"\x0136")},
    {QStringLiteral("&Kcy;"), QString::fromUtf16(u"\x041A")},
    {QStringLiteral("&Kfr;"), QString::fromUtf16(u"\xD835\xDD0E")},
    {QStringLiteral("&Kopf;"), QString::fromUtf16(u"\xD835\xDD42")},
    {QStringLiteral("&Kscr;"), QString::fromUtf16(u"\xD835\xDCA6")},
    {QStringLiteral("&LJcy;"), QString::fromUtf16(u"\x0409")},
    {QStringLiteral("&LT"), QString::fromUtf16(u"\x003C")},
    {QStringLiteral("&LT;"), QString::fromUtf16(u"\x003C")},
    {QStringLiteral("&Lacute;"), QString::fromUtf16(u"\x0139")},
    {QStringLiteral("&Lambda;"), QString::fromUtf16(u"\x039B")},
    {QStringLiteral("&Lang;"), QString::fromUtf16(u"\x27EA")},
    {QStringLiteral("&Laplacetrf;"), QString::fromUtf16(u"\x2112")},
    {QStringLiteral("&Larr;"), QString::fromUtf16(u"\x219E")},
    {QStringLiteral("&Lcaron;"), QString::fromUtf16(u"\x013D")},
    {QStringLiteral("&Lcedil;"), QString::fromUtf16(u"\x013B")},
    {QStringLiteral("&Lcy;"), QString::fromUtf16(u"\x041B")},
    {QStringLiteral("&LeftAngleBracket;"), QString::fromUtf16(u"\x27E8")},
    {QStringLiteral("&LeftArrow;"), QString::fromUtf16(u"\x2190")},
    {QStringLiteral("&LeftArrowBar;"), QString::fromUtf16(u"\x21E4")},
    {QStringLiteral("&LeftArrowRightArrow;"), QString::fromUtf16(u"\x21C6")},
    {QStringLiteral("&LeftCeiling;"), QString::fromUtf16(u"\x2308")},
    {QStringLiteral("&LeftDoubleBracket;"), QString::fromUtf16(u"\x27E6")},
    {QStringLiteral("&LeftDownTeeVector;"), QString::fromUtf16(u"\x2961")},
    {QStringLiteral("&LeftDownVector;"), QString::fromUtf16(u"\x21C3")},
    {QStringLiteral("&LeftDownVectorBar;"), QString::fromUtf16(u"\x2959")},
    {QStringLiteral("&LeftFloor;"), QString::fromUtf16(u"\x230A")},
    {QStringLiteral("&LeftRightArrow;"), QString::fromUtf16(u"\x2194")},
    {QStringLiteral("&LeftRightVector;"), QString::fromUtf16(u"\x294E")},
    {QStringLiteral("&LeftTee;"), QString::fromUtf16(u"\x22A3")},
    {QStringLiteral("&LeftTeeArrow;"), QString::fromUtf16(u"\x21A4")},
    {QStringLiteral("&LeftTeeVector;"), QString::fromUtf16(u"\x295A")},
    {QStringLiteral("&LeftTriangle;"), QString::fromUtf16(u"\x22B2")},
    {QStringLiteral("&LeftTriangleBar;"), QString::fromUtf16(u"\x29CF")},
    {QStringLiteral("&LeftTriangleEqual;"), QString::fromUtf16(u"\x22B4")},
    {QStringLiteral("&LeftUpDownVector;"), QString::fromUtf16(u"\x2951")},
    {QStringLiteral("&LeftUpTeeVector;"), QString::fromUtf16(u"\x2960")},
    {QStringLiteral("&LeftUpVector;"), QString::fromUtf16(u"\x21BF")},
    {QStringLiteral("&LeftUpVectorBar;"), QString::fromUtf16(u"\x2958")},
    {QStringLiteral("&LeftVector;"), QString::fromUtf16(u"\x21BC")},
    {QStringLiteral("&LeftVectorBar;"), QString::fromUtf16(u"\x2952")},
    {QStringLiteral("&Leftarrow;"), QString::fromUtf16(u"\x21D0")},
    {QStringLiteral("&Leftrightarrow;"), QString::fromUtf16(u"\x21D4")},
    {QStringLiteral("&LessEqualGreater;"), QString::fromUtf16(u"\x22DA")},
    {QStringLiteral("&LessFullEqual;"), QString::fromUtf16(u"\x2266")},
    {QStringLiteral("&LessGreater;"), QString::fromUtf16(u"\x2276")},
    {QStringLiteral("&LessLess;"), QString::fromUtf16(u"\x2AA1")},
    {QStringLiteral("&LessSlantEqual;"), QString::fromUtf16(u"\x2A7D")},
    {QStringLiteral("&LessTilde;"), QString::fromUtf16(u"\x2272")},
    {QStringLiteral("&Lfr;"), QString::fromUtf16(u"\xD835\xDD0F")},
    {QStringLiteral("&Ll;"), QString::fromUtf16(u"\x22D8")},
    {QStringLiteral("&Lleftarrow;"), QString::fromUtf16(u"\x21DA")},
    {QStringLiteral("&Lmidot;"), QString::fromUtf16(u"\x013F")},
    {QStringLiteral("&LongLeftArrow;"), QString::fromUtf16(u"\x27F5")},
    {QStringLiteral("&LongLeftRightArrow;"), QString::fromUtf16(u"\x27F7")},
    {QStringLiteral("&LongRightArrow;"), QString::fromUtf16(u"\x27F6")},
    {QStringLiteral("&Longleftarrow;"), QString::fromUtf16(u"\x27F8")},
    {QStringLiteral("&Longleftrightarrow;"), QString::fromUtf16(u"\x27FA")},
    {QStringLiteral("&Longrightarrow;"), QString::fromUtf16(u"\x27F9")},
    {QStringLiteral("&Lopf;"), QString::fromUtf16(u"\xD835\xDD43")},
    {QStringLiteral("&LowerLeftArrow;"), QString::fromUtf16(u"\x2199")},
    {QStringLiteral("&LowerRightArrow;"), QString::fromUtf16(u"\x2198")},
    {QStringLiteral("&Lscr;"), QString::fromUtf16(u"\x2112")},
    {QStringLiteral("&Lsh;"), QString::fromUtf16(u"\x21B0")},
    {QStringLiteral("&Lstrok;"), QString::fromUtf16(u"\x0141")},
    {QStringLiteral("&Lt;"), QString::fromUtf16(u"\x226A")},
    {QStringLiteral("&Map;"), QString::fromUtf16(u"\x2905")},
    {QStringLiteral("&Mcy;"), QString::fromUtf16(u"\x041C")},
    {QStringLiteral("&MediumSpace;"), QString::fromUtf16(u"\x205F")},
    {QStringLiteral("&Mellintrf;"), QString::fromUtf16(u"\x2133")},
    {QStringLiteral("&Mfr;"), QString::fromUtf16(u"\xD835\xDD10")},
    {QStringLiteral("&MinusPlus;"), QString::fromUtf16(u"\x2213")},
    {QStringLiteral("&Mopf;"), QString::fromUtf16(u"\xD835\xDD44")},
    {QStringLiteral("&Mscr;"), QString::fromUtf16(u"\x2133")},
    {QStringLiteral("&Mu;"), QString::fromUtf16(u"\x039C")},
    {QStringLiteral("&NJcy;"), QString::fromUtf16(u"\x040A")},
    {QStringLiteral("&Nacute;"), QString::fromUtf16(u"\x0143")},
    {QStringLiteral("&Ncaron;"), QString::fromUtf16(u"\x0147")},
    {QStringLiteral("&Ncedil;"), QString::fromUtf16(u"\x0145")},
    {QStringLiteral("&Ncy;"), QString::fromUtf16(u"\x041D")},
    {QStringLiteral("&NegativeMediumSpace;"), QString::fromUtf16(u"\x200B")},
    {QStringLiteral("&NegativeThickSpace;"), QString::fromUtf16(u"\x200B")},
    {QStringLiteral("&NegativeThinSpace;"), QString::fromUtf16(u"\x200B")},
    {QStringLiteral("&NegativeVeryThinSpace;"), QString::fromUtf16(u"\x200B")},
    {QStringLiteral("&NestedGreaterGreater;"), QString::fromUtf16(u"\x226B")},
    {QStringLiteral("&NestedLessLess;"), QString::fromUtf16(u"\x226A")},
    {QStringLiteral("&NewLine;"), QString::fromUtf16(u"\x000A")},
    {QStringLiteral("&Nfr;"), QString::fromUtf16(u"\xD835\xDD11")},
    {QStringLiteral("&NoBreak;"), QString::fromUtf16(u"\x2060")},
    {QStringLiteral("&NonBreakingSpace;"), QString::fromUtf16(u"\x00A0")},
    {QStringLiteral("&Nopf;"), QString::fromUtf16(u"\x2115")},
    {QStringLiteral("&Not;"), QString::fromUtf16(u"\x2AEC")},
    {QStringLiteral("&NotCongruent;"), QString::fromUtf16(u"\x2262")},
    {QStringLiteral("&NotCupCap;"), QString::fromUtf16(u"\x226D")},
    {QStringLiteral("&NotDoubleVerticalBar;"), QString::fromUtf16(u"\x2226")},
    {QStringLiteral("&NotElement;"), QString::fromUtf16(u"\x2209")},
    {QStringLiteral("&NotEqual;"), QString::fromUtf16(u"\x2260")},
    {QStringLiteral("&NotEqualTilde;"), QString::fromUtf16(u"\x2242\x0338")},
    {QStringLiteral("&NotExists;"), QString::fromUtf16(u"\x2204")},
    {QStringLiteral("&NotGreater;"), QString::fromUtf16(u"\x226F")},
    {QStringLiteral("&NotGreaterEqual;"), QString::fromUtf16(u"\x2271")},
    {QStringLiteral("&NotGreaterFullEqual;"), QString::fromUtf16(u"\x2267\x0338")},
    {QStringLiteral("&NotGreaterGreater;"), QString::fromUtf16(u"\x226B\x0338")},
    {QStringLiteral("&NotGreaterLess;"), QString::fromUtf16(u"\x2279")},
    {QStringLiteral("&NotGreaterSlantEqual;"), QString::fromUtf16(u"\x2A7E\x0338")},
    {QStringLiteral("&NotGreaterTilde;"), QString::fromUtf16(u"\x2275")},
    {QStringLiteral("&NotHumpDownHump;"), QString::fromUtf16(u"\x224E\x0338")},
    {QStringLiteral("&NotHumpEqual;"), QString::fromUtf16(u"\x224F\x0338")},
    {QStringLiteral("&NotLeftTriangle;"), QString::fromUtf16(u"\x22EA")},
    {QStringLiteral("&NotLeftTriangleBar;"), QString::fromUtf16(u"\x29CF\x0338")},
    {QStringLiteral("&NotLeftTriangleEqual;"), QString::fromUtf16(u"\x22EC")},
    {QStringLiteral("&NotLess;"), QString::fromUtf16(u"\x226E")},
    {QStringLiteral("&NotLessEqual;"), QString::fromUtf16(u"\x2270")},
    {QStringLiteral("&NotLessGreater;"), QString::fromUtf16(u"\x2278")},
    {QStringLiteral("&NotLessLess;"), QString::fromUtf16(u"\x226A\x0338")},
    {QStringLiteral("&NotLessSlantEqual;"), QString::fromUtf16(u"\x2A7D\x0338")},
    {QStringLiteral("&NotLessTilde;"), QString::fromUtf16(u"\x2274")},
    {QStringLiteral("&NotNestedGreaterGreater;"), QString::fromUtf16(u"\x2AA2\x0338")},
    {QStringLiteral("&NotNestedLessLess;"), QString::fromUtf16(u"\x2AA1\x0338")},
    {QStringLiteral("&NotPrecedes;"), QString::fromUtf16(u"\x2280")},
    {QStringLiteral("&NotPrecedesEqual;"), QString::fromUtf16(u"\x2AAF\x0338")},
    {QStringLiteral("&NotPrecedesSlantEqual;"), QString::fromUtf16(u"\x22E0")},
    {QStringLiteral("&NotReverseElement;"), QString::fromUtf16(u"\x220C")},
    {QStringLiteral("&NotRightTriangle;"), QString::fromUtf16(u"\x22EB")},
    {QStringLiteral("&NotRightTriangleBar;"), QString::fromUtf16(u"\x29D0\x0338")},
    {QStringLiteral("&NotRightTriangleEqual;"), QString::fromUtf16(u"\x22ED")},
    {QStringLiteral("&NotSquareSubset;"), QString::fromUtf16(u"\x228F\x0338")},
    {QStringLiteral("&NotSquareSubsetEqual;"), QString::fromUtf16(u"\x22E2")},
    {QStringLiteral("&NotSquareSuperset;"), QString::fromUtf16(u"\x2290\x0338")},
    {QStringLiteral("&NotSquareSupersetEqual;"), QString::fromUtf16(u"\x22E3")},
    {QStringLiteral("&NotSubset;"), QString::fromUtf16(u"\x2282\x20D2")},
    {QStringLiteral("&NotSubsetEqual;"), QString::fromUtf16(u"\x2288")},
    {QStringLiteral("&NotSucceeds;"), QString::fromUtf16(u"\x2281")},
    {QStringLiteral("&NotSucceedsEqual;"), QString::fromUtf16(u"\x2AB0\x0338")},
    {QStringLiteral("&NotSucceedsSlantEqual;"), QString::fromUtf16(u"\x22E1")},
    {QStringLiteral("&NotSucceedsTilde;"), QString::fromUtf16(u"\x227F\x0338")},
    {QStringLiteral("&NotSuperset;"), QString::fromUtf16(u"\x2283\x20D2")},
    {QStringLiteral("&NotSupersetEqual;"), QString::fromUtf16(u"\x2289")},
    {QStringLiteral("&NotTilde;"), QString::fromUtf16(u"\x2241")},
    {QStringLiteral("&NotTildeEqual;"), QString::fromUtf16(u"\x2244")},
    {QStringLiteral("&NotTildeFullEqual;"), QString::fromUtf16(u"\x2247")},
    {QStringLiteral("&NotTildeTilde;"), QString::fromUtf16(u"\x2249")},
    {QStringLiteral("&NotVerticalBar;"), QString::fromUtf16(u"\x2224")},
    {QStringLiteral("&Nscr;"), QString::fromUtf16(u"\xD835\xDCA9")},
    {QStringLiteral("&Ntilde"), QString::fromUtf16(u"\x00D1")},
    {QStringLiteral("&Ntilde;"), QString::fromUtf16(u"\x00D1")},
    {QStringLiteral("&Nu;"), QString::fromUtf16(u"\x039D")},
    {QStringLiteral("&OElig;"), QString::fromUtf16(u"\x0152")},
    {QStringLiteral("&Oacute"), QString::fromUtf16(u"\x00D3")},
    {QStringLiteral("&Oacute;"), QString::fromUtf16(u"\x00D3")},
    {QStringLiteral("&Ocirc"), QString::fromUtf16(u"\x00D4")},
    {QStringLiteral("&Ocirc;"), QString::fromUtf16(u"\x00D4")},
    {QStringLiteral("&Ocy;"), QString::fromUtf16(u"\x041E")},
    {QStringLiteral("&Odblac;"), QString::fromUtf16(u"\x0150")},
    {QStringLiteral("&Ofr;"), QString::fromUtf16(u"\xD835\xDD12")},
    {QStringLiteral("&Ograve"), QString::fromUtf16(u"\x00D2")},
    {QStringLiteral("&Ograve;"), QString::fromUtf16(u"\x00D2")},
    {QStringLiteral("&Omacr;"), QString::fromUtf16(u"\x014C")},
    {QStringLiteral("&Omega;"), QString::fromUtf16(u"\x03A9")},
    {QStringLiteral("&Omicron;"), QString::fromUtf16(u"\x039F")},
    {QStringLiteral("&Oopf;"), QString::fromUtf16(u"\xD835\xDD46")},
    {QStringLiteral("&OpenCurlyDoubleQuote;"), QString::fromUtf16(u"\x201C")},
    {QStringLiteral("&OpenCurlyQuote;"), QString::fromUtf16(u"\x2018")},
    {QStringLiteral("&Or;"), QString::fromUtf16(u"\x2A54")},
    {QStringLiteral("&Oscr;"), QString::fromUtf16(u"\xD835\xDCAA")},
    {QStringLiteral("&Oslash"), QString::fromUtf16(u"\x00D8")},
    {QStringLiteral("&Oslash;"), QString::fromUtf16(u"\x00D8")},
    {QStringLiteral("&Otilde"), QString::fromUtf16(u"\x00D5")},
    {QStringLiteral("&Otilde;"), QString::fromUtf16(u"\x00D5")},
    {QStringLiteral("&Otimes;"), QString::fromUtf16(u"\x2A37")},
    {QStringLiteral("&Ouml"), QString::fromUtf16(u"\x00D6")},
    {QStringLiteral("&Ouml;"), QString::fromUtf16(u"\x00D6")},
    {QStringLiteral("&OverBar;"), QString::fromUtf16(u"\x203E")},
    {QStringLiteral("&OverBrace;"), QString::fromUtf16(u"\x23DE")},
    {QStringLiteral("&OverBracket;"), QString::fromUtf16(u"\x23B4")},
    {QStringLiteral("&OverParenthesis;"), QString::fromUtf16(u"\x23DC")},
    {QStringLiteral("&PartialD;"), QString::fromUtf16(u"\x2202")},
    {QStringLiteral("&Pcy;"), QString::fromUtf16(u"\x041F")},
    {QStringLiteral("&Pfr;"), QString::fromUtf16(u"\xD835\xDD13")},
    {QStringLiteral("&Phi;"), QString::fromUtf16(u"\x03A6")},
    {QStringLiteral("&Pi;"), QString::fromUtf16(u"\x03A0")},
    {QStringLiteral("&PlusMinus;"), QString::fromUtf16(u"\x00B1")},
    {QStringLiteral("&Poincareplane;"), QString::fromUtf16(u"\x210C")},
    {QStringLiteral("&Popf;"), QString::fromUtf16(u"\x2119")},
    {QStringLiteral("&Pr;"), QString::fromUtf16(u"\x2ABB")},
    {QStringLiteral("&Precedes;"), QString::fromUtf16(u"\x227A")},
    {QStringLiteral("&PrecedesEqual;"), QString::fromUtf16(u"\x2AAF")},
    {QStringLiteral("&PrecedesSlantEqual;"), QString::fromUtf16(u"\x227C")},
    {QStringLiteral("&PrecedesTilde;"), QString::fromUtf16(u"\x227E")},
    {QStringLiteral("&Prime;"), QString::fromUtf16(u"\x2033")},
    {QStringLiteral("&Product;"), QString::fromUtf16(u"\x220F")},
    {QStringLiteral("&Proportion;"), QString::fromUtf16(u"\x2237")},
    {QStringLiteral("&Proportional;"), QString::fromUtf16(u"\x221D")},
    {QStringLiteral("&Pscr;"), QString::fromUtf16(u"\xD835\xDCAB")},
    {QStringLiteral("&Psi;"), QString::fromUtf16(u"\x03A8")},
    {QStringLiteral("&QUOT"), QString::fromUtf16(u"\x0022")},
    {QStringLiteral("&QUOT;"), QString::fromUtf16(u"\x0022")},
    {QStringLiteral("&Qfr;"), QString::fromUtf16(u"\xD835\xDD14")},
    {QStringLiteral("&Qopf;"), QString::fromUtf16(u"\x211A")},
    {QStringLiteral("&Qscr;"), QString::fromUtf16(u"\xD835\xDCAC")},
    {QStringLiteral("&RBarr;"), QString::fromUtf16(u"\x2910")},
    {QStringLiteral("&REG"), QString::fromUtf16(u"\x00AE")},
    {QStringLiteral("&REG;"), QString::fromUtf16(u"\x00AE")},
    {QStringLiteral("&Racute;"), QString::fromUtf16(u"\x0154")},
    {QStringLiteral("&Rang;"), QString::fromUtf16(u"\x27EB")},
    {QStringLiteral("&Rarr;"), QString::fromUtf16(u"\x21A0")},
    {QStringLiteral("&Rarrtl;"), QString::fromUtf16(u"\x2916")},
    {QStringLiteral("&Rcaron;"), QString::fromUtf16(u"\x0158")},
    {QStringLiteral("&Rcedil;"), QString::fromUtf16(u"\x0156")},
    {QStringLiteral("&Rcy;"), QString::fromUtf16(u"\x0420")},
    {QStringLiteral("&Re;"), QString::fromUtf16(u"\x211C")},
    {QStringLiteral("&ReverseElement;"), QString::fromUtf16(u"\x220B")},
    {QStringLiteral("&ReverseEquilibrium;"), QString::fromUtf16(u"\x21CB")},
    {QStringLiteral("&ReverseUpEquilibrium;"), QString::fromUtf16(u"\x296F")},
    {QStringLiteral("&Rfr;"), QString::fromUtf16(u"\x211C")},
    {QStringLiteral("&Rho;"), QString::fromUtf16(u"\x03A1")},
    {QStringLiteral("&RightAngleBracket;"), QString::fromUtf16(u"\x27E9")},
    {QStringLiteral("&RightArrow;"), QString::fromUtf16(u"\x2192")},
    {QStringLiteral("&RightArrowBar;"), QString::fromUtf16(u"\x21E5")},
    {QStringLiteral("&RightArrowLeftArrow;"), QString::fromUtf16(u"\x21C4")},
    {QStringLiteral("&RightCeiling;"), QString::fromUtf16(u"\x2309")},
    {QStringLiteral("&RightDoubleBracket;"), QString::fromUtf16(u"\x27E7")},
    {QStringLiteral("&RightDownTeeVector;"), QString::fromUtf16(u"\x295D")},
    {QStringLiteral("&RightDownVector;"), QString::fromUtf16(u"\x21C2")},
    {QStringLiteral("&RightDownVectorBar;"), QString::fromUtf16(u"\x2955")},
    {QStringLiteral("&RightFloor;"), QString::fromUtf16(u"\x230B")},
    {QStringLiteral("&RightTee;"), QString::fromUtf16(u"\x22A2")},
    {QStringLiteral("&RightTeeArrow;"), QString::fromUtf16(u"\x21A6")},
    {QStringLiteral("&RightTeeVector;"), QString::fromUtf16(u"\x295B")},
    {QStringLiteral("&RightTriangle;"), QString::fromUtf16(u"\x22B3")},
    {QStringLiteral("&RightTriangleBar;"), QString::fromUtf16(u"\x29D0")},
    {QStringLiteral("&RightTriangleEqual;"), QString::fromUtf16(u"\x22B5")},
    {QStringLiteral("&RightUpDownVector;"), QString::fromUtf16(u"\x294F")},
    {QStringLiteral("&RightUpTeeVector;"), QString::fromUtf16(u"\x295C")},
    {QStringLiteral("&RightUpVector;"), QString::fromUtf16(u"\x21BE")},
    {QStringLiteral("&RightUpVectorBar;"), QString::fromUtf16(u"\x2954")},
    {QStringLiteral("&RightVector;"), QString::fromUtf16(u"\x21C0")},
    {QStringLiteral("&RightVectorBar;"), QString::fromUtf16(u"\x2953")},
    {QStringLiteral("&Rightarrow;"), QString::fromUtf16(u"\x21D2")},
    {QStringLiteral("&Ropf;"), QString::fromUtf16(u"\x211D")},
    {QStringLiteral("&RoundImplies;"), QString::fromUtf16(u"\x2970")},
    {QStringLiteral("&Rrightarrow;"), QString::fromUtf16(u"\x21DB")},
    {QStringLiteral("&Rscr;"), QString::fromUtf16(u"\x211B")},
    {QStringLiteral("&Rsh;"), QString::fromUtf16(u"\x21B1")},
    {QStringLiteral("&RuleDelayed;"), QString::fromUtf16(u"\x29F4")},
    {QStringLiteral("&SHCHcy;"), QString::fromUtf16(u"\x0429")},
    {QStringLiteral("&SHcy;"), QString::fromUtf16(u"\x0428")},
    {QStringLiteral("&SOFTcy;"), QString::fromUtf16(u"\x042C")},
    {QStringLiteral("&Sacute;"), QString::fromUtf16(u"\x015A")},
    {QStringLiteral("&Sc;"), QString::fromUtf16(u"\x2ABC")},
    {QStringLiteral("&Scaron;"), QString::fromUtf16(u"\x0160")},
    {QStringLiteral("&Scedil;"), QString::fromUtf16(u"\x015E")},
    {QStringLiteral("&Scirc;"), QString::fromUtf16(u"\x015C")},
    {QStringLiteral("&Scy;"), QString::fromUtf16(u"\x0421")},
    {QStringLiteral("&Sfr;"), QString::fromUtf16(u"\xD835\xDD16")},
    {QStringLiteral("&ShortDownArrow;"), QString::fromUtf16(u"\x2193")},
    {QStringLiteral("&ShortLeftArrow;"), QString::fromUtf16(u"\x2190")},
    {QStringLiteral("&ShortRightArrow;"), QString::fromUtf16(u"\x2192")},
    {QStringLiteral("&ShortUpArrow;"), QString::fromUtf16(u"\x2191")},
    {QStringLiteral("&Sigma;"), QString::fromUtf16(u"\x03A3")},
    {QStringLiteral("&SmallCircle;"), QString::fromUtf16(u"\x2218")},
    {QStringLiteral("&Sopf;"), QString::fromUtf16(u"\xD835\xDD4A")},
    {QStringLiteral("&Sqrt;"), QString::fromUtf16(u"\x221A")},
    {QStringLiteral("&Square;"), QString::fromUtf16(u"\x25A1")},
    {QStringLiteral("&SquareIntersection;"), QString::fromUtf16(u"\x2293")},
    {QStringLiteral("&SquareSubset;"), QString::fromUtf16(u"\x228F")},
    {QStringLiteral("&SquareSubsetEqual;"), QString::fromUtf16(u"\x2291")},
    {QStringLiteral("&SquareSuperset;"), QString::fromUtf16(u"\x2290")},
    {QStringLiteral("&SquareSupersetEqual;"), QString::fromUtf16(u"\x2292")},
    {QStringLiteral("&SquareUnion;"), QString::fromUtf16(u"\x2294")},
    {QStringLiteral("&Sscr;"), QString::fromUtf16(u"\xD835\xDCAE")},
    {QStringLiteral("&Star;"), QString::fromUtf16(u"\x22C6")},
    {QStringLiteral("&Sub;"), QString::fromUtf16(u"\x22D0")},
    {QStringLiteral("&Subset;"), QString::fromUtf16(u"\x22D0")},
    {QStringLiteral("&SubsetEqual;"), QString::fromUtf16(u"\x2286")},
    {QStringLiteral("&Succeeds;"), QString::fromUtf16(u"\x227B")},
    {QStringLiteral("&SucceedsEqual;"), QString::fromUtf16(u"\x2AB0")},
    {QStringLiteral("&SucceedsSlantEqual;"), QString::fromUtf16(u"\x227D")},
    {QStringLiteral("&SucceedsTilde;"), QString::fromUtf16(u"\x227F")},
    {QStringLiteral("&SuchThat;"), QString::fromUtf16(u"\x220B")},
    {QStringLiteral("&Sum;"), QString::fromUtf16(u"\x2211")},
    {QStringLiteral("&Sup;"), QString::fromUtf16(u"\x22D1")},
    {QStringLiteral("&Superset;"), QString::fromUtf16(u"\x2283")},
    {QStringLiteral("&SupersetEqual;"), QString::fromUtf16(u"\x2287")},
    {QStringLiteral("&Supset;"), QString::fromUtf16(u"\x22D1")},
    {QStringLiteral("&THORN"), QString::fromUtf16(u"\x00DE")},
    {QStringLiteral("&THORN;"), QString::fromUtf16(u"\x00DE")},
    {QStringLiteral("&TRADE;"), QString::fromUtf16(u"\x2122")},
    {QStringLiteral("&TSHcy;"), QString::fromUtf16(u"\x040B")},
    {QStringLiteral("&TScy;"), QString::fromUtf16(u"\x0426")},
    {QStringLiteral("&Tab;"), QString::fromUtf16(u"\x0009")},
    {QStringLiteral("&Tau;"), QString::fromUtf16(u"\x03A4")},
    {QStringLiteral("&Tcaron;"), QString::fromUtf16(u"\x0164")},
    {QStringLiteral("&Tcedil;"), QString::fromUtf16(u"\x0162")},
    {QStringLiteral("&Tcy;"), QString::fromUtf16(u"\x0422")},
    {QStringLiteral("&Tfr;"), QString::fromUtf16(u"\xD835\xDD17")},
    {QStringLiteral("&Therefore;"), QString::fromUtf16(u"\x2234")},
    {QStringLiteral("&Theta;"), QString::fromUtf16(u"\x0398")},
    {QStringLiteral("&ThickSpace;"), QString::fromUtf16(u"\x205F\x200A")},
    {QStringLiteral("&ThinSpace;"), QString::fromUtf16(u"\x2009")},
    {QStringLiteral("&Tilde;"), QString::fromUtf16(u"\x223C")},
    {QStringLiteral("&TildeEqual;"), QString::fromUtf16(u"\x2243")},
    {QStringLiteral("&TildeFullEqual;"), QString::fromUtf16(u"\x2245")},
    {QStringLiteral("&TildeTilde;"), QString::fromUtf16(u"\x2248")},
    {QStringLiteral("&Topf;"), QString::fromUtf16(u"\xD835\xDD4B")},
    {QStringLiteral("&TripleDot;"), QString::fromUtf16(u"\x20DB")},
    {QStringLiteral("&Tscr;"), QString::fromUtf16(u"\xD835\xDCAF")},
    {QStringLiteral("&Tstrok;"), QString::fromUtf16(u"\x0166")},
    {QStringLiteral("&Uacute"), QString::fromUtf16(u"\x00DA")},
    {QStringLiteral("&Uacute;"), QString::fromUtf16(u"\x00DA")},
    {QStringLiteral("&Uarr;"), QString::fromUtf16(u"\x219F")},
    {QStringLiteral("&Uarrocir;"), QString::fromUtf16(u"\x2949")},
    {QStringLiteral("&Ubrcy;"), QString::fromUtf16(u"\x040E")},
    {QStringLiteral("&Ubreve;"), QString::fromUtf16(u"\x016C")},
    {QStringLiteral("&Ucirc"), QString::fromUtf16(u"\x00DB")},
    {QStringLiteral("&Ucirc;"), QString::fromUtf16(u"\x00DB")},
    {QStringLiteral("&Ucy;"), QString::fromUtf16(u"\x0423")},
    {QStringLiteral("&Udblac;"), QString::fromUtf16(u"\x0170")},
    {QStringLiteral("&Ufr;"), QString::fromUtf16(u"\xD835\xDD18")},
    {QStringLiteral("&Ugrave"), QString::fromUtf16(u"\x00D9")},
    {QStringLiteral("&Ugrave;"), QString::fromUtf16(u"\x00D9")},
    {QStringLiteral("&Umacr;"), QString::fromUtf16(u"\x016A")},
    {QStringLiteral("&UnderBar;"), QString::fromUtf16(u"\x005F")},
    {QStringLiteral("&UnderBrace;"), QString::fromUtf16(u"\x23DF")},
    {QStringLiteral("&UnderBracket;"), QString::fromUtf16(u"\x23B5")},
    {QStringLiteral("&UnderParenthesis;"), QString::fromUtf16(u"\x23DD")},
    {QStringLiteral("&Union;"), QString::fromUtf16(u"\x22C3")},
    {QStringLiteral("&UnionPlus;"), QString::fromUtf16(u"\x228E")},
    {QStringLiteral("&Uogon;"), QString::fromUtf16(u"\x0172")},
    {QStringLiteral("&Uopf;"), QString::fromUtf16(u"\xD835\xDD4C")},
    {QStringLiteral("&UpArrow;"), QString::fromUtf16(u"\x2191")},
    {QStringLiteral("&UpArrowBar;"), QString::fromUtf16(u"\x2912")},
    {QStringLiteral("&UpArrowDownArrow;"), QString::fromUtf16(u"\x21C5")},
    {QStringLiteral("&UpDownArrow;"), QString::fromUtf16(u"\x2195")},
    {QStringLiteral("&UpEquilibrium;"), QString::fromUtf16(u"\x296E")},
    {QStringLiteral("&UpTee;"), QString::fromUtf16(u"\x22A5")},
    {QStringLiteral("&UpTeeArrow;"), QString::fromUtf16(u"\x21A5")},
    {QStringLiteral("&Uparrow;"), QString::fromUtf16(u"\x21D1")},
    {QStringLiteral("&Updownarrow;"), QString::fromUtf16(u"\x21D5")},
    {QStringLiteral("&UpperLeftArrow;"), QString::fromUtf16(u"\x2196")},
    {QStringLiteral("&UpperRightArrow;"), QString::fromUtf16(u"\x2197")},
    {QStringLiteral("&Upsi;"), QString::fromUtf16(u"\x03D2")},
    {QStringLiteral("&Upsilon;"), QString::fromUtf16(u"\x03A5")},
    {QStringLiteral("&Uring;"), QString::fromUtf16(u"\x016E")},
    {QStringLiteral("&Uscr;"), QString::fromUtf16(u"\xD835\xDCB0")},
    {QStringLiteral("&Utilde;"), QString::fromUtf16(u"\x0168")},
    {QStringLiteral("&Uuml"), QString::fromUtf16(u"\x00DC")},
    {QStringLiteral("&Uuml;"), QString::fromUtf16(u"\x00DC")},
    {QStringLiteral("&VDash;"), QString::fromUtf16(u"\x22AB")},
    {QStringLiteral("&Vbar;"), QString::fromUtf16(u"\x2AEB")},
    {QStringLiteral("&Vcy;"), QString::fromUtf16(u"\x0412")},
    {QStringLiteral("&Vdash;"), QString::fromUtf16(u"\x22A9")},
    {QStringLiteral("&Vdashl;"), QString::fromUtf16(u"\x2AE6")},
    {QStringLiteral("&Vee;"), QString::fromUtf16(u"\x22C1")},
    {QStringLiteral("&Verbar;"), QString::fromUtf16(u"\x2016")},
    {QStringLiteral("&Vert;"), QString::fromUtf16(u"\x2016")},
    {QStringLiteral("&VerticalBar;"), QString::fromUtf16(u"\x2223")},
    {QStringLiteral("&VerticalLine;"), QString::fromUtf16(u"\x007C")},
    {QStringLiteral("&VerticalSeparator;"), QString::fromUtf16(u"\x2758")},
    {QStringLiteral("&VerticalTilde;"), QString::fromUtf16(u"\x2240")},
    {QStringLiteral("&VeryThinSpace;"), QString::fromUtf16(u"\x200A")},
    {QStringLiteral("&Vfr;"), QString::fromUtf16(u"\xD835\xDD19")},
    {QStringLiteral("&Vopf;"), QString::fromUtf16(u"\xD835\xDD4D")},
    {QStringLiteral("&Vscr;"), QString::fromUtf16(u"\xD835\xDCB1")},
    {QStringLiteral("&Vvdash;"), QString::fromUtf16(u"\x22AA")},
    {QStringLiteral("&Wcirc;"), QString::fromUtf16(u"\x0174")},
    {QStringLiteral("&Wedge;"), QString::fromUtf16(u"\x22C0")},
    {QStringLiteral("&Wfr;"), QString::fromUtf16(u"\xD835\xDD1A")},
    {QStringLiteral("&Wopf;"), QString::fromUtf16(u"\xD835\xDD4E")},
    {QStringLiteral("&Wscr;"), QString::fromUtf16(u"\xD835\xDCB2")},
    {QStringLiteral("&Xfr;"), QString::fromUtf16(u"\xD835\xDD1B")},
    {QStringLiteral("&Xi;"), QString::fromUtf16(u"\x039E")},
    {QStringLiteral("&Xopf;"), QString::fromUtf16(u"\xD835\xDD4F")},
    {QStringLiteral("&Xscr;"), QString::fromUtf16(u"\xD835\xDCB3")},
    {QStringLiteral("&YAcy;"), QString::fromUtf16(u"\x042F")},
    {QStringLiteral("&YIcy;"), QString::fromUtf16(u"\x0407")},
    {QStringLiteral("&YUcy;"), QString::fromUtf16(u"\x042E")},
    {QStringLiteral("&Yacute"), QString::fromUtf16(u"\x00DD")},
    {QStringLiteral("&Yacute;"), QString::fromUtf16(u"\x00DD")},
    {QStringLiteral("&Ycirc;"), QString::fromUtf16(u"\x0176")},
    {QStringLiteral("&Ycy;"), QString::fromUtf16(u"\x042B")},
    {QStringLiteral("&Yfr;"), QString::fromUtf16(u"\xD835\xDD1C")},
    {QStringLiteral("&Yopf;"), QString::fromUtf16(u"\xD835\xDD50")},
    {QStringLiteral("&Yscr;"), QString::fromUtf16(u"\xD835\xDCB4")},
    {QStringLiteral("&Yuml;"), QString::fromUtf16(u"\x0178")},
    {QStringLiteral("&ZHcy;"), QString::fromUtf16(u"\x0416")},
    {QStringLiteral("&Zacute;"), QString::fromUtf16(u"\x0179")},
    {QStringLiteral("&Zcaron;"), QString::fromUtf16(u"\x017D")},
    {QStringLiteral("&Zcy;"), QString::fromUtf16(u"\x0417")},
    {QStringLiteral("&Zdot;"), QString::fromUtf16(u"\x017B")},
    {QStringLiteral("&ZeroWidthSpace;"), QString::fromUtf16(u"\x200B")},
    {QStringLiteral("&Zeta;"), QString::fromUtf16(u"\x0396")},
    {QStringLiteral("&Zfr;"), QString::fromUtf16(u"\x2128")},
    {QStringLiteral("&Zopf;"), QString::fromUtf16(u"\x2124")},
    {QStringLiteral("&Zscr;"), QString::fromUtf16(u"\xD835\xDCB5")},
    {QStringLiteral("&aacute"), QString::fromUtf16(u"\x00E1")},
    {QStringLiteral("&aacute;"), QString::fromUtf16(u"\x00E1")},
    {QStringLiteral("&abreve;"), QString::fromUtf16(u"\x0103")},
    {QStringLiteral("&ac;"), QString::fromUtf16(u"\x223E")},
    {QStringLiteral("&acE;"), QString::fromUtf16(u"\x223E\x0333")},
    {QStringLiteral("&acd;"), QString::fromUtf16(u"\x223F")},
    {QStringLiteral("&acirc"), QString::fromUtf16(u"\x00E2")},
    {QStringLiteral("&acirc;"), QString::fromUtf16(u"\x00E2")},
    {QStringLiteral("&acute"), QString::fromUtf16(u"\x00B4")},
    {QStringLiteral("&acute;"), QString::fromUtf16(u"\x00B4")},
    {QStringLiteral("&acy;"), QString::fromUtf16(u"\x0430")},
    {QStringLiteral("&aelig"), QString::fromUtf16(u"\x00E6")},
    {QStringLiteral("&aelig;"), QString::fromUtf16(u"\x00E6")},
    {QStringLiteral("&af;"), QString::fromUtf16(u"\x2061")},
    {QStringLiteral("&afr;"), QString::fromUtf16(u"\xD835\xDD1E")},
    {QStringLiteral("&agrave"), QString::fromUtf16(u"\x00E0")},
    {QStringLiteral("&agrave;"), QString::fromUtf16(u"\x00E0")},
    {QStringLiteral("&alefsym;"), QString::fromUtf16(u"\x2135")},
    {QStringLiteral("&aleph;"), QString::fromUtf16(u"\x2135")},
    {QStringLiteral("&alpha;"), QString::fromUtf16(u"\x03B1")},
    {QStringLiteral("&amacr;"), QString::fromUtf16(u"\x0101")},
    {QStringLiteral("&amalg;"), QString::fromUtf16(u"\x2A3F")},
    {QStringLiteral("&amp"), QString::fromUtf16(u"\x0026")},
    {QStringLiteral("&amp;"), QString::fromUtf16(u"\x0026")},
    {QStringLiteral("&and;"), QString::fromUtf16(u"\x2227")},
    {QStringLiteral("&andand;"), QString::fromUtf16(u"\x2A55")},
    {QStringLiteral("&andd;"), QString::fromUtf16(u"\x2A5C")},
    {QStringLiteral("&andslope;"), QString::fromUtf16(u"\x2A58")},
    {QStringLiteral("&andv;"), QString::fromUtf16(u"\x2A5A")},
    {QStringLiteral("&ang;"), QString::fromUtf16(u"\x2220")},
    {QStringLiteral("&ange;"), QString::fromUtf16(u"\x29A4")},
    {QStringLiteral("&angle;"), QString::fromUtf16(u"\x2220")},
    {QStringLiteral("&angmsd;"), QString::fromUtf16(u"\x2221")},
    {QStringLiteral("&angmsdaa;"), QString::fromUtf16(u"\x29A8")},
    {QStringLiteral("&angmsdab;"), QString::fromUtf16(u"\x29A9")},
    {QStringLiteral("&angmsdac;"), QString::fromUtf16(u"\x29AA")},
    {QStringLiteral("&angmsdad;"), QString::fromUtf16(u"\x29AB")},
    {QStringLiteral("&angmsdae;"), QString::fromUtf16(u"\x29AC")},
    {QStringLiteral("&angmsdaf;"), QString::fromUtf16(u"\x29AD")},
    {QStringLiteral("&angmsdag;"), QString::fromUtf16(u"\x29AE")},
    {QStringLiteral("&angmsdah;"), QString::fromUtf16(u"\x29AF")},
    {QStringLiteral("&angrt;"), QString::fromUtf16(u"\x221F")},
    {QStringLiteral("&angrtvb;"), QString::fromUtf16(u"\x22BE")},
    {QStringLiteral("&angrtvbd;"), QString::fromUtf16(u"\x299D")},
    {QStringLiteral("&angsph;"), QString::fromUtf16(u"\x2222")},
    {QStringLiteral("&angst;"), QString::fromUtf16(u"\x00C5")},
    {QStringLiteral("&angzarr;"), QString::fromUtf16(u"\x237C")},
    {QStringLiteral("&aogon;"), QString::fromUtf16(u"\x0105")},
    {QStringLiteral("&aopf;"), QString::fromUtf16(u"\xD835\xDD52")},
    {QStringLiteral("&ap;"), QString::fromUtf16(u"\x2248")},
    {QStringLiteral("&apE;"), QString::fromUtf16(u"\x2A70")},
    {QStringLiteral("&apacir;"), QString::fromUtf16(u"\x2A6F")},
    {QStringLiteral("&ape;"), QString::fromUtf16(u"\x224A")},
    {QStringLiteral("&apid;"), QString::fromUtf16(u"\x224B")},
    {QStringLiteral("&apos;"), QString::fromUtf16(u"\x0027")},
    {QStringLiteral("&approx;"), QString::fromUtf16(u"\x2248")},
    {QStringLiteral("&approxeq;"), QString::fromUtf16(u"\x224A")},
    {QStringLiteral("&aring"), QString::fromUtf16(u"\x00E5")},
    {QStringLiteral("&aring;"), QString::fromUtf16(u"\x00E5")},
    {QStringLiteral("&ascr;"), QString::fromUtf16(u"\xD835\xDCB6")},
    {QStringLiteral("&ast;"), QString::fromUtf16(u"\x002A")},
    {QStringLiteral("&asymp;"), QString::fromUtf16(u"\x2248")},
    {QStringLiteral("&asympeq;"), QString::fromUtf16(u"\x224D")},
    {QStringLiteral("&atilde"), QString::fromUtf16(u"\x00E3")},
    {QStringLiteral("&atilde;"), QString::fromUtf16(u"\x00E3")},
    {QStringLiteral("&auml"), QString::fromUtf16(u"\x00E4")},
    {QStringLiteral("&auml;"), QString::fromUtf16(u"\x00E4")},
    {QStringLiteral("&awconint;"), QString::fromUtf16(u"\x2233")},
    {QStringLiteral("&awint;"), QString::fromUtf16(u"\x2A11")},
    {QStringLiteral("&bNot;"), QString::fromUtf16(u"\x2AED")},
    {QStringLiteral("&backcong;"), QString::fromUtf16(u"\x224C")},
    {QStringLiteral("&backepsilon;"), QString::fromUtf16(u"\x03F6")},
    {QStringLiteral("&backprime;"), QString::fromUtf16(u"\x2035")},
    {QStringLiteral("&backsim;"), QString::fromUtf16(u"\x223D")},
    {QStringLiteral("&backsimeq;"), QString::fromUtf16(u"\x22CD")},
    {QStringLiteral("&barvee;"), QString::fromUtf16(u"\x22BD")},
    {QStringLiteral("&barwed;"), QString::fromUtf16(u"\x2305")},
    {QStringLiteral("&barwedge;"), QString::fromUtf16(u"\x2305")},
    {QStringLiteral("&bbrk;"), QString::fromUtf16(u"\x23B5")},
    {QStringLiteral("&bbrktbrk;"), QString::fromUtf16(u"\x23B6")},
    {QStringLiteral("&bcong;"), QString::fromUtf16(u"\x224C")},
    {QStringLiteral("&bcy;"), QString::fromUtf16(u"\x0431")},
    {QStringLiteral("&bdquo;"), QString::fromUtf16(u"\x201E")},
    {QStringLiteral("&becaus;"), QString::fromUtf16(u"\x2235")},
    {QStringLiteral("&because;"), QString::fromUtf16(u"\x2235")},
    {QStringLiteral("&bemptyv;"), QString::fromUtf16(u"\x29B0")},
    {QStringLiteral("&bepsi;"), QString::fromUtf16(u"\x03F6")},
    {QStringLiteral("&bernou;"), QString::fromUtf16(u"\x212C")},
    {QStringLiteral("&beta;"), QString::fromUtf16(u"\x03B2")},
    {QStringLiteral("&beth;"), QString::fromUtf16(u"\x2136")},
    {QStringLiteral("&between;"), QString::fromUtf16(u"\x226C")},
    {QStringLiteral("&bfr;"), QString::fromUtf16(u"\xD835\xDD1F")},
    {QStringLiteral("&bigcap;"), QString::fromUtf16(u"\x22C2")},
    {QStringLiteral("&bigcirc;"), QString::fromUtf16(u"\x25EF")},
    {QStringLiteral("&bigcup;"), QString::fromUtf16(u"\x22C3")},
    {QStringLiteral("&bigodot;"), QString::fromUtf16(u"\x2A00")},
    {QStringLiteral("&bigoplus;"), QString::fromUtf16(u"\x2A01")},
    {QStringLiteral("&bigotimes;"), QString::fromUtf16(u"\x2A02")},
    {QStringLiteral("&bigsqcup;"), QString::fromUtf16(u"\x2A06")},
    {QStringLiteral("&bigstar;"), QString::fromUtf16(u"\x2605")},
    {QStringLiteral("&bigtriangledown;"), QString::fromUtf16(u"\x25BD")},
    {QStringLiteral("&bigtriangleup;"), QString::fromUtf16(u"\x25B3")},
    {QStringLiteral("&biguplus;"), QString::fromUtf16(u"\x2A04")},
    {QStringLiteral("&bigvee;"), QString::fromUtf16(u"\x22C1")},
    {QStringLiteral("&bigwedge;"), QString::fromUtf16(u"\x22C0")},
    {QStringLiteral("&bkarow;"), QString::fromUtf16(u"\x290D")},
    {QStringLiteral("&blacklozenge;"), QString::fromUtf16(u"\x29EB")},
    {QStringLiteral("&blacksquare;"), QString::fromUtf16(u"\x25AA")},
    {QStringLiteral("&blacktriangle;"), QString::fromUtf16(u"\x25B4")},
    {QStringLiteral("&blacktriangledown;"), QString::fromUtf16(u"\x25BE")},
    {QStringLiteral("&blacktriangleleft;"), QString::fromUtf16(u"\x25C2")},
    {QStringLiteral("&blacktriangleright;"), QString::fromUtf16(u"\x25B8")},
    {QStringLiteral("&blank;"), QString::fromUtf16(u"\x2423")},
    {QStringLiteral("&blk12;"), QString::fromUtf16(u"\x2592")},
    {QStringLiteral("&blk14;"), QString::fromUtf16(u"\x2591")},
    {QStringLiteral("&blk34;"), QString::fromUtf16(u"\x2593")},
    {QStringLiteral("&block;"), QString::fromUtf16(u"\x2588")},
    {QStringLiteral("&bne;"), QString::fromUtf16(u"\x003D\x20E5")},
    {QStringLiteral("&bnequiv;"), QString::fromUtf16(u"\x2261\x20E5")},
    {QStringLiteral("&bnot;"), QString::fromUtf16(u"\x2310")},
    {QStringLiteral("&bopf;"), QString::fromUtf16(u"\xD835\xDD53")},
    {QStringLiteral("&bot;"), QString::fromUtf16(u"\x22A5")},
    {QStringLiteral("&bottom;"), QString::fromUtf16(u"\x22A5")},
    {QStringLiteral("&bowtie;"), QString::fromUtf16(u"\x22C8")},
    {QStringLiteral("&boxDL;"), QString::fromUtf16(u"\x2557")},
    {QStringLiteral("&boxDR;"), QString::fromUtf16(u"\x2554")},
    {QStringLiteral("&boxDl;"), QString::fromUtf16(u"\x2556")},
    {QStringLiteral("&boxDr;"), QString::fromUtf16(u"\x2553")},
    {QStringLiteral("&boxH;"), QString::fromUtf16(u"\x2550")},
    {QStringLiteral("&boxHD;"), QString::fromUtf16(u"\x2566")},
    {QStringLiteral("&boxHU;"), QString::fromUtf16(u"\x2569")},
    {QStringLiteral("&boxHd;"), QString::fromUtf16(u"\x2564")},
    {QStringLiteral("&boxHu;"), QString::fromUtf16(u"\x2567")},
    {QStringLiteral("&boxUL;"), QString::fromUtf16(u"\x255D")},
    {QStringLiteral("&boxUR;"), QString::fromUtf16(u"\x255A")},
    {QStringLiteral("&boxUl;"), QString::fromUtf16(u"\x255C")},
    {QStringLiteral("&boxUr;"), QString::fromUtf16(u"\x2559")},
    {QStringLiteral("&boxV;"), QString::fromUtf16(u"\x2551")},
    {QStringLiteral("&boxVH;"), QString::fromUtf16(u"\x256C")},
    {QStringLiteral("&boxVL;"), QString::fromUtf16(u"\x2563")},
    {QStringLiteral("&boxVR;"), QString::fromUtf16(u"\x2560")},
    {QStringLiteral("&boxVh;"), QString::fromUtf16(u"\x256B")},
    {QStringLiteral("&boxVl;"), QString::fromUtf16(u"\x2562")},
    {QStringLiteral("&boxVr;"), QString::fromUtf16(u"\x255F")},
    {QStringLiteral("&boxbox;"), QString::fromUtf16(u"\x29C9")},
    {QStringLiteral("&boxdL;"), QString::fromUtf16(u"\x2555")},
    {QStringLiteral("&boxdR;"), QString::fromUtf16(u"\x2552")},
    {QStringLiteral("&boxdl;"), QString::fromUtf16(u"\x2510")},
    {QStringLiteral("&boxdr;"), QString::fromUtf16(u"\x250C")},
    {QStringLiteral("&boxh;"), QString::fromUtf16(u"\x2500")},
    {QStringLiteral("&boxhD;"), QString::fromUtf16(u"\x2565")},
    {QStringLiteral("&boxhU;"), QString::fromUtf16(u"\x2568")},
    {QStringLiteral("&boxhd;"), QString::fromUtf16(u"\x252C")},
    {QStringLiteral("&boxhu;"), QString::fromUtf16(u"\x2534")},
    {QStringLiteral("&boxminus;"), QString::fromUtf16(u"\x229F")},
    {QStringLiteral("&boxplus;"), QString::fromUtf16(u"\x229E")},
    {QStringLiteral("&boxtimes;"), QString::fromUtf16(u"\x22A0")},
    {QStringLiteral("&boxuL;"), QString::fromUtf16(u"\x255B")},
    {QStringLiteral("&boxuR;"), QString::fromUtf16(u"\x2558")},
    {QStringLiteral("&boxul;"), QString::fromUtf16(u"\x2518")},
    {QStringLiteral("&boxur;"), QString::fromUtf16(u"\x2514")},
    {QStringLiteral("&boxv;"), QString::fromUtf16(u"\x2502")},
    {QStringLiteral("&boxvH;"), QString::fromUtf16(u"\x256A")},
    {QStringLiteral("&boxvL;"), QString::fromUtf16(u"\x2561")},
    {QStringLiteral("&boxvR;"), QString::fromUtf16(u"\x255E")},
    {QStringLiteral("&boxvh;"), QString::fromUtf16(u"\x253C")},
    {QStringLiteral("&boxvl;"), QString::fromUtf16(u"\x2524")},
    {QStringLiteral("&boxvr;"), QString::fromUtf16(u"\x251C")},
    {QStringLiteral("&bprime;"), QString::fromUtf16(u"\x2035")},
    {QStringLiteral("&breve;"), QString::fromUtf16(u"\x02D8")},
    {QStringLiteral("&brvbar"), QString::fromUtf16(u"\x00A6")},
    {QStringLiteral("&brvbar;"), QString::fromUtf16(u"\x00A6")},
    {QStringLiteral("&bscr;"), QString::fromUtf16(u"\xD835\xDCB7")},
    {QStringLiteral("&bsemi;"), QString::fromUtf16(u"\x204F")},
    {QStringLiteral("&bsim;"), QString::fromUtf16(u"\x223D")},
    {QStringLiteral("&bsime;"), QString::fromUtf16(u"\x22CD")},
    {QStringLiteral("&bsol;"), QString::fromUtf16(u"\x005C")},
    {QStringLiteral("&bsolb;"), QString::fromUtf16(u"\x29C5")},
    {QStringLiteral("&bsolhsub;"), QString::fromUtf16(u"\x27C8")},
    {QStringLiteral("&bull;"), QString::fromUtf16(u"\x2022")},
    {QStringLiteral("&bullet;"), QString::fromUtf16(u"\x2022")},
    {QStringLiteral("&bump;"), QString::fromUtf16(u"\x224E")},
    {QStringLiteral("&bumpE;"), QString::fromUtf16(u"\x2AAE")},
    {QStringLiteral("&bumpe;"), QString::fromUtf16(u"\x224F")},
    {QStringLiteral("&bumpeq;"), QString::fromUtf16(u"\x224F")},
    {QStringLiteral("&cacute;"), QString::fromUtf16(u"\x0107")},
    {QStringLiteral("&cap;"), QString::fromUtf16(u"\x2229")},
    {QStringLiteral("&capand;"), QString::fromUtf16(u"\x2A44")},
    {QStringLiteral("&capbrcup;"), QString::fromUtf16(u"\x2A49")},
    {QStringLiteral("&capcap;"), QString::fromUtf16(u"\x2A4B")},
    {QStringLiteral("&capcup;"), QString::fromUtf16(u"\x2A47")},
    {QStringLiteral("&capdot;"), QString::fromUtf16(u"\x2A40")},
    {QStringLiteral("&caps;"), QString::fromUtf16(u"\x2229\xFE00")},
    {QStringLiteral("&caret;"), QString::fromUtf16(u"\x2041")},
    {QStringLiteral("&caron;"), QString::fromUtf16(u"\x02C7")},
    {QStringLiteral("&ccaps;"), QString::fromUtf16(u"\x2A4D")},
    {QStringLiteral("&ccaron;"), QString::fromUtf16(u"\x010D")},
    {QStringLiteral("&ccedil"), QString::fromUtf16(u"\x00E7")},
    {QStringLiteral("&ccedil;"), QString::fromUtf16(u"\x00E7")},
    {QStringLiteral("&ccirc;"), QString::fromUtf16(u"\x0109")},
    {QStringLiteral("&ccups;"), QString::fromUtf16(u"\x2A4C")},
    {QStringLiteral("&ccupssm;"), QString::fromUtf16(u"\x2A50")},
    {QStringLiteral("&cdot;"), QString::fromUtf16(u"\x010B")},
    {QStringLiteral("&cedil"), QString::fromUtf16(u"\x00B8")},
    {QStringLiteral("&cedil;"), QString::fromUtf16(u"\x00B8")},
    {QStringLiteral("&cemptyv;"), QString::fromUtf16(u"\x29B2")},
    {QStringLiteral("&cent"), QString::fromUtf16(u"\x00A2")},
    {QStringLiteral("&cent;"), QString::fromUtf16(u"\x00A2")},
    {QStringLiteral("&centerdot;"), QString::fromUtf16(u"\x00B7")},
    {QStringLiteral("&cfr;"), QString::fromUtf16(u"\xD835\xDD20")},
    {QStringLiteral("&chcy;"), QString::fromUtf16(u"\x0447")},
    {QStringLiteral("&check;"), QString::fromUtf16(u"\x2713")},
    {QStringLiteral("&checkmark;"), QString::fromUtf16(u"\x2713")},
    {QStringLiteral("&chi;"), QString::fromUtf16(u"\x03C7")},
    {QStringLiteral("&cir;"), QString::fromUtf16(u"\x25CB")},
    {QStringLiteral("&cirE;"), QString::fromUtf16(u"\x29C3")},
    {QStringLiteral("&circ;"), QString::fromUtf16(u"\x02C6")},
    {QStringLiteral("&circeq;"), QString::fromUtf16(u"\x2257")},
    {QStringLiteral("&circlearrowleft;"), QString::fromUtf16(u"\x21BA")},
    {QStringLiteral("&circlearrowright;"), QString::fromUtf16(u"\x21BB")},
    {QStringLiteral("&circledR;"), QString::fromUtf16(u"\x00AE")},
    {QStringLiteral("&circledS;"), QString::fromUtf16(u"\x24C8")},
    {QStringLiteral("&circledast;"), QString::fromUtf16(u"\x229B")},
    {QStringLiteral("&circledcirc;"), QString::fromUtf16(u"\x229A")},
    {QStringLiteral("&circleddash;"), QString::fromUtf16(u"\x229D")},
    {QStringLiteral("&cire;"), QString::fromUtf16(u"\x2257")},
    {QStringLiteral("&cirfnint;"), QString::fromUtf16(u"\x2A10")},
    {QStringLiteral("&cirmid;"), QString::fromUtf16(u"\x2AEF")},
    {QStringLiteral("&cirscir;"), QString::fromUtf16(u"\x29C2")},
    {QStringLiteral("&clubs;"), QString::fromUtf16(u"\x2663")},
    {QStringLiteral("&clubsuit;"), QString::fromUtf16(u"\x2663")},
    {QStringLiteral("&colon;"), QString::fromUtf16(u"\x003A")},
    {QStringLiteral("&colone;"), QString::fromUtf16(u"\x2254")},
    {QStringLiteral("&coloneq;"), QString::fromUtf16(u"\x2254")},
    {QStringLiteral("&comma;"), QString::fromUtf16(u"\x002C")},
    {QStringLiteral("&commat;"), QString::fromUtf16(u"\x0040")},
    {QStringLiteral("&comp;"), QString::fromUtf16(u"\x2201")},
    {QStringLiteral("&compfn;"), QString::fromUtf16(u"\x2218")},
    {QStringLiteral("&complement;"), QString::fromUtf16(u"\x2201")},
    {QStringLiteral("&complexes;"), QString::fromUtf16(u"\x2102")},
    {QStringLiteral("&cong;"), QString::fromUtf16(u"\x2245")},
    {QStringLiteral("&congdot;"), QString::fromUtf16(u"\x2A6D")},
    {QStringLiteral("&conint;"), QString::fromUtf16(u"\x222E")},
    {QStringLiteral("&copf;"), QString::fromUtf16(u"\xD835\xDD54")},
    {QStringLiteral("&coprod;"), QString::fromUtf16(u"\x2210")},
    {QStringLiteral("&copy"), QString::fromUtf16(u"\x00A9")},
    {QStringLiteral("&copy;"), QString::fromUtf16(u"\x00A9")},
    {QStringLiteral("&copysr;"), QString::fromUtf16(u"\x2117")},
    {QStringLiteral("&crarr;"), QString::fromUtf16(u"\x21B5")},
    {QStringLiteral("&cross;"), QString::fromUtf16(u"\x2717")},
    {QStringLiteral("&cscr;"), QString::fromUtf16(u"\xD835\xDCB8")},
    {QStringLiteral("&csub;"), QString::fromUtf16(u"\x2ACF")},
    {QStringLiteral("&csube;"), QString::fromUtf16(u"\x2AD1")},
    {QStringLiteral("&csup;"), QString::fromUtf16(u"\x2AD0")},
    {QStringLiteral("&csupe;"), QString::fromUtf16(u"\x2AD2")},
    {QStringLiteral("&ctdot;"), QString::fromUtf16(u"\x22EF")},
    {QStringLiteral("&cudarrl;"), QString::fromUtf16(u"\x2938")},
    {QStringLiteral("&cudarrr;"), QString::fromUtf16(u"\x2935")},
    {QStringLiteral("&cuepr;"), QString::fromUtf16(u"\x22DE")},
    {QStringLiteral("&cuesc;"), QString::fromUtf16(u"\x22DF")},
    {QStringLiteral("&cularr;"), QString::fromUtf16(u"\x21B6")},
    {QStringLiteral("&cularrp;"), QString::fromUtf16(u"\x293D")},
    {QStringLiteral("&cup;"), QString::fromUtf16(u"\x222A")},
    {QStringLiteral("&cupbrcap;"), QString::fromUtf16(u"\x2A48")},
    {QStringLiteral("&cupcap;"), QString::fromUtf16(u"\x2A46")},
    {QStringLiteral("&cupcup;"), QString::fromUtf16(u"\x2A4A")},
    {QStringLiteral("&cupdot;"), QString::fromUtf16(u"\x228D")},
    {QStringLiteral("&cupor;"), QString::fromUtf16(u"\x2A45")},
    {QStringLiteral("&cups;"), QString::fromUtf16(u"\x222A\xFE00")},
    {QStringLiteral("&curarr;"), QString::fromUtf16(u"\x21B7")},
    {QStringLiteral("&curarrm;"), QString::fromUtf16(u"\x293C")},
    {QStringLiteral("&curlyeqprec;"), QString::fromUtf16(u"\x22DE")},
    {QStringLiteral("&curlyeqsucc;"), QString::fromUtf16(u"\x22DF")},
    {QStringLiteral("&curlyvee;"), QString::fromUtf16(u"\x22CE")},
    {QStringLiteral("&curlywedge;"), QString::fromUtf16(u"\x22CF")},
    {QStringLiteral("&curren"), QString::fromUtf16(u"\x00A4")},
    {QStringLiteral("&curren;"), QString::fromUtf16(u"\x00A4")},
    {QStringLiteral("&curvearrowleft;"), QString::fromUtf16(u"\x21B6")},
    {QStringLiteral("&curvearrowright;"), QString::fromUtf16(u"\x21B7")},
    {QStringLiteral("&cuvee;"), QString::fromUtf16(u"\x22CE")},
    {QStringLiteral("&cuwed;"), QString::fromUtf16(u"\x22CF")},
    {QStringLiteral("&cwconint;"), QString::fromUtf16(u"\x2232")},
    {QStringLiteral("&cwint;"), QString::fromUtf16(u"\x2231")},
    {QStringLiteral("&cylcty;"), QString::fromUtf16(u"\x232D")},
    {QStringLiteral("&dArr;"), QString::fromUtf16(u"\x21D3")},
    {QStringLiteral("&dHar;"), QString::fromUtf16(u"\x2965")},
    {QStringLiteral("&dagger;"), QString::fromUtf16(u"\x2020")},
    {QStringLiteral("&daleth;"), QString::fromUtf16(u"\x2138")},
    {QStringLiteral("&darr;"), QString::fromUtf16(u"\x2193")},
    {QStringLiteral("&dash;"), QString::fromUtf16(u"\x2010")},
    {QStringLiteral("&dashv;"), QString::fromUtf16(u"\x22A3")},
    {QStringLiteral("&dbkarow;"), QString::fromUtf16(u"\x290F")},
    {QStringLiteral("&dblac;"), QString::fromUtf16(u"\x02DD")},
    {QStringLiteral("&dcaron;"), QString::fromUtf16(u"\x010F")},
    {QStringLiteral("&dcy;"), QString::fromUtf16(u"\x0434")},
    {QStringLiteral("&dd;"), QString::fromUtf16(u"\x2146")},
    {QStringLiteral("&ddagger;"), QString::fromUtf16(u"\x2021")},
    {QStringLiteral("&ddarr;"), QString::fromUtf16(u"\x21CA")},
    {QStringLiteral("&ddotseq;"), QString::fromUtf16(u"\x2A77")},
    {QStringLiteral("&deg"), QString::fromUtf16(u"\x00B0")},
    {QStringLiteral("&deg;"), QString::fromUtf16(u"\x00B0")},
    {QStringLiteral("&delta;"), QString::fromUtf16(u"\x03B4")},
    {QStringLiteral("&demptyv;"), QString::fromUtf16(u"\x29B1")},
    {QStringLiteral("&dfisht;"), QString::fromUtf16(u"\x297F")},
    {QStringLiteral("&dfr;"), QString::fromUtf16(u"\xD835\xDD21")},
    {QStringLiteral("&dharl;"), QString::fromUtf16(u"\x21C3")},
    {QStringLiteral("&dharr;"), QString::fromUtf16(u"\x21C2")},
    {QStringLiteral("&diam;"), QString::fromUtf16(u"\x22C4")},
    {QStringLiteral("&diamond;"), QString::fromUtf16(u"\x22C4")},
    {QStringLiteral("&diamondsuit;"), QString::fromUtf16(u"\x2666")},
    {QStringLiteral("&diams;"), QString::fromUtf16(u"\x2666")},
    {QStringLiteral("&die;"), QString::fromUtf16(u"\x00A8")},
    {QStringLiteral("&digamma;"), QString::fromUtf16(u"\x03DD")},
    {QStringLiteral("&disin;"), QString::fromUtf16(u"\x22F2")},
    {QStringLiteral("&div;"), QString::fromUtf16(u"\x00F7")},
    {QStringLiteral("&divide"), QString::fromUtf16(u"\x00F7")},
    {QStringLiteral("&divide;"), QString::fromUtf16(u"\x00F7")},
    {QStringLiteral("&divideontimes;"), QString::fromUtf16(u"\x22C7")},
    {QStringLiteral("&divonx;"), QString::fromUtf16(u"\x22C7")},
    {QStringLiteral("&djcy;"), QString::fromUtf16(u"\x0452")},
    {QStringLiteral("&dlcorn;"), QString::fromUtf16(u"\x231E")},
    {QStringLiteral("&dlcrop;"), QString::fromUtf16(u"\x230D")},
    {QStringLiteral("&dollar;"), QString::fromUtf16(u"\x0024")},
    {QStringLiteral("&dopf;"), QString::fromUtf16(u"\xD835\xDD55")},
    {QStringLiteral("&dot;"), QString::fromUtf16(u"\x02D9")},
    {QStringLiteral("&doteq;"), QString::fromUtf16(u"\x2250")},
    {QStringLiteral("&doteqdot;"), QString::fromUtf16(u"\x2251")},
    {QStringLiteral("&dotminus;"), QString::fromUtf16(u"\x2238")},
    {QStringLiteral("&dotplus;"), QString::fromUtf16(u"\x2214")},
    {QStringLiteral("&dotsquare;"), QString::fromUtf16(u"\x22A1")},
    {QStringLiteral("&doublebarwedge;"), QString::fromUtf16(u"\x2306")},
    {QStringLiteral("&downarrow;"), QString::fromUtf16(u"\x2193")},
    {QStringLiteral("&downdownarrows;"), QString::fromUtf16(u"\x21CA")},
    {QStringLiteral("&downharpoonleft;"), QString::fromUtf16(u"\x21C3")},
    {QStringLiteral("&downharpoonright;"), QString::fromUtf16(u"\x21C2")},
    {QStringLiteral("&drbkarow;"), QString::fromUtf16(u"\x2910")},
    {QStringLiteral("&drcorn;"), QString::fromUtf16(u"\x231F")},
    {QStringLiteral("&drcrop;"), QString::fromUtf16(u"\x230C")},
    {QStringLiteral("&dscr;"), QString::fromUtf16(u"\xD835\xDCB9")},
    {QStringLiteral("&dscy;"), QString::fromUtf16(u"\x0455")},
    {QStringLiteral("&dsol;"), QString::fromUtf16(u"\x29F6")},
    {QStringLiteral("&dstrok;"), QString::fromUtf16(u"\x0111")},
    {QStringLiteral("&dtdot;"), QString::fromUtf16(u"\x22F1")},
    {QStringLiteral("&dtri;"), QString::fromUtf16(u"\x25BF")},
    {QStringLiteral("&dtrif;"), QString::fromUtf16(u"\x25BE")},
    {QStringLiteral("&duarr;"), QString::fromUtf16(u"\x21F5")},
    {QStringLiteral("&duhar;"), QString::fromUtf16(u"\x296F")},
    {QStringLiteral("&dwangle;"), QString::fromUtf16(u"\x29A6")},
    {QStringLiteral("&dzcy;"), QString::fromUtf16(u"\x045F")},
    {QStringLiteral("&dzigrarr;"), QString::fromUtf16(u"\x27FF")},
    {QStringLiteral("&eDDot;"), QString::fromUtf16(u"\x2A77")},
    {QStringLiteral("&eDot;"), QString::fromUtf16(u"\x2251")},
    {QStringLiteral("&eacute"), QString::fromUtf16(u"\x00E9")},
    {QStringLiteral("&eacute;"), QString::fromUtf16(u"\x00E9")},
    {QStringLiteral("&easter;"), QString::fromUtf16(u"\x2A6E")},
    {QStringLiteral("&ecaron;"), QString::fromUtf16(u"\x011B")},
    {QStringLiteral("&ecir;"), QString::fromUtf16(u"\x2256")},
    {QStringLiteral("&ecirc"), QString::fromUtf16(u"\x00EA")},
    {QStringLiteral("&ecirc;"), QString::fromUtf16(u"\x00EA")},
    {QStringLiteral("&ecolon;"), QString::fromUtf16(u"\x2255")},
    {QStringLiteral("&ecy;"), QString::fromUtf16(u"\x044D")},
    {QStringLiteral("&edot;"), QString::fromUtf16(u"\x0117")},
    {QStringLiteral("&ee;"), QString::fromUtf16(u"\x2147")},
    {QStringLiteral("&efDot;"), QString::fromUtf16(u"\x2252")},
    {QStringLiteral("&efr;"), QString::fromUtf16(u"\xD835\xDD22")},
    {QStringLiteral("&eg;"), QString::fromUtf16(u"\x2A9A")},
    {QStringLiteral("&egrave"), QString::fromUtf16(u"\x00E8")},
    {QStringLiteral("&egrave;"), QString::fromUtf16(u"\x00E8")},
    {QStringLiteral("&egs;"), QString::fromUtf16(u"\x2A96")},
    {QStringLiteral("&egsdot;"), QString::fromUtf16(u"\x2A98")},
    {QStringLiteral("&el;"), QString::fromUtf16(u"\x2A99")},
    {QStringLiteral("&elinters;"), QString::fromUtf16(u"\x23E7")},
    {QStringLiteral("&ell;"), QString::fromUtf16(u"\x2113")},
    {QStringLiteral("&els;"), QString::fromUtf16(u"\x2A95")},
    {QStringLiteral("&elsdot;"), QString::fromUtf16(u"\x2A97")},
    {QStringLiteral("&emacr;"), QString::fromUtf16(u"\x0113")},
    {QStringLiteral("&empty;"), QString::fromUtf16(u"\x2205")},
    {QStringLiteral("&emptyset;"), QString::fromUtf16(u"\x2205")},
    {QStringLiteral("&emptyv;"), QString::fromUtf16(u"\x2205")},
    {QStringLiteral("&emsp13;"), QString::fromUtf16(u"\x2004")},
    {QStringLiteral("&emsp14;"), QString::fromUtf16(u"\x2005")},
    {QStringLiteral("&emsp;"), QString::fromUtf16(u"\x2003")},
    {QStringLiteral("&eng;"), QString::fromUtf16(u"\x014B")},
    {QStringLiteral("&ensp;"), QString::fromUtf16(u"\x2002")},
    {QStringLiteral("&eogon;"), QString::fromUtf16(u"\x0119")},
    {QStringLiteral("&eopf;"), QString::fromUtf16(u"\xD835\xDD56")},
    {QStringLiteral("&epar;"), QString::fromUtf16(u"\x22D5")},
    {QStringLiteral("&eparsl;"), QString::fromUtf16(u"\x29E3")},
    {QStringLiteral("&eplus;"), QString::fromUtf16(u"\x2A71")},
    {QStringLiteral("&epsi;"), QString::fromUtf16(u"\x03B5")},
    {QStringLiteral("&epsilon;"), QString::fromUtf16(u"\x03B5")},
    {QStringLiteral("&epsiv;"), QString::fromUtf16(u"\x03F5")},
    {QStringLiteral("&eqcirc;"), QString::fromUtf16(u"\x2256")},
    {QStringLiteral("&eqcolon;"), QString::fromUtf16(u"\x2255")},
    {QStringLiteral("&eqsim;"), QString::fromUtf16(u"\x2242")},
    {QStringLiteral("&eqslantgtr;"), QString::fromUtf16(u"\x2A96")},
    {QStringLiteral("&eqslantless;"), QString::fromUtf16(u"\x2A95")},
    {QStringLiteral("&equals;"), QString::fromUtf16(u"\x003D")},
    {QStringLiteral("&equest;"), QString::fromUtf16(u"\x225F")},
    {QStringLiteral("&equiv;"), QString::fromUtf16(u"\x2261")},
    {QStringLiteral("&equivDD;"), QString::fromUtf16(u"\x2A78")},
    {QStringLiteral("&eqvparsl;"), QString::fromUtf16(u"\x29E5")},
    {QStringLiteral("&erDot;"), QString::fromUtf16(u"\x2253")},
    {QStringLiteral("&erarr;"), QString::fromUtf16(u"\x2971")},
    {QStringLiteral("&escr;"), QString::fromUtf16(u"\x212F")},
    {QStringLiteral("&esdot;"), QString::fromUtf16(u"\x2250")},
    {QStringLiteral("&esim;"), QString::fromUtf16(u"\x2242")},
    {QStringLiteral("&eta;"), QString::fromUtf16(u"\x03B7")},
    {QStringLiteral("&eth"), QString::fromUtf16(u"\x00F0")},
    {QStringLiteral("&eth;"), QString::fromUtf16(u"\x00F0")},
    {QStringLiteral("&euml"), QString::fromUtf16(u"\x00EB")},
    {QStringLiteral("&euml;"), QString::fromUtf16(u"\x00EB")},
    {QStringLiteral("&euro;"), QString::fromUtf16(u"\x20AC")},
    {QStringLiteral("&excl;"), QString::fromUtf16(u"\x0021")},
    {QStringLiteral("&exist;"), QString::fromUtf16(u"\x2203")},
    {QStringLiteral("&expectation;"), QString::fromUtf16(u"\x2130")},
    {QStringLiteral("&exponentiale;"), QString::fromUtf16(u"\x2147")},
    {QStringLiteral("&fallingdotseq;"), QString::fromUtf16(u"\x2252")},
    {QStringLiteral("&fcy;"), QString::fromUtf16(u"\x0444")},
    {QStringLiteral("&female;"), QString::fromUtf16(u"\x2640")},
    {QStringLiteral("&ffilig;"), QString::fromUtf16(u"\xFB03")},
    {QStringLiteral("&fflig;"), QString::fromUtf16(u"\xFB00")},
    {QStringLiteral("&ffllig;"), QString::fromUtf16(u"\xFB04")},
    {QStringLiteral("&ffr;"), QString::fromUtf16(u"\xD835\xDD23")},
    {QStringLiteral("&filig;"), QString::fromUtf16(u"\xFB01")},
    {QStringLiteral("&fjlig;"), QString::fromUtf16(u"\x0066\x006A")},
    {QStringLiteral("&flat;"), QString::fromUtf16(u"\x266D")},
    {QStringLiteral("&fllig;"), QString::fromUtf16(u"\xFB02")},
    {QStringLiteral("&fltns;"), QString::fromUtf16(u"\x25B1")},
    {QStringLiteral("&fnof;"), QString::fromUtf16(u"\x0192")},
    {QStringLiteral("&fopf;"), QString::fromUtf16(u"\xD835\xDD57")},
    {QStringLiteral("&forall;"), QString::fromUtf16(u"\x2200")},
    {QStringLiteral("&fork;"), QString::fromUtf16(u"\x22D4")},
    {QStringLiteral("&forkv;"), QString::fromUtf16(u"\x2AD9")},
    {QStringLiteral("&fpartint;"), QString::fromUtf16(u"\x2A0D")},
    {QStringLiteral("&frac12"), QString::fromUtf16(u"\x00BD")},
    {QStringLiteral("&frac12;"), QString::fromUtf16(u"\x00BD")},
    {QStringLiteral("&frac13;"), QString::fromUtf16(u"\x2153")},
    {QStringLiteral("&frac14"), QString::fromUtf16(u"\x00BC")},
    {QStringLiteral("&frac14;"), QString::fromUtf16(u"\x00BC")},
    {QStringLiteral("&frac15;"), QString::fromUtf16(u"\x2155")},
    {QStringLiteral("&frac16;"), QString::fromUtf16(u"\x2159")},
    {QStringLiteral("&frac18;"), QString::fromUtf16(u"\x215B")},
    {QStringLiteral("&frac23;"), QString::fromUtf16(u"\x2154")},
    {QStringLiteral("&frac25;"), QString::fromUtf16(u"\x2156")},
    {QStringLiteral("&frac34"), QString::fromUtf16(u"\x00BE")},
    {QStringLiteral("&frac34;"), QString::fromUtf16(u"\x00BE")},
    {QStringLiteral("&frac35;"), QString::fromUtf16(u"\x2157")},
    {QStringLiteral("&frac38;"), QString::fromUtf16(u"\x215C")},
    {QStringLiteral("&frac45;"), QString::fromUtf16(u"\x2158")},
    {QStringLiteral("&frac56;"), QString::fromUtf16(u"\x215A")},
    {QStringLiteral("&frac58;"), QString::fromUtf16(u"\x215D")},
    {QStringLiteral("&frac78;"), QString::fromUtf16(u"\x215E")},
    {QStringLiteral("&frasl;"), QString::fromUtf16(u"\x2044")},
    {QStringLiteral("&frown;"), QString::fromUtf16(u"\x2322")},
    {QStringLiteral("&fscr;"), QString::fromUtf16(u"\xD835\xDCBB")},
    {QStringLiteral("&gE;"), QString::fromUtf16(u"\x2267")},
    {QStringLiteral("&gEl;"), QString::fromUtf16(u"\x2A8C")},
    {QStringLiteral("&gacute;"), QString::fromUtf16(u"\x01F5")},
    {QStringLiteral("&gamma;"), QString::fromUtf16(u"\x03B3")},
    {QStringLiteral("&gammad;"), QString::fromUtf16(u"\x03DD")},
    {QStringLiteral("&gap;"), QString::fromUtf16(u"\x2A86")},
    {QStringLiteral("&gbreve;"), QString::fromUtf16(u"\x011F")},
    {QStringLiteral("&gcirc;"), QString::fromUtf16(u"\x011D")},
    {QStringLiteral("&gcy;"), QString::fromUtf16(u"\x0433")},
    {QStringLiteral("&gdot;"), QString::fromUtf16(u"\x0121")},
    {QStringLiteral("&ge;"), QString::fromUtf16(u"\x2265")},
    {QStringLiteral("&gel;"), QString::fromUtf16(u"\x22DB")},
    {QStringLiteral("&geq;"), QString::fromUtf16(u"\x2265")},
    {QStringLiteral("&geqq;"), QString::fromUtf16(u"\x2267")},
    {QStringLiteral("&geqslant;"), QString::fromUtf16(u"\x2A7E")},
    {QStringLiteral("&ges;"), QString::fromUtf16(u"\x2A7E")},
    {QStringLiteral("&gescc;"), QString::fromUtf16(u"\x2AA9")},
    {QStringLiteral("&gesdot;"), QString::fromUtf16(u"\x2A80")},
    {QStringLiteral("&gesdoto;"), QString::fromUtf16(u"\x2A82")},
    {QStringLiteral("&gesdotol;"), QString::fromUtf16(u"\x2A84")},
    {QStringLiteral("&gesl;"), QString::fromUtf16(u"\x22DB\xFE00")},
    {QStringLiteral("&gesles;"), QString::fromUtf16(u"\x2A94")},
    {QStringLiteral("&gfr;"), QString::fromUtf16(u"\xD835\xDD24")},
    {QStringLiteral("&gg;"), QString::fromUtf16(u"\x226B")},
    {QStringLiteral("&ggg;"), QString::fromUtf16(u"\x22D9")},
    {QStringLiteral("&gimel;"), QString::fromUtf16(u"\x2137")},
    {QStringLiteral("&gjcy;"), QString::fromUtf16(u"\x0453")},
    {QStringLiteral("&gl;"), QString::fromUtf16(u"\x2277")},
    {QStringLiteral("&glE;"), QString::fromUtf16(u"\x2A92")},
    {QStringLiteral("&gla;"), QString::fromUtf16(u"\x2AA5")},
    {QStringLiteral("&glj;"), QString::fromUtf16(u"\x2AA4")},
    {QStringLiteral("&gnE;"), QString::fromUtf16(u"\x2269")},
    {QStringLiteral("&gnap;"), QString::fromUtf16(u"\x2A8A")},
    {QStringLiteral("&gnapprox;"), QString::fromUtf16(u"\x2A8A")},
    {QStringLiteral("&gne;"), QString::fromUtf16(u"\x2A88")},
    {QStringLiteral("&gneq;"), QString::fromUtf16(u"\x2A88")},
    {QStringLiteral("&gneqq;"), QString::fromUtf16(u"\x2269")},
    {QStringLiteral("&gnsim;"), QString::fromUtf16(u"\x22E7")},
    {QStringLiteral("&gopf;"), QString::fromUtf16(u"\xD835\xDD58")},
    {QStringLiteral("&grave;"), QString::fromUtf16(u"\x0060")},
    {QStringLiteral("&gscr;"), QString::fromUtf16(u"\x210A")},
    {QStringLiteral("&gsim;"), QString::fromUtf16(u"\x2273")},
    {QStringLiteral("&gsime;"), QString::fromUtf16(u"\x2A8E")},
    {QStringLiteral("&gsiml;"), QString::fromUtf16(u"\x2A90")},
    {QStringLiteral("&gt"), QString::fromUtf16(u"\x003E")},
    {QStringLiteral("&gt;"), QString::fromUtf16(u"\x003E")},
    {QStringLiteral("&gtcc;"), QString::fromUtf16(u"\x2AA7")},
    {QStringLiteral("&gtcir;"), QString::fromUtf16(u"\x2A7A")},
    {QStringLiteral("&gtdot;"), QString::fromUtf16(u"\x22D7")},
    {QStringLiteral("&gtlPar;"), QString::fromUtf16(u"\x2995")},
    {QStringLiteral("&gtquest;"), QString::fromUtf16(u"\x2A7C")},
    {QStringLiteral("&gtrapprox;"), QString::fromUtf16(u"\x2A86")},
    {QStringLiteral("&gtrarr;"), QString::fromUtf16(u"\x2978")},
    {QStringLiteral("&gtrdot;"), QString::fromUtf16(u"\x22D7")},
    {QStringLiteral("&gtreqless;"), QString::fromUtf16(u"\x22DB")},
    {QStringLiteral("&gtreqqless;"), QString::fromUtf16(u"\x2A8C")},
    {QStringLiteral("&gtrless;"), QString::fromUtf16(u"\x2277")},
    {QStringLiteral("&gtrsim;"), QString::fromUtf16(u"\x2273")},
    {QStringLiteral("&gvertneqq;"), QString::fromUtf16(u"\x2269\xFE00")},
    {QStringLiteral("&gvnE;"), QString::fromUtf16(u"\x2269\xFE00")},
    {QStringLiteral("&hArr;"), QString::fromUtf16(u"\x21D4")},
    {QStringLiteral("&hairsp;"), QString::fromUtf16(u"\x200A")},
    {QStringLiteral("&half;"), QString::fromUtf16(u"\x00BD")},
    {QStringLiteral("&hamilt;"), QString::fromUtf16(u"\x210B")},
    {QStringLiteral("&hardcy;"), QString::fromUtf16(u"\x044A")},
    {QStringLiteral("&harr;"), QString::fromUtf16(u"\x2194")},
    {QStringLiteral("&harrcir;"), QString::fromUtf16(u"\x2948")},
    {QStringLiteral("&harrw;"), QString::fromUtf16(u"\x21AD")},
    {QStringLiteral("&hbar;"), QString::fromUtf16(u"\x210F")},
    {QStringLiteral("&hcirc;"), QString::fromUtf16(u"\x0125")},
    {QStringLiteral("&hearts;"), QString::fromUtf16(u"\x2665")},
    {QStringLiteral("&heartsuit;"), QString::fromUtf16(u"\x2665")},
    {QStringLiteral("&hellip;"), QString::fromUtf16(u"\x2026")},
    {QStringLiteral("&hercon;"), QString::fromUtf16(u"\x22B9")},
    {QStringLiteral("&hfr;"), QString::fromUtf16(u"\xD835\xDD25")},
    {QStringLiteral("&hksearow;"), QString::fromUtf16(u"\x2925")},
    {QStringLiteral("&hkswarow;"), QString::fromUtf16(u"\x2926")},
    {QStringLiteral("&hoarr;"), QString::fromUtf16(u"\x21FF")},
    {QStringLiteral("&homtht;"), QString::fromUtf16(u"\x223B")},
    {QStringLiteral("&hookleftarrow;"), QString::fromUtf16(u"\x21A9")},
    {QStringLiteral("&hookrightarrow;"), QString::fromUtf16(u"\x21AA")},
    {QStringLiteral("&hopf;"), QString::fromUtf16(u"\xD835\xDD59")},
    {QStringLiteral("&horbar;"), QString::fromUtf16(u"\x2015")},
    {QStringLiteral("&hscr;"), QString::fromUtf16(u"\xD835\xDCBD")},
    {QStringLiteral("&hslash;"), QString::fromUtf16(u"\x210F")},
    {QStringLiteral("&hstrok;"), QString::fromUtf16(u"\x0127")},
    {QStringLiteral("&hybull;"), QString::fromUtf16(u"\x2043")},
    {QStringLiteral("&hyphen;"), QString::fromUtf16(u"\x2010")},
    {QStringLiteral("&iacute"), QString::fromUtf16(u"\x00ED")},
    {QStringLiteral("&iacute;"), QString::fromUtf16(u"\x00ED")},
    {QStringLiteral("&ic;"), QString::fromUtf16(u"\x2063")},
    {QStringLiteral("&icirc"), QString::fromUtf16(u"\x00EE")},
    {QStringLiteral("&icirc;"), QString::fromUtf16(u"\x00EE")},
    {QStringLiteral("&icy;"), QString::fromUtf16(u"\x0438")},
    {QStringLiteral("&iecy;"), QString::fromUtf16(u"\x0435")},
    {QStringLiteral("&iexcl"), QString::fromUtf16(u"\x00A1")},
    {QStringLiteral("&iexcl;"), QString::fromUtf16(u"\x00A1")},
    {QStringLiteral("&iff;"), QString::fromUtf16(u"\x21D4")},
    {QStringLiteral("&ifr;"), QString::fromUtf16(u"\xD835\xDD26")},
    {QStringLiteral("&igrave"), QString::fromUtf16(u"\x00EC")},
    {QStringLiteral("&igrave;"), QString::fromUtf16(u"\x00EC")},
    {QStringLiteral("&ii;"), QString::fromUtf16(u"\x2148")},
    {QStringLiteral("&iiiint;"), QString::fromUtf16(u"\x2A0C")},
    {QStringLiteral("&iiint;"), QString::fromUtf16(u"\x222D")},
    {QStringLiteral("&iinfin;"), QString::fromUtf16(u"\x29DC")},
    {QStringLiteral("&iiota;"), QString::fromUtf16(u"\x2129")},
    {QStringLiteral("&ijlig;"), QString::fromUtf16(u"\x0133")},
    {QStringLiteral("&imacr;"), QString::fromUtf16(u"\x012B")},
    {QStringLiteral("&image;"), QString::fromUtf16(u"\x2111")},
    {QStringLiteral("&imagline;"), QString::fromUtf16(u"\x2110")},
    {QStringLiteral("&imagpart;"), QString::fromUtf16(u"\x2111")},
    {QStringLiteral("&imath;"), QString::fromUtf16(u"\x0131")},
    {QStringLiteral("&imof;"), QString::fromUtf16(u"\x22B7")},
    {QStringLiteral("&imped;"), QString::fromUtf16(u"\x01B5")},
    {QStringLiteral("&in;"), QString::fromUtf16(u"\x2208")},
    {QStringLiteral("&incare;"), QString::fromUtf16(u"\x2105")},
    {QStringLiteral("&infin;"), QString::fromUtf16(u"\x221E")},
    {QStringLiteral("&infintie;"), QString::fromUtf16(u"\x29DD")},
    {QStringLiteral("&inodot;"), QString::fromUtf16(u"\x0131")},
    {QStringLiteral("&int;"), QString::fromUtf16(u"\x222B")},
    {QStringLiteral("&intcal;"), QString::fromUtf16(u"\x22BA")},
    {QStringLiteral("&integers;"), QString::fromUtf16(u"\x2124")},
    {QStringLiteral("&intercal;"), QString::fromUtf16(u"\x22BA")},
    {QStringLiteral("&intlarhk;"), QString::fromUtf16(u"\x2A17")},
    {QStringLiteral("&intprod;"), QString::fromUtf16(u"\x2A3C")},
    {QStringLiteral("&iocy;"), QString::fromUtf16(u"\x0451")},
    {QStringLiteral("&iogon;"), QString::fromUtf16(u"\x012F")},
    {QStringLiteral("&iopf;"), QString::fromUtf16(u"\xD835\xDD5A")},
    {QStringLiteral("&iota;"), QString::fromUtf16(u"\x03B9")},
    {QStringLiteral("&iprod;"), QString::fromUtf16(u"\x2A3C")},
    {QStringLiteral("&iquest"), QString::fromUtf16(u"\x00BF")},
    {QStringLiteral("&iquest;"), QString::fromUtf16(u"\x00BF")},
    {QStringLiteral("&iscr;"), QString::fromUtf16(u"\xD835\xDCBE")},
    {QStringLiteral("&isin;"), QString::fromUtf16(u"\x2208")},
    {QStringLiteral("&isinE;"), QString::fromUtf16(u"\x22F9")},
    {QStringLiteral("&isindot;"), QString::fromUtf16(u"\x22F5")},
    {QStringLiteral("&isins;"), QString::fromUtf16(u"\x22F4")},
    {QStringLiteral("&isinsv;"), QString::fromUtf16(u"\x22F3")},
    {QStringLiteral("&isinv;"), QString::fromUtf16(u"\x2208")},
    {QStringLiteral("&it;"), QString::fromUtf16(u"\x2062")},
    {QStringLiteral("&itilde;"), QString::fromUtf16(u"\x0129")},
    {QStringLiteral("&iukcy;"), QString::fromUtf16(u"\x0456")},
    {QStringLiteral("&iuml"), QString::fromUtf16(u"\x00EF")},
    {QStringLiteral("&iuml;"), QString::fromUtf16(u"\x00EF")},
    {QStringLiteral("&jcirc;"), QString::fromUtf16(u"\x0135")},
    {QStringLiteral("&jcy;"), QString::fromUtf16(u"\x0439")},
    {QStringLiteral("&jfr;"), QString::fromUtf16(u"\xD835\xDD27")},
    {QStringLiteral("&jmath;"), QString::fromUtf16(u"\x0237")},
    {QStringLiteral("&jopf;"), QString::fromUtf16(u"\xD835\xDD5B")},
    {QStringLiteral("&jscr;"), QString::fromUtf16(u"\xD835\xDCBF")},
    {QStringLiteral("&jsercy;"), QString::fromUtf16(u"\x0458")},
    {QStringLiteral("&jukcy;"), QString::fromUtf16(u"\x0454")},
    {QStringLiteral("&kappa;"), QString::fromUtf16(u"\x03BA")},
    {QStringLiteral("&kappav;"), QString::fromUtf16(u"\x03F0")},
    {QStringLiteral("&kcedil;"), QString::fromUtf16(u"\x0137")},
    {QStringLiteral("&kcy;"), QString::fromUtf16(u"\x043A")},
    {QStringLiteral("&kfr;"), QString::fromUtf16(u"\xD835\xDD28")},
    {QStringLiteral("&kgreen;"), QString::fromUtf16(u"\x0138")},
    {QStringLiteral("&khcy;"), QString::fromUtf16(u"\x0445")},
    {QStringLiteral("&kjcy;"), QString::fromUtf16(u"\x045C")},
    {QStringLiteral("&kopf;"), QString::fromUtf16(u"\xD835\xDD5C")},
    {QStringLiteral("&kscr;"), QString::fromUtf16(u"\xD835\xDCC0")},
    {QStringLiteral("&lAarr;"), QString::fromUtf16(u"\x21DA")},
    {QStringLiteral("&lArr;"), QString::fromUtf16(u"\x21D0")},
    {QStringLiteral("&lAtail;"), QString::fromUtf16(u"\x291B")},
    {QStringLiteral("&lBarr;"), QString::fromUtf16(u"\x290E")},
    {QStringLiteral("&lE;"), QString::fromUtf16(u"\x2266")},
    {QStringLiteral("&lEg;"), QString::fromUtf16(u"\x2A8B")},
    {QStringLiteral("&lHar;"), QString::fromUtf16(u"\x2962")},
    {QStringLiteral("&lacute;"), QString::fromUtf16(u"\x013A")},
    {QStringLiteral("&laemptyv;"), QString::fromUtf16(u"\x29B4")},
    {QStringLiteral("&lagran;"), QString::fromUtf16(u"\x2112")},
    {QStringLiteral("&lambda;"), QString::fromUtf16(u"\x03BB")},
    {QStringLiteral("&lang;"), QString::fromUtf16(u"\x27E8")},
    {QStringLiteral("&langd;"), QString::fromUtf16(u"\x2991")},
    {QStringLiteral("&langle;"), QString::fromUtf16(u"\x27E8")},
    {QStringLiteral("&lap;"), QString::fromUtf16(u"\x2A85")},
    {QStringLiteral("&laquo"), QString::fromUtf16(u"\x00AB")},
    {QStringLiteral("&laquo;"), QString::fromUtf16(u"\x00AB")},
    {QStringLiteral("&larr;"), QString::fromUtf16(u"\x2190")},
    {QStringLiteral("&larrb;"), QString::fromUtf16(u"\x21E4")},
    {QStringLiteral("&larrbfs;"), QString::fromUtf16(u"\x291F")},
    {QStringLiteral("&larrfs;"), QString::fromUtf16(u"\x291D")},
    {QStringLiteral("&larrhk;"), QString::fromUtf16(u"\x21A9")},
    {QStringLiteral("&larrlp;"), QString::fromUtf16(u"\x21AB")},
    {QStringLiteral("&larrpl;"), QString::fromUtf16(u"\x2939")},
    {QStringLiteral("&larrsim;"), QString::fromUtf16(u"\x2973")},
    {QStringLiteral("&larrtl;"), QString::fromUtf16(u"\x21A2")},
    {QStringLiteral("&lat;"), QString::fromUtf16(u"\x2AAB")},
    {QStringLiteral("&latail;"), QString::fromUtf16(u"\x2919")},
    {QStringLiteral("&late;"), QString::fromUtf16(u"\x2AAD")},
    {QStringLiteral("&lates;"), QString::fromUtf16(u"\x2AAD\xFE00")},
    {QStringLiteral("&lbarr;"), QString::fromUtf16(u"\x290C")},
    {QStringLiteral("&lbbrk;"), QString::fromUtf16(u"\x2772")},
    {QStringLiteral("&lbrace;"), QString::fromUtf16(u"\x007B")},
    {QStringLiteral("&lbrack;"), QString::fromUtf16(u"\x005B")},
    {QStringLiteral("&lbrke;"), QString::fromUtf16(u"\x298B")},
    {QStringLiteral("&lbrksld;"), QString::fromUtf16(u"\x298F")},
    {QStringLiteral("&lbrkslu;"), QString::fromUtf16(u"\x298D")},
    {QStringLiteral("&lcaron;"), QString::fromUtf16(u"\x013E")},
    {QStringLiteral("&lcedil;"), QString::fromUtf16(u"\x013C")},
    {QStringLiteral("&lceil;"), QString::fromUtf16(u"\x2308")},
    {QStringLiteral("&lcub;"), QString::fromUtf16(u"\x007B")},
    {QStringLiteral("&lcy;"), QString::fromUtf16(u"\x043B")},
    {QStringLiteral("&ldca;"), QString::fromUtf16(u"\x2936")},
    {QStringLiteral("&ldquo;"), QString::fromUtf16(u"\x201C")},
    {QStringLiteral("&ldquor;"), QString::fromUtf16(u"\x201E")},
    {QStringLiteral("&ldrdhar;"), QString::fromUtf16(u"\x2967")},
    {QStringLiteral("&ldrushar;"), QString::fromUtf16(u"\x294B")},
    {QStringLiteral("&ldsh;"), QString::fromUtf16(u"\x21B2")},
    {QStringLiteral("&le;"), QString::fromUtf16(u"\x2264")},
    {QStringLiteral("&leftarrow;"), QString::fromUtf16(u"\x2190")},
    {QStringLiteral("&leftarrowtail;"), QString::fromUtf16(u"\x21A2")},
    {QStringLiteral("&leftharpoondown;"), QString::fromUtf16(u"\x21BD")},
    {QStringLiteral("&leftharpoonup;"), QString::fromUtf16(u"\x21BC")},
    {QStringLiteral("&leftleftarrows;"), QString::fromUtf16(u"\x21C7")},
    {QStringLiteral("&leftrightarrow;"), QString::fromUtf16(u"\x2194")},
    {QStringLiteral("&leftrightarrows;"), QString::fromUtf16(u"\x21C6")},
    {QStringLiteral("&leftrightharpoons;"), QString::fromUtf16(u"\x21CB")},
    {QStringLiteral("&leftrightsquigarrow;"), QString::fromUtf16(u"\x21AD")},
    {QStringLiteral("&leftthreetimes;"), QString::fromUtf16(u"\x22CB")},
    {QStringLiteral("&leg;"), QString::fromUtf16(u"\x22DA")},
    {QStringLiteral("&leq;"), QString::fromUtf16(u"\x2264")},
    {QStringLiteral("&leqq;"), QString::fromUtf16(u"\x2266")},
    {QStringLiteral("&leqslant;"), QString::fromUtf16(u"\x2A7D")},
    {QStringLiteral("&les;"), QString::fromUtf16(u"\x2A7D")},
    {QStringLiteral("&lescc;"), QString::fromUtf16(u"\x2AA8")},
    {QStringLiteral("&lesdot;"), QString::fromUtf16(u"\x2A7F")},
    {QStringLiteral("&lesdoto;"), QString::fromUtf16(u"\x2A81")},
    {QStringLiteral("&lesdotor;"), QString::fromUtf16(u"\x2A83")},
    {QStringLiteral("&lesg;"), QString::fromUtf16(u"\x22DA\xFE00")},
    {QStringLiteral("&lesges;"), QString::fromUtf16(u"\x2A93")},
    {QStringLiteral("&lessapprox;"), QString::fromUtf16(u"\x2A85")},
    {QStringLiteral("&lessdot;"), QString::fromUtf16(u"\x22D6")},
    {QStringLiteral("&lesseqgtr;"), QString::fromUtf16(u"\x22DA")},
    {QStringLiteral("&lesseqqgtr;"), QString::fromUtf16(u"\x2A8B")},
    {QStringLiteral("&lessgtr;"), QString::fromUtf16(u"\x2276")},
    {QStringLiteral("&lesssim;"), QString::fromUtf16(u"\x2272")},
    {QStringLiteral("&lfisht;"), QString::fromUtf16(u"\x297C")},
    {QStringLiteral("&lfloor;"), QString::fromUtf16(u"\x230A")},
    {QStringLiteral("&lfr;"), QString::fromUtf16(u"\xD835\xDD29")},
    {QStringLiteral("&lg;"), QString::fromUtf16(u"\x2276")},
    {QStringLiteral("&lgE;"), QString::fromUtf16(u"\x2A91")},
    {QStringLiteral("&lhard;"), QString::fromUtf16(u"\x21BD")},
    {QStringLiteral("&lharu;"), QString::fromUtf16(u"\x21BC")},
    {QStringLiteral("&lharul;"), QString::fromUtf16(u"\x296A")},
    {QStringLiteral("&lhblk;"), QString::fromUtf16(u"\x2584")},
    {QStringLiteral("&ljcy;"), QString::fromUtf16(u"\x0459")},
    {QStringLiteral("&ll;"), QString::fromUtf16(u"\x226A")},
    {QStringLiteral("&llarr;"), QString::fromUtf16(u"\x21C7")},
    {QStringLiteral("&llcorner;"), QString::fromUtf16(u"\x231E")},
    {QStringLiteral("&llhard;"), QString::fromUtf16(u"\x296B")},
    {QStringLiteral("&lltri;"), QString::fromUtf16(u"\x25FA")},
    {QStringLiteral("&lmidot;"), QString::fromUtf16(u"\x0140")},
    {QStringLiteral("&lmoust;"), QString::fromUtf16(u"\x23B0")},
    {QStringLiteral("&lmoustache;"), QString::fromUtf16(u"\x23B0")},
    {QStringLiteral("&lnE;"), QString::fromUtf16(u"\x2268")},
    {QStringLiteral("&lnap;"), QString::fromUtf16(u"\x2A89")},
    {QStringLiteral("&lnapprox;"), QString::fromUtf16(u"\x2A89")},
    {QStringLiteral("&lne;"), QString::fromUtf16(u"\x2A87")},
    {QStringLiteral("&lneq;"), QString::fromUtf16(u"\x2A87")},
    {QStringLiteral("&lneqq;"), QString::fromUtf16(u"\x2268")},
    {QStringLiteral("&lnsim;"), QString::fromUtf16(u"\x22E6")},
    {QStringLiteral("&loang;"), QString::fromUtf16(u"\x27EC")},
    {QStringLiteral("&loarr;"), QString::fromUtf16(u"\x21FD")},
    {QStringLiteral("&lobrk;"), QString::fromUtf16(u"\x27E6")},
    {QStringLiteral("&longleftarrow;"), QString::fromUtf16(u"\x27F5")},
    {QStringLiteral("&longleftrightarrow;"), QString::fromUtf16(u"\x27F7")},
    {QStringLiteral("&longmapsto;"), QString::fromUtf16(u"\x27FC")},
    {QStringLiteral("&longrightarrow;"), QString::fromUtf16(u"\x27F6")},
    {QStringLiteral("&looparrowleft;"), QString::fromUtf16(u"\x21AB")},
    {QStringLiteral("&looparrowright;"), QString::fromUtf16(u"\x21AC")},
    {QStringLiteral("&lopar;"), QString::fromUtf16(u"\x2985")},
    {QStringLiteral("&lopf;"), QString::fromUtf16(u"\xD835\xDD5D")},
    {QStringLiteral("&loplus;"), QString::fromUtf16(u"\x2A2D")},
    {QStringLiteral("&lotimes;"), QString::fromUtf16(u"\x2A34")},
    {QStringLiteral("&lowast;"), QString::fromUtf16(u"\x2217")},
    {QStringLiteral("&lowbar;"), QString::fromUtf16(u"\x005F")},
    {QStringLiteral("&loz;"), QString::fromUtf16(u"\x25CA")},
    {QStringLiteral("&lozenge;"), QString::fromUtf16(u"\x25CA")},
    {QStringLiteral("&lozf;"), QString::fromUtf16(u"\x29EB")},
    {QStringLiteral("&lpar;"), QString::fromUtf16(u"\x0028")},
    {QStringLiteral("&lparlt;"), QString::fromUtf16(u"\x2993")},
    {QStringLiteral("&lrarr;"), QString::fromUtf16(u"\x21C6")},
    {QStringLiteral("&lrcorner;"), QString::fromUtf16(u"\x231F")},
    {QStringLiteral("&lrhar;"), QString::fromUtf16(u"\x21CB")},
    {QStringLiteral("&lrhard;"), QString::fromUtf16(u"\x296D")},
    {QStringLiteral("&lrm;"), QString::fromUtf16(u"\x200E")},
    {QStringLiteral("&lrtri;"), QString::fromUtf16(u"\x22BF")},
    {QStringLiteral("&lsaquo;"), QString::fromUtf16(u"\x2039")},
    {QStringLiteral("&lscr;"), QString::fromUtf16(u"\xD835\xDCC1")},
    {QStringLiteral("&lsh;"), QString::fromUtf16(u"\x21B0")},
    {QStringLiteral("&lsim;"), QString::fromUtf16(u"\x2272")},
    {QStringLiteral("&lsime;"), QString::fromUtf16(u"\x2A8D")},
    {QStringLiteral("&lsimg;"), QString::fromUtf16(u"\x2A8F")},
    {QStringLiteral("&lsqb;"), QString::fromUtf16(u"\x005B")},
    {QStringLiteral("&lsquo;"), QString::fromUtf16(u"\x2018")},
    {QStringLiteral("&lsquor;"), QString::fromUtf16(u"\x201A")},
    {QStringLiteral("&lstrok;"), QString::fromUtf16(u"\x0142")},
    {QStringLiteral("&lt"), QString::fromUtf16(u"\x003C")},
    {QStringLiteral("&lt;"), QString::fromUtf16(u"\x003C")},
    {QStringLiteral("&ltcc;"), QString::fromUtf16(u"\x2AA6")},
    {QStringLiteral("&ltcir;"), QString::fromUtf16(u"\x2A79")},
    {QStringLiteral("&ltdot;"), QString::fromUtf16(u"\x22D6")},
    {QStringLiteral("&lthree;"), QString::fromUtf16(u"\x22CB")},
    {QStringLiteral("&ltimes;"), QString::fromUtf16(u"\x22C9")},
    {QStringLiteral("&ltlarr;"), QString::fromUtf16(u"\x2976")},
    {QStringLiteral("&ltquest;"), QString::fromUtf16(u"\x2A7B")},
    {QStringLiteral("&ltrPar;"), QString::fromUtf16(u"\x2996")},
    {QStringLiteral("&ltri;"), QString::fromUtf16(u"\x25C3")},
    {QStringLiteral("&ltrie;"), QString::fromUtf16(u"\x22B4")},
    {QStringLiteral("&ltrif;"), QString::fromUtf16(u"\x25C2")},
    {QStringLiteral("&lurdshar;"), QString::fromUtf16(u"\x294A")},
    {QStringLiteral("&luruhar;"), QString::fromUtf16(u"\x2966")},
    {QStringLiteral("&lvertneqq;"), QString::fromUtf16(u"\x2268\xFE00")},
    {QStringLiteral("&lvnE;"), QString::fromUtf16(u"\x2268\xFE00")},
    {QStringLiteral("&mDDot;"), QString::fromUtf16(u"\x223A")},
    {QStringLiteral("&macr"), QString::fromUtf16(u"\x00AF")},
    {QStringLiteral("&macr;"), QString::fromUtf16(u"\x00AF")},
    {QStringLiteral("&male;"), QString::fromUtf16(u"\x2642")},
    {QStringLiteral("&malt;"), QString::fromUtf16(u"\x2720")},
    {QStringLiteral("&maltese;"), QString::fromUtf16(u"\x2720")},
    {QStringLiteral("&map;"), QString::fromUtf16(u"\x21A6")},
    {QStringLiteral("&mapsto;"), QString::fromUtf16(u"\x21A6")},
    {QStringLiteral("&mapstodown;"), QString::fromUtf16(u"\x21A7")},
    {QStringLiteral("&mapstoleft;"), QString::fromUtf16(u"\x21A4")},
    {QStringLiteral("&mapstoup;"), QString::fromUtf16(u"\x21A5")},
    {QStringLiteral("&marker;"), QString::fromUtf16(u"\x25AE")},
    {QStringLiteral("&mcomma;"), QString::fromUtf16(u"\x2A29")},
    {QStringLiteral("&mcy;"), QString::fromUtf16(u"\x043C")},
    {QStringLiteral("&mdash;"), QString::fromUtf16(u"\x2014")},
    {QStringLiteral("&measuredangle;"), QString::fromUtf16(u"\x2221")},
    {QStringLiteral("&mfr;"), QString::fromUtf16(u"\xD835\xDD2A")},
    {QStringLiteral("&mho;"), QString::fromUtf16(u"\x2127")},
    {QStringLiteral("&micro"), QString::fromUtf16(u"\x00B5")},
    {QStringLiteral("&micro;"), QString::fromUtf16(u"\x00B5")},
    {QStringLiteral("&mid;"), QString::fromUtf16(u"\x2223")},
    {QStringLiteral("&midast;"), QString::fromUtf16(u"\x002A")},
    {QStringLiteral("&midcir;"), QString::fromUtf16(u"\x2AF0")},
    {QStringLiteral("&middot"), QString::fromUtf16(u"\x00B7")},
    {QStringLiteral("&middot;"), QString::fromUtf16(u"\x00B7")},
    {QStringLiteral("&minus;"), QString::fromUtf16(u"\x2212")},
    {QStringLiteral("&minusb;"), QString::fromUtf16(u"\x229F")},
    {QStringLiteral("&minusd;"), QString::fromUtf16(u"\x2238")},
    {QStringLiteral("&minusdu;"), QString::fromUtf16(u"\x2A2A")},
    {QStringLiteral("&mlcp;"), QString::fromUtf16(u"\x2ADB")},
    {QStringLiteral("&mldr;"), QString::fromUtf16(u"\x2026")},
    {QStringLiteral("&mnplus;"), QString::fromUtf16(u"\x2213")},
    {QStringLiteral("&models;"), QString::fromUtf16(u"\x22A7")},
    {QStringLiteral("&mopf;"), QString::fromUtf16(u"\xD835\xDD5E")},
    {QStringLiteral("&mp;"), QString::fromUtf16(u"\x2213")},
    {QStringLiteral("&mscr;"), QString::fromUtf16(u"\xD835\xDCC2")},
    {QStringLiteral("&mstpos;"), QString::fromUtf16(u"\x223E")},
    {QStringLiteral("&mu;"), QString::fromUtf16(u"\x03BC")},
    {QStringLiteral("&multimap;"), QString::fromUtf16(u"\x22B8")},
    {QStringLiteral("&mumap;"), QString::fromUtf16(u"\x22B8")},
    {QStringLiteral("&nGg;"), QString::fromUtf16(u"\x22D9\x0338")},
    {QStringLiteral("&nGt;"), QString::fromUtf16(u"\x226B\x20D2")},
    {QStringLiteral("&nGtv;"), QString::fromUtf16(u"\x226B\x0338")},
    {QStringLiteral("&nLeftarrow;"), QString::fromUtf16(u"\x21CD")},
    {QStringLiteral("&nLeftrightarrow;"), QString::fromUtf16(u"\x21CE")},
    {QStringLiteral("&nLl;"), QString::fromUtf16(u"\x22D8\x0338")},
    {QStringLiteral("&nLt;"), QString::fromUtf16(u"\x226A\x20D2")},
    {QStringLiteral("&nLtv;"), QString::fromUtf16(u"\x226A\x0338")},
    {QStringLiteral("&nRightarrow;"), QString::fromUtf16(u"\x21CF")},
    {QStringLiteral("&nVDash;"), QString::fromUtf16(u"\x22AF")},
    {QStringLiteral("&nVdash;"), QString::fromUtf16(u"\x22AE")},
    {QStringLiteral("&nabla;"), QString::fromUtf16(u"\x2207")},
    {QStringLiteral("&nacute;"), QString::fromUtf16(u"\x0144")},
    {QStringLiteral("&nang;"), QString::fromUtf16(u"\x2220\x20D2")},
    {QStringLiteral("&nap;"), QString::fromUtf16(u"\x2249")},
    {QStringLiteral("&napE;"), QString::fromUtf16(u"\x2A70\x0338")},
    {QStringLiteral("&napid;"), QString::fromUtf16(u"\x224B\x0338")},
    {QStringLiteral("&napos;"), QString::fromUtf16(u"\x0149")},
    {QStringLiteral("&napprox;"), QString::fromUtf16(u"\x2249")},
    {QStringLiteral("&natur;"), QString::fromUtf16(u"\x266E")},
    {QStringLiteral("&natural;"), QString::fromUtf16(u"\x266E")},
    {QStringLiteral("&naturals;"), QString::fromUtf16(u"\x2115")},
    {QStringLiteral("&nbsp"), QString::fromUtf16(u"\x00A0")},
    {QStringLiteral("&nbsp;"), QString::fromUtf16(u"\x00A0")},
    {QStringLiteral("&nbump;"), QString::fromUtf16(u"\x224E\x0338")},
    {QStringLiteral("&nbumpe;"), QString::fromUtf16(u"\x224F\x0338")},
    {QStringLiteral("&ncap;"), QString::fromUtf16(u"\x2A43")},
    {QStringLiteral("&ncaron;"), QString::fromUtf16(u"\x0148")},
    {QStringLiteral("&ncedil;"), QString::fromUtf16(u"\x0146")},
    {QStringLiteral("&ncong;"), QString::fromUtf16(u"\x2247")},
    {QStringLiteral("&ncongdot;"), QString::fromUtf16(u"\x2A6D\x0338")},
    {QStringLiteral("&ncup;"), QString::fromUtf16(u"\x2A42")},
    {QStringLiteral("&ncy;"), QString::fromUtf16(u"\x043D")},
    {QStringLiteral("&ndash;"), QString::fromUtf16(u"\x2013")},
    {QStringLiteral("&ne;"), QString::fromUtf16(u"\x2260")},
    {QStringLiteral("&neArr;"), QString::fromUtf16(u"\x21D7")},
    {QStringLiteral("&nearhk;"), QString::fromUtf16(u"\x2924")},
    {QStringLiteral("&nearr;"), QString::fromUtf16(u"\x2197")},
    {QStringLiteral("&nearrow;"), QString::fromUtf16(u"\x2197")},
    {QStringLiteral("&nedot;"), QString::fromUtf16(u"\x2250\x0338")},
    {QStringLiteral("&nequiv;"), QString::fromUtf16(u"\x2262")},
    {QStringLiteral("&nesear;"), QString::fromUtf16(u"\x2928")},
    {QStringLiteral("&nesim;"), QString::fromUtf16(u"\x2242\x0338")},
    {QStringLiteral("&nexist;"), QString::fromUtf16(u"\x2204")},
    {QStringLiteral("&nexists;"), QString::fromUtf16(u"\x2204")},
    {QStringLiteral("&nfr;"), QString::fromUtf16(u"\xD835\xDD2B")},
    {QStringLiteral("&ngE;"), QString::fromUtf16(u"\x2267\x0338")},
    {QStringLiteral("&nge;"), QString::fromUtf16(u"\x2271")},
    {QStringLiteral("&ngeq;"), QString::fromUtf16(u"\x2271")},
    {QStringLiteral("&ngeqq;"), QString::fromUtf16(u"\x2267\x0338")},
    {QStringLiteral("&ngeqslant;"), QString::fromUtf16(u"\x2A7E\x0338")},
    {QStringLiteral("&nges;"), QString::fromUtf16(u"\x2A7E\x0338")},
    {QStringLiteral("&ngsim;"), QString::fromUtf16(u"\x2275")},
    {QStringLiteral("&ngt;"), QString::fromUtf16(u"\x226F")},
    {QStringLiteral("&ngtr;"), QString::fromUtf16(u"\x226F")},
    {QStringLiteral("&nhArr;"), QString::fromUtf16(u"\x21CE")},
    {QStringLiteral("&nharr;"), QString::fromUtf16(u"\x21AE")},
    {QStringLiteral("&nhpar;"), QString::fromUtf16(u"\x2AF2")},
    {QStringLiteral("&ni;"), QString::fromUtf16(u"\x220B")},
    {QStringLiteral("&nis;"), QString::fromUtf16(u"\x22FC")},
    {QStringLiteral("&nisd;"), QString::fromUtf16(u"\x22FA")},
    {QStringLiteral("&niv;"), QString::fromUtf16(u"\x220B")},
    {QStringLiteral("&njcy;"), QString::fromUtf16(u"\x045A")},
    {QStringLiteral("&nlArr;"), QString::fromUtf16(u"\x21CD")},
    {QStringLiteral("&nlE;"), QString::fromUtf16(u"\x2266\x0338")},
    {QStringLiteral("&nlarr;"), QString::fromUtf16(u"\x219A")},
    {QStringLiteral("&nldr;"), QString::fromUtf16(u"\x2025")},
    {QStringLiteral("&nle;"), QString::fromUtf16(u"\x2270")},
    {QStringLiteral("&nleftarrow;"), QString::fromUtf16(u"\x219A")},
    {QStringLiteral("&nleftrightarrow;"), QString::fromUtf16(u"\x21AE")},
    {QStringLiteral("&nleq;"), QString::fromUtf16(u"\x2270")},
    {QStringLiteral("&nleqq;"), QString::fromUtf16(u"\x2266\x0338")},
    {QStringLiteral("&nleqslant;"), QString::fromUtf16(u"\x2A7D\x0338")},
    {QStringLiteral("&nles;"), QString::fromUtf16(u"\x2A7D\x0338")},
    {QStringLiteral("&nless;"), QString::fromUtf16(u"\x226E")},
    {QStringLiteral("&nlsim;"), QString::fromUtf16(u"\x2274")},
    {QStringLiteral("&nlt;"), QString::fromUtf16(u"\x226E")},
    {QStringLiteral("&nltri;"), QString::fromUtf16(u"\x22EA")},
    {QStringLiteral("&nltrie;"), QString::fromUtf16(u"\x22EC")},
    {QStringLiteral("&nmid;"), QString::fromUtf16(u"\x2224")},
    {QStringLiteral("&nopf;"), QString::fromUtf16(u"\xD835\xDD5F")},
    {QStringLiteral("&not"), QString::fromUtf16(u"\x00AC")},
    {QStringLiteral("&not;"), QString::fromUtf16(u"\x00AC")},
    {QStringLiteral("&notin;"), QString::fromUtf16(u"\x2209")},
    {QStringLiteral("&notinE;"), QString::fromUtf16(u"\x22F9\x0338")},
    {QStringLiteral("&notindot;"), QString::fromUtf16(u"\x22F5\x0338")},
    {QStringLiteral("&notinva;"), QString::fromUtf16(u"\x2209")},
    {QStringLiteral("&notinvb;"), QString::fromUtf16(u"\x22F7")},
    {QStringLiteral("&notinvc;"), QString::fromUtf16(u"\x22F6")},
    {QStringLiteral("&notni;"), QString::fromUtf16(u"\x220C")},
    {QStringLiteral("&notniva;"), QString::fromUtf16(u"\x220C")},
    {QStringLiteral("&notnivb;"), QString::fromUtf16(u"\x22FE")},
    {QStringLiteral("&notnivc;"), QString::fromUtf16(u"\x22FD")},
    {QStringLiteral("&npar;"), QString::fromUtf16(u"\x2226")},
    {QStringLiteral("&nparallel;"), QString::fromUtf16(u"\x2226")},
    {QStringLiteral("&nparsl;"), QString::fromUtf16(u"\x2AFD\x20E5")},
    {QStringLiteral("&npart;"), QString::fromUtf16(u"\x2202\x0338")},
    {QStringLiteral("&npolint;"), QString::fromUtf16(u"\x2A14")},
    {QStringLiteral("&npr;"), QString::fromUtf16(u"\x2280")},
    {QStringLiteral("&nprcue;"), QString::fromUtf16(u"\x22E0")},
    {QStringLiteral("&npre;"), QString::fromUtf16(u"\x2AAF\x0338")},
    {QStringLiteral("&nprec;"), QString::fromUtf16(u"\x2280")},
    {QStringLiteral("&npreceq;"), QString::fromUtf16(u"\x2AAF\x0338")},
    {QStringLiteral("&nrArr;"), QString::fromUtf16(u"\x21CF")},
    {QStringLiteral("&nrarr;"), QString::fromUtf16(u"\x219B")},
    {QStringLiteral("&nrarrc;"), QString::fromUtf16(u"\x2933\x0338")},
    {QStringLiteral("&nrarrw;"), QString::fromUtf16(u"\x219D\x0338")},
    {QStringLiteral("&nrightarrow;"), QString::fromUtf16(u"\x219B")},
    {QStringLiteral("&nrtri;"), QString::fromUtf16(u"\x22EB")},
    {QStringLiteral("&nrtrie;"), QString::fromUtf16(u"\x22ED")},
    {QStringLiteral("&nsc;"), QString::fromUtf16(u"\x2281")},
    {QStringLiteral("&nsccue;"), QString::fromUtf16(u"\x22E1")},
    {QStringLiteral("&nsce;"), QString::fromUtf16(u"\x2AB0\x0338")},
    {QStringLiteral("&nscr;"), QString::fromUtf16(u"\xD835\xDCC3")},
    {QStringLiteral("&nshortmid;"), QString::fromUtf16(u"\x2224")},
    {QStringLiteral("&nshortparallel;"), QString::fromUtf16(u"\x2226")},
    {QStringLiteral("&nsim;"), QString::fromUtf16(u"\x2241")},
    {QStringLiteral("&nsime;"), QString::fromUtf16(u"\x2244")},
    {QStringLiteral("&nsimeq;"), QString::fromUtf16(u"\x2244")},
    {QStringLiteral("&nsmid;"), QString::fromUtf16(u"\x2224")},
    {QStringLiteral("&nspar;"), QString::fromUtf16(u"\x2226")},
    {QStringLiteral("&nsqsube;"), QString::fromUtf16(u"\x22E2")},
    {QStringLiteral("&nsqsupe;"), QString::fromUtf16(u"\x22E3")},
    {QStringLiteral("&nsub;"), QString::fromUtf16(u"\x2284")},
    {QStringLiteral("&nsubE;"), QString::fromUtf16(u"\x2AC5\x0338")},
    {QStringLiteral("&nsube;"), QString::fromUtf16(u"\x2288")},
    {QStringLiteral("&nsubset;"), QString::fromUtf16(u"\x2282\x20D2")},
    {QStringLiteral("&nsubseteq;"), QString::fromUtf16(u"\x2288")},
    {QStringLiteral("&nsubseteqq;"), QString::fromUtf16(u"\x2AC5\x0338")},
    {QStringLiteral("&nsucc;"), QString::fromUtf16(u"\x2281")},
    {QStringLiteral("&nsucceq;"), QString::fromUtf16(u"\x2AB0\x0338")},
    {QStringLiteral("&nsup;"), QString::fromUtf16(u"\x2285")},
    {QStringLiteral("&nsupE;"), QString::fromUtf16(u"\x2AC6\x0338")},
    {QStringLiteral("&nsupe;"), QString::fromUtf16(u"\x2289")},
    {QStringLiteral("&nsupset;"), QString::fromUtf16(u"\x2283\x20D2")},
    {QStringLiteral("&nsupseteq;"), QString::fromUtf16(u"\x2289")},
    {QStringLiteral("&nsupseteqq;"), QString::fromUtf16(u"\x2AC6\x0338")},
    {QStringLiteral("&ntgl;"), QString::fromUtf16(u"\x2279")},
    {QStringLiteral("&ntilde"), QString::fromUtf16(u"\x00F1")},
    {QStringLiteral("&ntilde;"), QString::fromUtf16(u"\x00F1")},
    {QStringLiteral("&ntlg;"), QString::fromUtf16(u"\x2278")},
    {QStringLiteral("&ntriangleleft;"), QString::fromUtf16(u"\x22EA")},
    {QStringLiteral("&ntrianglelefteq;"), QString::fromUtf16(u"\x22EC")},
    {QStringLiteral("&ntriangleright;"), QString::fromUtf16(u"\x22EB")},
    {QStringLiteral("&ntrianglerighteq;"), QString::fromUtf16(u"\x22ED")},
    {QStringLiteral("&nu;"), QString::fromUtf16(u"\x03BD")},
    {QStringLiteral("&num;"), QString::fromUtf16(u"\x0023")},
    {QStringLiteral("&numero;"), QString::fromUtf16(u"\x2116")},
    {QStringLiteral("&numsp;"), QString::fromUtf16(u"\x2007")},
    {QStringLiteral("&nvDash;"), QString::fromUtf16(u"\x22AD")},
    {QStringLiteral("&nvHarr;"), QString::fromUtf16(u"\x2904")},
    {QStringLiteral("&nvap;"), QString::fromUtf16(u"\x224D\x20D2")},
    {QStringLiteral("&nvdash;"), QString::fromUtf16(u"\x22AC")},
    {QStringLiteral("&nvge;"), QString::fromUtf16(u"\x2265\x20D2")},
    {QStringLiteral("&nvgt;"), QString::fromUtf16(u"\x003E\x20D2")},
    {QStringLiteral("&nvinfin;"), QString::fromUtf16(u"\x29DE")},
    {QStringLiteral("&nvlArr;"), QString::fromUtf16(u"\x2902")},
    {QStringLiteral("&nvle;"), QString::fromUtf16(u"\x2264\x20D2")},
    {QStringLiteral("&nvlt;"), QString::fromUtf16(u"\x003C\x20D2")},
    {QStringLiteral("&nvltrie;"), QString::fromUtf16(u"\x22B4\x20D2")},
    {QStringLiteral("&nvrArr;"), QString::fromUtf16(u"\x2903")},
    {QStringLiteral("&nvrtrie;"), QString::fromUtf16(u"\x22B5\x20D2")},
    {QStringLiteral("&nvsim;"), QString::fromUtf16(u"\x223C\x20D2")},
    {QStringLiteral("&nwArr;"), QString::fromUtf16(u"\x21D6")},
    {QStringLiteral("&nwarhk;"), QString::fromUtf16(u"\x2923")},
    {QStringLiteral("&nwarr;"), QString::fromUtf16(u"\x2196")},
    {QStringLiteral("&nwarrow;"), QString::fromUtf16(u"\x2196")},
    {QStringLiteral("&nwnear;"), QString::fromUtf16(u"\x2927")},
    {QStringLiteral("&oS;"), QString::fromUtf16(u"\x24C8")},
    {QStringLiteral("&oacute"), QString::fromUtf16(u"\x00F3")},
    {QStringLiteral("&oacute;"), QString::fromUtf16(u"\x00F3")},
    {QStringLiteral("&oast;"), QString::fromUtf16(u"\x229B")},
    {QStringLiteral("&ocir;"), QString::fromUtf16(u"\x229A")},
    {QStringLiteral("&ocirc"), QString::fromUtf16(u"\x00F4")},
    {QStringLiteral("&ocirc;"), QString::fromUtf16(u"\x00F4")},
    {QStringLiteral("&ocy;"), QString::fromUtf16(u"\x043E")},
    {QStringLiteral("&odash;"), QString::fromUtf16(u"\x229D")},
    {QStringLiteral("&odblac;"), QString::fromUtf16(u"\x0151")},
    {QStringLiteral("&odiv;"), QString::fromUtf16(u"\x2A38")},
    {QStringLiteral("&odot;"), QString::fromUtf16(u"\x2299")},
    {QStringLiteral("&odsold;"), QString::fromUtf16(u"\x29BC")},
    {QStringLiteral("&oelig;"), QString::fromUtf16(u"\x0153")},
    {QStringLiteral("&ofcir;"), QString::fromUtf16(u"\x29BF")},
    {QStringLiteral("&ofr;"), QString::fromUtf16(u"\xD835\xDD2C")},
    {QStringLiteral("&ogon;"), QString::fromUtf16(u"\x02DB")},
    {QStringLiteral("&ograve"), QString::fromUtf16(u"\x00F2")},
    {QStringLiteral("&ograve;"), QString::fromUtf16(u"\x00F2")},
    {QStringLiteral("&ogt;"), QString::fromUtf16(u"\x29C1")},
    {QStringLiteral("&ohbar;"), QString::fromUtf16(u"\x29B5")},
    {QStringLiteral("&ohm;"), QString::fromUtf16(u"\x03A9")},
    {QStringLiteral("&oint;"), QString::fromUtf16(u"\x222E")},
    {QStringLiteral("&olarr;"), QString::fromUtf16(u"\x21BA")},
    {QStringLiteral("&olcir;"), QString::fromUtf16(u"\x29BE")},
    {QStringLiteral("&olcross;"), QString::fromUtf16(u"\x29BB")},
    {QStringLiteral("&oline;"), QString::fromUtf16(u"\x203E")},
    {QStringLiteral("&olt;"), QString::fromUtf16(u"\x29C0")},
    {QStringLiteral("&omacr;"), QString::fromUtf16(u"\x014D")},
    {QStringLiteral("&omega;"), QString::fromUtf16(u"\x03C9")},
    {QStringLiteral("&omicron;"), QString::fromUtf16(u"\x03BF")},
    {QStringLiteral("&omid;"), QString::fromUtf16(u"\x29B6")},
    {QStringLiteral("&ominus;"), QString::fromUtf16(u"\x2296")},
    {QStringLiteral("&oopf;"), QString::fromUtf16(u"\xD835\xDD60")},
    {QStringLiteral("&opar;"), QString::fromUtf16(u"\x29B7")},
    {QStringLiteral("&operp;"), QString::fromUtf16(u"\x29B9")},
    {QStringLiteral("&oplus;"), QString::fromUtf16(u"\x2295")},
    {QStringLiteral("&or;"), QString::fromUtf16(u"\x2228")},
    {QStringLiteral("&orarr;"), QString::fromUtf16(u"\x21BB")},
    {QStringLiteral("&ord;"), QString::fromUtf16(u"\x2A5D")},
    {QStringLiteral("&order;"), QString::fromUtf16(u"\x2134")},
    {QStringLiteral("&orderof;"), QString::fromUtf16(u"\x2134")},
    {QStringLiteral("&ordf"), QString::fromUtf16(u"\x00AA")},
    {QStringLiteral("&ordf;"), QString::fromUtf16(u"\x00AA")},
    {QStringLiteral("&ordm"), QString::fromUtf16(u"\x00BA")},
    {QStringLiteral("&ordm;"), QString::fromUtf16(u"\x00BA")},
    {QStringLiteral("&origof;"), QString::fromUtf16(u"\x22B6")},
    {QStringLiteral("&oror;"), QString::fromUtf16(u"\x2A56")},
    {QStringLiteral("&orslope;"), QString::fromUtf16(u"\x2A57")},
    {QStringLiteral("&orv;"), QString::fromUtf16(u"\x2A5B")},
    {QStringLiteral("&oscr;"), QString::fromUtf16(u"\x2134")},
    {QStringLiteral("&oslash"), QString::fromUtf16(u"\x00F8")},
    {QStringLiteral("&oslash;"), QString::fromUtf16(u"\x00F8")},
    {QStringLiteral("&osol;"), QString::fromUtf16(u"\x2298")},
    {QStringLiteral("&otilde"), QString::fromUtf16(u"\x00F5")},
    {QStringLiteral("&otilde;"), QString::fromUtf16(u"\x00F5")},
    {QStringLiteral("&otimes;"), QString::fromUtf16(u"\x2297")},
    {QStringLiteral("&otimesas;"), QString::fromUtf16(u"\x2A36")},
    {QStringLiteral("&ouml"), QString::fromUtf16(u"\x00F6")},
    {QStringLiteral("&ouml;"), QString::fromUtf16(u"\x00F6")},
    {QStringLiteral("&ovbar;"), QString::fromUtf16(u"\x233D")},
    {QStringLiteral("&par;"), QString::fromUtf16(u"\x2225")},
    {QStringLiteral("&para"), QString::fromUtf16(u"\x00B6")},
    {QStringLiteral("&para;"), QString::fromUtf16(u"\x00B6")},
    {QStringLiteral("&parallel;"), QString::fromUtf16(u"\x2225")},
    {QStringLiteral("&parsim;"), QString::fromUtf16(u"\x2AF3")},
    {QStringLiteral("&parsl;"), QString::fromUtf16(u"\x2AFD")},
    {QStringLiteral("&part;"), QString::fromUtf16(u"\x2202")},
    {QStringLiteral("&pcy;"), QString::fromUtf16(u"\x043F")},
    {QStringLiteral("&percnt;"), QString::fromUtf16(u"\x0025")},
    {QStringLiteral("&period;"), QString::fromUtf16(u"\x002E")},
    {QStringLiteral("&permil;"), QString::fromUtf16(u"\x2030")},
    {QStringLiteral("&perp;"), QString::fromUtf16(u"\x22A5")},
    {QStringLiteral("&pertenk;"), QString::fromUtf16(u"\x2031")},
    {QStringLiteral("&pfr;"), QString::fromUtf16(u"\xD835\xDD2D")},
    {QStringLiteral("&phi;"), QString::fromUtf16(u"\x03C6")},
    {QStringLiteral("&phiv;"), QString::fromUtf16(u"\x03D5")},
    {QStringLiteral("&phmmat;"), QString::fromUtf16(u"\x2133")},
    {QStringLiteral("&phone;"), QString::fromUtf16(u"\x260E")},
    {QStringLiteral("&pi;"), QString::fromUtf16(u"\x03C0")},
    {QStringLiteral("&pitchfork;"), QString::fromUtf16(u"\x22D4")},
    {QStringLiteral("&piv;"), QString::fromUtf16(u"\x03D6")},
    {QStringLiteral("&planck;"), QString::fromUtf16(u"\x210F")},
    {QStringLiteral("&planckh;"), QString::fromUtf16(u"\x210E")},
    {QStringLiteral("&plankv;"), QString::fromUtf16(u"\x210F")},
    {QStringLiteral("&plus;"), QString::fromUtf16(u"\x002B")},
    {QStringLiteral("&plusacir;"), QString::fromUtf16(u"\x2A23")},
    {QStringLiteral("&plusb;"), QString::fromUtf16(u"\x229E")},
    {QStringLiteral("&pluscir;"), QString::fromUtf16(u"\x2A22")},
    {QStringLiteral("&plusdo;"), QString::fromUtf16(u"\x2214")},
    {QStringLiteral("&plusdu;"), QString::fromUtf16(u"\x2A25")},
    {QStringLiteral("&pluse;"), QString::fromUtf16(u"\x2A72")},
    {QStringLiteral("&plusmn"), QString::fromUtf16(u"\x00B1")},
    {QStringLiteral("&plusmn;"), QString::fromUtf16(u"\x00B1")},
    {QStringLiteral("&plussim;"), QString::fromUtf16(u"\x2A26")},
    {QStringLiteral("&plustwo;"), QString::fromUtf16(u"\x2A27")},
    {QStringLiteral("&pm;"), QString::fromUtf16(u"\x00B1")},
    {QStringLiteral("&pointint;"), QString::fromUtf16(u"\x2A15")},
    {QStringLiteral("&popf;"), QString::fromUtf16(u"\xD835\xDD61")},
    {QStringLiteral("&pound"), QString::fromUtf16(u"\x00A3")},
    {QStringLiteral("&pound;"), QString::fromUtf16(u"\x00A3")},
    {QStringLiteral("&pr;"), QString::fromUtf16(u"\x227A")},
    {QStringLiteral("&prE;"), QString::fromUtf16(u"\x2AB3")},
    {QStringLiteral("&prap;"), QString::fromUtf16(u"\x2AB7")},
    {QStringLiteral("&prcue;"), QString::fromUtf16(u"\x227C")},
    {QStringLiteral("&pre;"), QString::fromUtf16(u"\x2AAF")},
    {QStringLiteral("&prec;"), QString::fromUtf16(u"\x227A")},
    {QStringLiteral("&precapprox;"), QString::fromUtf16(u"\x2AB7")},
    {QStringLiteral("&preccurlyeq;"), QString::fromUtf16(u"\x227C")},
    {QStringLiteral("&preceq;"), QString::fromUtf16(u"\x2AAF")},
    {QStringLiteral("&precnapprox;"), QString::fromUtf16(u"\x2AB9")},
    {QStringLiteral("&precneqq;"), QString::fromUtf16(u"\x2AB5")},
    {QStringLiteral("&precnsim;"), QString::fromUtf16(u"\x22E8")},
    {QStringLiteral("&precsim;"), QString::fromUtf16(u"\x227E")},
    {QStringLiteral("&prime;"), QString::fromUtf16(u"\x2032")},
    {QStringLiteral("&primes;"), QString::fromUtf16(u"\x2119")},
    {QStringLiteral("&prnE;"), QString::fromUtf16(u"\x2AB5")},
    {QStringLiteral("&prnap;"), QString::fromUtf16(u"\x2AB9")},
    {QStringLiteral("&prnsim;"), QString::fromUtf16(u"\x22E8")},
    {QStringLiteral("&prod;"), QString::fromUtf16(u"\x220F")},
    {QStringLiteral("&profalar;"), QString::fromUtf16(u"\x232E")},
    {QStringLiteral("&profline;"), QString::fromUtf16(u"\x2312")},
    {QStringLiteral("&profsurf;"), QString::fromUtf16(u"\x2313")},
    {QStringLiteral("&prop;"), QString::fromUtf16(u"\x221D")},
    {QStringLiteral("&propto;"), QString::fromUtf16(u"\x221D")},
    {QStringLiteral("&prsim;"), QString::fromUtf16(u"\x227E")},
    {QStringLiteral("&prurel;"), QString::fromUtf16(u"\x22B0")},
    {QStringLiteral("&pscr;"), QString::fromUtf16(u"\xD835\xDCC5")},
    {QStringLiteral("&psi;"), QString::fromUtf16(u"\x03C8")},
    {QStringLiteral("&puncsp;"), QString::fromUtf16(u"\x2008")},
    {QStringLiteral("&qfr;"), QString::fromUtf16(u"\xD835\xDD2E")},
    {QStringLiteral("&qint;"), QString::fromUtf16(u"\x2A0C")},
    {QStringLiteral("&qopf;"), QString::fromUtf16(u"\xD835\xDD62")},
    {QStringLiteral("&qprime;"), QString::fromUtf16(u"\x2057")},
    {QStringLiteral("&qscr;"), QString::fromUtf16(u"\xD835\xDCC6")},
    {QStringLiteral("&quaternions;"), QString::fromUtf16(u"\x210D")},
    {QStringLiteral("&quatint;"), QString::fromUtf16(u"\x2A16")},
    {QStringLiteral("&quest;"), QString::fromUtf16(u"\x003F")},
    {QStringLiteral("&questeq;"), QString::fromUtf16(u"\x225F")},
    {QStringLiteral("&quot"), QString::fromUtf16(u"\x0022")},
    {QStringLiteral("&quot;"), QString::fromUtf16(u"\x0022")},
    {QStringLiteral("&rAarr;"), QString::fromUtf16(u"\x21DB")},
    {QStringLiteral("&rArr;"), QString::fromUtf16(u"\x21D2")},
    {QStringLiteral("&rAtail;"), QString::fromUtf16(u"\x291C")},
    {QStringLiteral("&rBarr;"), QString::fromUtf16(u"\x290F")},
    {QStringLiteral("&rHar;"), QString::fromUtf16(u"\x2964")},
    {QStringLiteral("&race;"), QString::fromUtf16(u"\x223D\x0331")},
    {QStringLiteral("&racute;"), QString::fromUtf16(u"\x0155")},
    {QStringLiteral("&radic;"), QString::fromUtf16(u"\x221A")},
    {QStringLiteral("&raemptyv;"), QString::fromUtf16(u"\x29B3")},
    {QStringLiteral("&rang;"), QString::fromUtf16(u"\x27E9")},
    {QStringLiteral("&rangd;"), QString::fromUtf16(u"\x2992")},
    {QStringLiteral("&range;"), QString::fromUtf16(u"\x29A5")},
    {QStringLiteral("&rangle;"), QString::fromUtf16(u"\x27E9")},
    {QStringLiteral("&raquo"), QString::fromUtf16(u"\x00BB")},
    {QStringLiteral("&raquo;"), QString::fromUtf16(u"\x00BB")},
    {QStringLiteral("&rarr;"), QString::fromUtf16(u"\x2192")},
    {QStringLiteral("&rarrap;"), QString::fromUtf16(u"\x2975")},
    {QStringLiteral("&rarrb;"), QString::fromUtf16(u"\x21E5")},
    {QStringLiteral("&rarrbfs;"), QString::fromUtf16(u"\x2920")},
    {QStringLiteral("&rarrc;"), QString::fromUtf16(u"\x2933")},
    {QStringLiteral("&rarrfs;"), QString::fromUtf16(u"\x291E")},
    {QStringLiteral("&rarrhk;"), QString::fromUtf16(u"\x21AA")},
    {QStringLiteral("&rarrlp;"), QString::fromUtf16(u"\x21AC")},
    {QStringLiteral("&rarrpl;"), QString::fromUtf16(u"\x2945")},
    {QStringLiteral("&rarrsim;"), QString::fromUtf16(u"\x2974")},
    {QStringLiteral("&rarrtl;"), QString::fromUtf16(u"\x21A3")},
    {QStringLiteral("&rarrw;"), QString::fromUtf16(u"\x219D")},
    {QStringLiteral("&ratail;"), QString::fromUtf16(u"\x291A")},
    {QStringLiteral("&ratio;"), QString::fromUtf16(u"\x2236")},
    {QStringLiteral("&rationals;"), QString::fromUtf16(u"\x211A")},
    {QStringLiteral("&rbarr;"), QString::fromUtf16(u"\x290D")},
    {QStringLiteral("&rbbrk;"), QString::fromUtf16(u"\x2773")},
    {QStringLiteral("&rbrace;"), QString::fromUtf16(u"\x007D")},
    {QStringLiteral("&rbrack;"), QString::fromUtf16(u"\x005D")},
    {QStringLiteral("&rbrke;"), QString::fromUtf16(u"\x298C")},
    {QStringLiteral("&rbrksld;"), QString::fromUtf16(u"\x298E")},
    {QStringLiteral("&rbrkslu;"), QString::fromUtf16(u"\x2990")},
    {QStringLiteral("&rcaron;"), QString::fromUtf16(u"\x0159")},
    {QStringLiteral("&rcedil;"), QString::fromUtf16(u"\x0157")},
    {QStringLiteral("&rceil;"), QString::fromUtf16(u"\x2309")},
    {QStringLiteral("&rcub;"), QString::fromUtf16(u"\x007D")},
    {QStringLiteral("&rcy;"), QString::fromUtf16(u"\x0440")},
    {QStringLiteral("&rdca;"), QString::fromUtf16(u"\x2937")},
    {QStringLiteral("&rdldhar;"), QString::fromUtf16(u"\x2969")},
    {QStringLiteral("&rdquo;"), QString::fromUtf16(u"\x201D")},
    {QStringLiteral("&rdquor;"), QString::fromUtf16(u"\x201D")},
    {QStringLiteral("&rdsh;"), QString::fromUtf16(u"\x21B3")},
    {QStringLiteral("&real;"), QString::fromUtf16(u"\x211C")},
    {QStringLiteral("&realine;"), QString::fromUtf16(u"\x211B")},
    {QStringLiteral("&realpart;"), QString::fromUtf16(u"\x211C")},
    {QStringLiteral("&reals;"), QString::fromUtf16(u"\x211D")},
    {QStringLiteral("&rect;"), QString::fromUtf16(u"\x25AD")},
    {QStringLiteral("&reg"), QString::fromUtf16(u"\x00AE")},
    {QStringLiteral("&reg;"), QString::fromUtf16(u"\x00AE")},
    {QStringLiteral("&rfisht;"), QString::fromUtf16(u"\x297D")},
    {QStringLiteral("&rfloor;"), QString::fromUtf16(u"\x230B")},
    {QStringLiteral("&rfr;"), QString::fromUtf16(u"\xD835\xDD2F")},
    {QStringLiteral("&rhard;"), QString::fromUtf16(u"\x21C1")},
    {QStringLiteral("&rharu;"), QString::fromUtf16(u"\x21C0")},
    {QStringLiteral("&rharul;"), QString::fromUtf16(u"\x296C")},
    {QStringLiteral("&rho;"), QString::fromUtf16(u"\x03C1")},
    {QStringLiteral("&rhov;"), QString::fromUtf16(u"\x03F1")},
    {QStringLiteral("&rightarrow;"), QString::fromUtf16(u"\x2192")},
    {QStringLiteral("&rightarrowtail;"), QString::fromUtf16(u"\x21A3")},
    {QStringLiteral("&rightharpoondown;"), QString::fromUtf16(u"\x21C1")},
    {QStringLiteral("&rightharpoonup;"), QString::fromUtf16(u"\x21C0")},
    {QStringLiteral("&rightleftarrows;"), QString::fromUtf16(u"\x21C4")},
    {QStringLiteral("&rightleftharpoons;"), QString::fromUtf16(u"\x21CC")},
    {QStringLiteral("&rightrightarrows;"), QString::fromUtf16(u"\x21C9")},
    {QStringLiteral("&rightsquigarrow;"), QString::fromUtf16(u"\x219D")},
    {QStringLiteral("&rightthreetimes;"), QString::fromUtf16(u"\x22CC")},
    {QStringLiteral("&ring;"), QString::fromUtf16(u"\x02DA")},
    {QStringLiteral("&risingdotseq;"), QString::fromUtf16(u"\x2253")},
    {QStringLiteral("&rlarr;"), QString::fromUtf16(u"\x21C4")},
    {QStringLiteral("&rlhar;"), QString::fromUtf16(u"\x21CC")},
    {QStringLiteral("&rlm;"), QString::fromUtf16(u"\x200F")},
    {QStringLiteral("&rmoust;"), QString::fromUtf16(u"\x23B1")},
    {QStringLiteral("&rmoustache;"), QString::fromUtf16(u"\x23B1")},
    {QStringLiteral("&rnmid;"), QString::fromUtf16(u"\x2AEE")},
    {QStringLiteral("&roang;"), QString::fromUtf16(u"\x27ED")},
    {QStringLiteral("&roarr;"), QString::fromUtf16(u"\x21FE")},
    {QStringLiteral("&robrk;"), QString::fromUtf16(u"\x27E7")},
    {QStringLiteral("&ropar;"), QString::fromUtf16(u"\x2986")},
    {QStringLiteral("&ropf;"), QString::fromUtf16(u"\xD835\xDD63")},
    {QStringLiteral("&roplus;"), QString::fromUtf16(u"\x2A2E")},
    {QStringLiteral("&rotimes;"), QString::fromUtf16(u"\x2A35")},
    {QStringLiteral("&rpar;"), QString::fromUtf16(u"\x0029")},
    {QStringLiteral("&rpargt;"), QString::fromUtf16(u"\x2994")},
    {QStringLiteral("&rppolint;"), QString::fromUtf16(u"\x2A12")},
    {QStringLiteral("&rrarr;"), QString::fromUtf16(u"\x21C9")},
    {QStringLiteral("&rsaquo;"), QString::fromUtf16(u"\x203A")},
    {QStringLiteral("&rscr;"), QString::fromUtf16(u"\xD835\xDCC7")},
    {QStringLiteral("&rsh;"), QString::fromUtf16(u"\x21B1")},
    {QStringLiteral("&rsqb;"), QString::fromUtf16(u"\x005D")},
    {QStringLiteral("&rsquo;"), QString::fromUtf16(u"\x2019")},
    {QStringLiteral("&rsquor;"), QString::fromUtf16(u"\x2019")},
    {QStringLiteral("&rthree;"), QString::fromUtf16(u"\x22CC")},
    {QStringLiteral("&rtimes;"), QString::fromUtf16(u"\x22CA")},
    {QStringLiteral("&rtri;"), QString::fromUtf16(u"\x25B9")},
    {QStringLiteral("&rtrie;"), QString::fromUtf16(u"\x22B5")},
    {QStringLiteral("&rtrif;"), QString::fromUtf16(u"\x25B8")},
    {QStringLiteral("&rtriltri;"), QString::fromUtf16(u"\x29CE")},
    {QStringLiteral("&ruluhar;"), QString::fromUtf16(u"\x2968")},
    {QStringLiteral("&rx;"), QString::fromUtf16(u"\x211E")},
    {QStringLiteral("&sacute;"), QString::fromUtf16(u"\x015B")},
    {QStringLiteral("&sbquo;"), QString::fromUtf16(u"\x201A")},
    {QStringLiteral("&sc;"), QString::fromUtf16(u"\x227B")},
    {QStringLiteral("&scE;"), QString::fromUtf16(u"\x2AB4")},
    {QStringLiteral("&scap;"), QString::fromUtf16(u"\x2AB8")},
    {QStringLiteral("&scaron;"), QString::fromUtf16(u"\x0161")},
    {QStringLiteral("&sccue;"), QString::fromUtf16(u"\x227D")},
    {QStringLiteral("&sce;"), QString::fromUtf16(u"\x2AB0")},
    {QStringLiteral("&scedil;"), QString::fromUtf16(u"\x015F")},
    {QStringLiteral("&scirc;"), QString::fromUtf16(u"\x015D")},
    {QStringLiteral("&scnE;"), QString::fromUtf16(u"\x2AB6")},
    {QStringLiteral("&scnap;"), QString::fromUtf16(u"\x2ABA")},
    {QStringLiteral("&scnsim;"), QString::fromUtf16(u"\x22E9")},
    {QStringLiteral("&scpolint;"), QString::fromUtf16(u"\x2A13")},
    {QStringLiteral("&scsim;"), QString::fromUtf16(u"\x227F")},
    {QStringLiteral("&scy;"), QString::fromUtf16(u"\x0441")},
    {QStringLiteral("&sdot;"), QString::fromUtf16(u"\x22C5")},
    {QStringLiteral("&sdotb;"), QString::fromUtf16(u"\x22A1")},
    {QStringLiteral("&sdote;"), QString::fromUtf16(u"\x2A66")},
    {QStringLiteral("&seArr;"), QString::fromUtf16(u"\x21D8")},
    {QStringLiteral("&searhk;"), QString::fromUtf16(u"\x2925")},
    {QStringLiteral("&searr;"), QString::fromUtf16(u"\x2198")},
    {QStringLiteral("&searrow;"), QString::fromUtf16(u"\x2198")},
    {QStringLiteral("&sect"), QString::fromUtf16(u"\x00A7")},
    {QStringLiteral("&sect;"), QString::fromUtf16(u"\x00A7")},
    {QStringLiteral("&semi;"), QString::fromUtf16(u"\x003B")},
    {QStringLiteral("&seswar;"), QString::fromUtf16(u"\x2929")},
    {QStringLiteral("&setminus;"), QString::fromUtf16(u"\x2216")},
    {QStringLiteral("&setmn;"), QString::fromUtf16(u"\x2216")},
    {QStringLiteral("&sext;"), QString::fromUtf16(u"\x2736")},
    {QStringLiteral("&sfr;"), QString::fromUtf16(u"\xD835\xDD30")},
    {QStringLiteral("&sfrown;"), QString::fromUtf16(u"\x2322")},
    {QStringLiteral("&sharp;"), QString::fromUtf16(u"\x266F")},
    {QStringLiteral("&shchcy;"), QString::fromUtf16(u"\x0449")},
    {QStringLiteral("&shcy;"), QString::fromUtf16(u"\x0448")},
    {QStringLiteral("&shortmid;"), QString::fromUtf16(u"\x2223")},
    {QStringLiteral("&shortparallel;"), QString::fromUtf16(u"\x2225")},
    {QStringLiteral("&shy"), QString::fromUtf16(u"\x00AD")},
    {QStringLiteral("&shy;"), QString::fromUtf16(u"\x00AD")},
    {QStringLiteral("&sigma;"), QString::fromUtf16(u"\x03C3")},
    {QStringLiteral("&sigmaf;"), QString::fromUtf16(u"\x03C2")},
    {QStringLiteral("&sigmav;"), QString::fromUtf16(u"\x03C2")},
    {QStringLiteral("&sim;"), QString::fromUtf16(u"\x223C")},
    {QStringLiteral("&simdot;"), QString::fromUtf16(u"\x2A6A")},
    {QStringLiteral("&sime;"), QString::fromUtf16(u"\x2243")},
    {QStringLiteral("&simeq;"), QString::fromUtf16(u"\x2243")},
    {QStringLiteral("&simg;"), QString::fromUtf16(u"\x2A9E")},
    {QStringLiteral("&simgE;"), QString::fromUtf16(u"\x2AA0")},
    {QStringLiteral("&siml;"), QString::fromUtf16(u"\x2A9D")},
    {QStringLiteral("&simlE;"), QString::fromUtf16(u"\x2A9F")},
    {QStringLiteral("&simne;"), QString::fromUtf16(u"\x2246")},
    {QStringLiteral("&simplus;"), QString::fromUtf16(u"\x2A24")},
    {QStringLiteral("&simrarr;"), QString::fromUtf16(u"\x2972")},
    {QStringLiteral("&slarr;"), QString::fromUtf16(u"\x2190")},
    {QStringLiteral("&smallsetminus;"), QString::fromUtf16(u"\x2216")},
    {QStringLiteral("&smashp;"), QString::fromUtf16(u"\x2A33")},
    {QStringLiteral("&smeparsl;"), QString::fromUtf16(u"\x29E4")},
    {QStringLiteral("&smid;"), QString::fromUtf16(u"\x2223")},
    {QStringLiteral("&smile;"), QString::fromUtf16(u"\x2323")},
    {QStringLiteral("&smt;"), QString::fromUtf16(u"\x2AAA")},
    {QStringLiteral("&smte;"), QString::fromUtf16(u"\x2AAC")},
    {QStringLiteral("&smtes;"), QString::fromUtf16(u"\x2AAC\xFE00")},
    {QStringLiteral("&softcy;"), QString::fromUtf16(u"\x044C")},
    {QStringLiteral("&sol;"), QString::fromUtf16(u"\x002F")},
    {QStringLiteral("&solb;"), QString::fromUtf16(u"\x29C4")},
    {QStringLiteral("&solbar;"), QString::fromUtf16(u"\x233F")},
    {QStringLiteral("&sopf;"), QString::fromUtf16(u"\xD835\xDD64")},
    {QStringLiteral("&spades;"), QString::fromUtf16(u"\x2660")},
    {QStringLiteral("&spadesuit;"), QString::fromUtf16(u"\x2660")},
    {QStringLiteral("&spar;"), QString::fromUtf16(u"\x2225")},
    {QStringLiteral("&sqcap;"), QString::fromUtf16(u"\x2293")},
    {QStringLiteral("&sqcaps;"), QString::fromUtf16(u"\x2293\xFE00")},
    {QStringLiteral("&sqcup;"), QString::fromUtf16(u"\x2294")},
    {QStringLiteral("&sqcups;"), QString::fromUtf16(u"\x2294\xFE00")},
    {QStringLiteral("&sqsub;"), QString::fromUtf16(u"\x228F")},
    {QStringLiteral("&sqsube;"), QString::fromUtf16(u"\x2291")},
    {QStringLiteral("&sqsubset;"), QString::fromUtf16(u"\x228F")},
    {QStringLiteral("&sqsubseteq;"), QString::fromUtf16(u"\x2291")},
    {QStringLiteral("&sqsup;"), QString::fromUtf16(u"\x2290")},
    {QStringLiteral("&sqsupe;"), QString::fromUtf16(u"\x2292")},
    {QStringLiteral("&sqsupset;"), QString::fromUtf16(u"\x2290")},
    {QStringLiteral("&sqsupseteq;"), QString::fromUtf16(u"\x2292")},
    {QStringLiteral("&squ;"), QString::fromUtf16(u"\x25A1")},
    {QStringLiteral("&square;"), QString::fromUtf16(u"\x25A1")},
    {QStringLiteral("&squarf;"), QString::fromUtf16(u"\x25AA")},
    {QStringLiteral("&squf;"), QString::fromUtf16(u"\x25AA")},
    {QStringLiteral("&srarr;"), QString::fromUtf16(u"\x2192")},
    {QStringLiteral("&sscr;"), QString::fromUtf16(u"\xD835\xDCC8")},
    {QStringLiteral("&ssetmn;"), QString::fromUtf16(u"\x2216")},
    {QStringLiteral("&ssmile;"), QString::fromUtf16(u"\x2323")},
    {QStringLiteral("&sstarf;"), QString::fromUtf16(u"\x22C6")},
    {QStringLiteral("&star;"), QString::fromUtf16(u"\x2606")},
    {QStringLiteral("&starf;"), QString::fromUtf16(u"\x2605")},
    {QStringLiteral("&straightepsilon;"), QString::fromUtf16(u"\x03F5")},
    {QStringLiteral("&straightphi;"), QString::fromUtf16(u"\x03D5")},
    {QStringLiteral("&strns;"), QString::fromUtf16(u"\x00AF")},
    {QStringLiteral("&sub;"), QString::fromUtf16(u"\x2282")},
    {QStringLiteral("&subE;"), QString::fromUtf16(u"\x2AC5")},
    {QStringLiteral("&subdot;"), QString::fromUtf16(u"\x2ABD")},
    {QStringLiteral("&sube;"), QString::fromUtf16(u"\x2286")},
    {QStringLiteral("&subedot;"), QString::fromUtf16(u"\x2AC3")},
    {QStringLiteral("&submult;"), QString::fromUtf16(u"\x2AC1")},
    {QStringLiteral("&subnE;"), QString::fromUtf16(u"\x2ACB")},
    {QStringLiteral("&subne;"), QString::fromUtf16(u"\x228A")},
    {QStringLiteral("&subplus;"), QString::fromUtf16(u"\x2ABF")},
    {QStringLiteral("&subrarr;"), QString::fromUtf16(u"\x2979")},
    {QStringLiteral("&subset;"), QString::fromUtf16(u"\x2282")},
    {QStringLiteral("&subseteq;"), QString::fromUtf16(u"\x2286")},
    {QStringLiteral("&subseteqq;"), QString::fromUtf16(u"\x2AC5")},
    {QStringLiteral("&subsetneq;"), QString::fromUtf16(u"\x228A")},
    {QStringLiteral("&subsetneqq;"), QString::fromUtf16(u"\x2ACB")},
    {QStringLiteral("&subsim;"), QString::fromUtf16(u"\x2AC7")},
    {QStringLiteral("&subsub;"), QString::fromUtf16(u"\x2AD5")},
    {QStringLiteral("&subsup;"), QString::fromUtf16(u"\x2AD3")},
    {QStringLiteral("&succ;"), QString::fromUtf16(u"\x227B")},
    {QStringLiteral("&succapprox;"), QString::fromUtf16(u"\x2AB8")},
    {QStringLiteral("&succcurlyeq;"), QString::fromUtf16(u"\x227D")},
    {QStringLiteral("&succeq;"), QString::fromUtf16(u"\x2AB0")},
    {QStringLiteral("&succnapprox;"), QString::fromUtf16(u"\x2ABA")},
    {QStringLiteral("&succneqq;"), QString::fromUtf16(u"\x2AB6")},
    {QStringLiteral("&succnsim;"), QString::fromUtf16(u"\x22E9")},
    {QStringLiteral("&succsim;"), QString::fromUtf16(u"\x227F")},
    {QStringLiteral("&sum;"), QString::fromUtf16(u"\x2211")},
    {QStringLiteral("&sung;"), QString::fromUtf16(u"\x266A")},
    {QStringLiteral("&sup1"), QString::fromUtf16(u"\x00B9")},
    {QStringLiteral("&sup1;"), QString::fromUtf16(u"\x00B9")},
    {QStringLiteral("&sup2"), QString::fromUtf16(u"\x00B2")},
    {QStringLiteral("&sup2;"), QString::fromUtf16(u"\x00B2")},
    {QStringLiteral("&sup3"), QString::fromUtf16(u"\x00B3")},
    {QStringLiteral("&sup3;"), QString::fromUtf16(u"\x00B3")},
    {QStringLiteral("&sup;"), QString::fromUtf16(u"\x2283")},
    {QStringLiteral("&supE;"), QString::fromUtf16(u"\x2AC6")},
    {QStringLiteral("&supdot;"), QString::fromUtf16(u"\x2ABE")},
    {QStringLiteral("&supdsub;"), QString::fromUtf16(u"\x2AD8")},
    {QStringLiteral("&supe;"), QString::fromUtf16(u"\x2287")},
    {QStringLiteral("&supedot;"), QString::fromUtf16(u"\x2AC4")},
    {QStringLiteral("&suphsol;"), QString::fromUtf16(u"\x27C9")},
    {QStringLiteral("&suphsub;"), QString::fromUtf16(u"\x2AD7")},
    {QStringLiteral("&suplarr;"), QString::fromUtf16(u"\x297B")},
    {QStringLiteral("&supmult;"), QString::fromUtf16(u"\x2AC2")},
    {QStringLiteral("&supnE;"), QString::fromUtf16(u"\x2ACC")},
    {QStringLiteral("&supne;"), QString::fromUtf16(u"\x228B")},
    {QStringLiteral("&supplus;"), QString::fromUtf16(u"\x2AC0")},
    {QStringLiteral("&supset;"), QString::fromUtf16(u"\x2283")},
    {QStringLiteral("&supseteq;"), QString::fromUtf16(u"\x2287")},
    {QStringLiteral("&supseteqq;"), QString::fromUtf16(u"\x2AC6")},
    {QStringLiteral("&supsetneq;"), QString::fromUtf16(u"\x228B")},
    {QStringLiteral("&supsetneqq;"), QString::fromUtf16(u"\x2ACC")},
    {QStringLiteral("&supsim;"), QString::fromUtf16(u"\x2AC8")},
    {QStringLiteral("&supsub;"), QString::fromUtf16(u"\x2AD4")},
    {QStringLiteral("&supsup;"), QString::fromUtf16(u"\x2AD6")},
    {QStringLiteral("&swArr;"), QString::fromUtf16(u"\x21D9")},
    {QStringLiteral("&swarhk;"), QString::fromUtf16(u"\x2926")},
    {QStringLiteral("&swarr;"), QString::fromUtf16(u"\x2199")},
    {QStringLiteral("&swarrow;"), QString::fromUtf16(u"\x2199")},
    {QStringLiteral("&swnwar;"), QString::fromUtf16(u"\x292A")},
    {QStringLiteral("&szlig"), QString::fromUtf16(u"\x00DF")},
    {QStringLiteral("&szlig;"), QString::fromUtf16(u"\x00DF")},
    {QStringLiteral("&target;"), QString::fromUtf16(u"\x2316")},
    {QStringLiteral("&tau;"), QString::fromUtf16(u"\x03C4")},
    {QStringLiteral("&tbrk;"), QString::fromUtf16(u"\x23B4")},
    {QStringLiteral("&tcaron;"), QString::fromUtf16(u"\x0165")},
    {QStringLiteral("&tcedil;"), QString::fromUtf16(u"\x0163")},
    {QStringLiteral("&tcy;"), QString::fromUtf16(u"\x0442")},
    {QStringLiteral("&tdot;"), QString::fromUtf16(u"\x20DB")},
    {QStringLiteral("&telrec;"), QString::fromUtf16(u"\x2315")},
    {QStringLiteral("&tfr;"), QString::fromUtf16(u"\xD835\xDD31")},
    {QStringLiteral("&there4;"), QString::fromUtf16(u"\x2234")},
    {QStringLiteral("&therefore;"), QString::fromUtf16(u"\x2234")},
    {QStringLiteral("&theta;"), QString::fromUtf16(u"\x03B8")},
    {QStringLiteral("&thetasym;"), QString::fromUtf16(u"\x03D1")},
    {QStringLiteral("&thetav;"), QString::fromUtf16(u"\x03D1")},
    {QStringLiteral("&thickapprox;"), QString::fromUtf16(u"\x2248")},
    {QStringLiteral("&thicksim;"), QString::fromUtf16(u"\x223C")},
    {QStringLiteral("&thinsp;"), QString::fromUtf16(u"\x2009")},
    {QStringLiteral("&thkap;"), QString::fromUtf16(u"\x2248")},
    {QStringLiteral("&thksim;"), QString::fromUtf16(u"\x223C")},
    {QStringLiteral("&thorn"), QString::fromUtf16(u"\x00FE")},
    {QStringLiteral("&thorn;"), QString::fromUtf16(u"\x00FE")},
    {QStringLiteral("&tilde;"), QString::fromUtf16(u"\x02DC")},
    {QStringLiteral("&times"), QString::fromUtf16(u"\x00D7")},
    {QStringLiteral("&times;"), QString::fromUtf16(u"\x00D7")},
    {QStringLiteral("&timesb;"), QString::fromUtf16(u"\x22A0")},
    {QStringLiteral("&timesbar;"), QString::fromUtf16(u"\x2A31")},
    {QStringLiteral("&timesd;"), QString::fromUtf16(u"\x2A30")},
    {QStringLiteral("&tint;"), QString::fromUtf16(u"\x222D")},
    {QStringLiteral("&toea;"), QString::fromUtf16(u"\x2928")},
    {QStringLiteral("&top;"), QString::fromUtf16(u"\x22A4")},
    {QStringLiteral("&topbot;"), QString::fromUtf16(u"\x2336")},
    {QStringLiteral("&topcir;"), QString::fromUtf16(u"\x2AF1")},
    {QStringLiteral("&topf;"), QString::fromUtf16(u"\xD835\xDD65")},
    {QStringLiteral("&topfork;"), QString::fromUtf16(u"\x2ADA")},
    {QStringLiteral("&tosa;"), QString::fromUtf16(u"\x2929")},
    {QStringLiteral("&tprime;"), QString::fromUtf16(u"\x2034")},
    {QStringLiteral("&trade;"), QString::fromUtf16(u"\x2122")},
    {QStringLiteral("&triangle;"), QString::fromUtf16(u"\x25B5")},
    {QStringLiteral("&triangledown;"), QString::fromUtf16(u"\x25BF")},
    {QStringLiteral("&triangleleft;"), QString::fromUtf16(u"\x25C3")},
    {QStringLiteral("&trianglelefteq;"), QString::fromUtf16(u"\x22B4")},
    {QStringLiteral("&triangleq;"), QString::fromUtf16(u"\x225C")},
    {QStringLiteral("&triangleright;"), QString::fromUtf16(u"\x25B9")},
    {QStringLiteral("&trianglerighteq;"), QString::fromUtf16(u"\x22B5")},
    {QStringLiteral("&tridot;"), QString::fromUtf16(u"\x25EC")},
    {QStringLiteral("&trie;"), QString::fromUtf16(u"\x225C")},
    {QStringLiteral("&triminus;"), QString::fromUtf16(u"\x2A3A")},
    {QStringLiteral("&triplus;"), QString::fromUtf16(u"\x2A39")},
    {QStringLiteral("&trisb;"), QString::fromUtf16(u"\x29CD")},
    {QStringLiteral("&tritime;"), QString::fromUtf16(u"\x2A3B")},
    {QStringLiteral("&trpezium;"), QString::fromUtf16(u"\x23E2")},
    {QStringLiteral("&tscr;"), QString::fromUtf16(u"\xD835\xDCC9")},
    {QStringLiteral("&tscy;"), QString::fromUtf16(u"\x0446")},
    {QStringLiteral("&tshcy;"), QString::fromUtf16(u"\x045B")},
    {QStringLiteral("&tstrok;"), QString::fromUtf16(u"\x0167")},
    {QStringLiteral("&twixt;"), QString::fromUtf16(u"\x226C")},
    {QStringLiteral("&twoheadleftarrow;"), QString::fromUtf16(u"\x219E")},
    {QStringLiteral("&twoheadrightarrow;"), QString::fromUtf16(u"\x21A0")},
    {QStringLiteral("&uArr;"), QString::fromUtf16(u"\x21D1")},
    {QStringLiteral("&uHar;"), QString::fromUtf16(u"\x2963")},
    {QStringLiteral("&uacute"), QString::fromUtf16(u"\x00FA")},
    {QStringLiteral("&uacute;"), QString::fromUtf16(u"\x00FA")},
    {QStringLiteral("&uarr;"), QString::fromUtf16(u"\x2191")},
    {QStringLiteral("&ubrcy;"), QString::fromUtf16(u"\x045E")},
    {QStringLiteral("&ubreve;"), QString::fromUtf16(u"\x016D")},
    {QStringLiteral("&ucirc"), QString::fromUtf16(u"\x00FB")},
    {QStringLiteral("&ucirc;"), QString::fromUtf16(u"\x00FB")},
    {QStringLiteral("&ucy;"), QString::fromUtf16(u"\x0443")},
    {QStringLiteral("&udarr;"), QString::fromUtf16(u"\x21C5")},
    {QStringLiteral("&udblac;"), QString::fromUtf16(u"\x0171")},
    {QStringLiteral("&udhar;"), QString::fromUtf16(u"\x296E")},
    {QStringLiteral("&ufisht;"), QString::fromUtf16(u"\x297E")},
    {QStringLiteral("&ufr;"), QString::fromUtf16(u"\xD835\xDD32")},
    {QStringLiteral("&ugrave"), QString::fromUtf16(u"\x00F9")},
    {QStringLiteral("&ugrave;"), QString::fromUtf16(u"\x00F9")},
    {QStringLiteral("&uharl;"), QString::fromUtf16(u"\x21BF")},
    {QStringLiteral("&uharr;"), QString::fromUtf16(u"\x21BE")},
    {QStringLiteral("&uhblk;"), QString::fromUtf16(u"\x2580")},
    {QStringLiteral("&ulcorn;"), QString::fromUtf16(u"\x231C")},
    {QStringLiteral("&ulcorner;"), QString::fromUtf16(u"\x231C")},
    {QStringLiteral("&ulcrop;"), QString::fromUtf16(u"\x230F")},
    {QStringLiteral("&ultri;"), QString::fromUtf16(u"\x25F8")},
    {QStringLiteral("&umacr;"), QString::fromUtf16(u"\x016B")},
    {QStringLiteral("&uml"), QString::fromUtf16(u"\x00A8")},
    {QStringLiteral("&uml;"), QString::fromUtf16(u"\x00A8")},
    {QStringLiteral("&uogon;"), QString::fromUtf16(u"\x0173")},
    {QStringLiteral("&uopf;"), QString::fromUtf16(u"\xD835\xDD66")},
    {QStringLiteral("&uparrow;"), QString::fromUtf16(u"\x2191")},
    {QStringLiteral("&updownarrow;"), QString::fromUtf16(u"\x2195")},
    {QStringLiteral("&upharpoonleft;"), QString::fromUtf16(u"\x21BF")},
    {QStringLiteral("&upharpoonright;"), QString::fromUtf16(u"\x21BE")},
    {QStringLiteral("&uplus;"), QString::fromUtf16(u"\x228E")},
    {QStringLiteral("&upsi;"), QString::fromUtf16(u"\x03C5")},
    {QStringLiteral("&upsih;"), QString::fromUtf16(u"\x03D2")},
    {QStringLiteral("&upsilon;"), QString::fromUtf16(u"\x03C5")},
    {QStringLiteral("&upuparrows;"), QString::fromUtf16(u"\x21C8")},
    {QStringLiteral("&urcorn;"), QString::fromUtf16(u"\x231D")},
    {QStringLiteral("&urcorner;"), QString::fromUtf16(u"\x231D")},
    {QStringLiteral("&urcrop;"), QString::fromUtf16(u"\x230E")},
    {QStringLiteral("&uring;"), QString::fromUtf16(u"\x016F")},
    {QStringLiteral("&urtri;"), QString::fromUtf16(u"\x25F9")},
    {QStringLiteral("&uscr;"), QString::fromUtf16(u"\xD835\xDCCA")},
    {QStringLiteral("&utdot;"), QString::fromUtf16(u"\x22F0")},
    {QStringLiteral("&utilde;"), QString::fromUtf16(u"\x0169")},
    {QStringLiteral("&utri;"), QString::fromUtf16(u"\x25B5")},
    {QStringLiteral("&utrif;"), QString::fromUtf16(u"\x25B4")},
    {QStringLiteral("&uuarr;"), QString::fromUtf16(u"\x21C8")},
    {QStringLiteral("&uuml"), QString::fromUtf16(u"\x00FC")},
    {QStringLiteral("&uuml;"), QString::fromUtf16(u"\x00FC")},
    {QStringLiteral("&uwangle;"), QString::fromUtf16(u"\x29A7")},
    {QStringLiteral("&vArr;"), QString::fromUtf16(u"\x21D5")},
    {QStringLiteral("&vBar;"), QString::fromUtf16(u"\x2AE8")},
    {QStringLiteral("&vBarv;"), QString::fromUtf16(u"\x2AE9")},
    {QStringLiteral("&vDash;"), QString::fromUtf16(u"\x22A8")},
    {QStringLiteral("&vangrt;"), QString::fromUtf16(u"\x299C")},
    {QStringLiteral("&varepsilon;"), QString::fromUtf16(u"\x03F5")},
    {QStringLiteral("&varkappa;"), QString::fromUtf16(u"\x03F0")},
    {QStringLiteral("&varnothing;"), QString::fromUtf16(u"\x2205")},
    {QStringLiteral("&varphi;"), QString::fromUtf16(u"\x03D5")},
    {QStringLiteral("&varpi;"), QString::fromUtf16(u"\x03D6")},
    {QStringLiteral("&varpropto;"), QString::fromUtf16(u"\x221D")},
    {QStringLiteral("&varr;"), QString::fromUtf16(u"\x2195")},
    {QStringLiteral("&varrho;"), QString::fromUtf16(u"\x03F1")},
    {QStringLiteral("&varsigma;"), QString::fromUtf16(u"\x03C2")},
    {QStringLiteral("&varsubsetneq;"), QString::fromUtf16(u"\x228A\xFE00")},
    {QStringLiteral("&varsubsetneqq;"), QString::fromUtf16(u"\x2ACB\xFE00")},
    {QStringLiteral("&varsupsetneq;"), QString::fromUtf16(u"\x228B\xFE00")},
    {QStringLiteral("&varsupsetneqq;"), QString::fromUtf16(u"\x2ACC\xFE00")},
    {QStringLiteral("&vartheta;"), QString::fromUtf16(u"\x03D1")},
    {QStringLiteral("&vartriangleleft;"), QString::fromUtf16(u"\x22B2")},
    {QStringLiteral("&vartriangleright;"), QString::fromUtf16(u"\x22B3")},
    {QStringLiteral("&vcy;"), QString::fromUtf16(u"\x0432")},
    {QStringLiteral("&vdash;"), QString::fromUtf16(u"\x22A2")},
    {QStringLiteral("&vee;"), QString::fromUtf16(u"\x2228")},
    {QStringLiteral("&veebar;"), QString::fromUtf16(u"\x22BB")},
    {QStringLiteral("&veeeq;"), QString::fromUtf16(u"\x225A")},
    {QStringLiteral("&vellip;"), QString::fromUtf16(u"\x22EE")},
    {QStringLiteral("&verbar;"), QString::fromUtf16(u"\x007C")},
    {QStringLiteral("&vert;"), QString::fromUtf16(u"\x007C")},
    {QStringLiteral("&vfr;"), QString::fromUtf16(u"\xD835\xDD33")},
    {QStringLiteral("&vltri;"), QString::fromUtf16(u"\x22B2")},
    {QStringLiteral("&vnsub;"), QString::fromUtf16(u"\x2282\x20D2")},
    {QStringLiteral("&vnsup;"), QString::fromUtf16(u"\x2283\x20D2")},
    {QStringLiteral("&vopf;"), QString::fromUtf16(u"\xD835\xDD67")},
    {QStringLiteral("&vprop;"), QString::fromUtf16(u"\x221D")},
    {QStringLiteral("&vrtri;"), QString::fromUtf16(u"\x22B3")},
    {QStringLiteral("&vscr;"), QString::fromUtf16(u"\xD835\xDCCB")},
    {QStringLiteral("&vsubnE;"), QString::fromUtf16(u"\x2ACB\xFE00")},
    {QStringLiteral("&vsubne;"), QString::fromUtf16(u"\x228A\xFE00")},
    {QStringLiteral("&vsupnE;"), QString::fromUtf16(u"\x2ACC\xFE00")},
    {QStringLiteral("&vsupne;"), QString::fromUtf16(u"\x228B\xFE00")},
    {QStringLiteral("&vzigzag;"), QString::fromUtf16(u"\x299A")},
    {QStringLiteral("&wcirc;"), QString::fromUtf16(u"\x0175")},
    {QStringLiteral("&wedbar;"), QString::fromUtf16(u"\x2A5F")},
    {QStringLiteral("&wedge;"), QString::fromUtf16(u"\x2227")},
    {QStringLiteral("&wedgeq;"), QString::fromUtf16(u"\x2259")},
    {QStringLiteral("&weierp;"), QString::fromUtf16(u"\x2118")},
    {QStringLiteral("&wfr;"), QString::fromUtf16(u"\xD835\xDD34")},
    {QStringLiteral("&wopf;"), QString::fromUtf16(u"\xD835\xDD68")},
    {QStringLiteral("&wp;"), QString::fromUtf16(u"\x2118")},
    {QStringLiteral("&wr;"), QString::fromUtf16(u"\x2240")},
    {QStringLiteral("&wreath;"), QString::fromUtf16(u"\x2240")},
    {QStringLiteral("&wscr;"), QString::fromUtf16(u"\xD835\xDCCC")},
    {QStringLiteral("&xcap;"), QString::fromUtf16(u"\x22C2")},
    {QStringLiteral("&xcirc;"), QString::fromUtf16(u"\x25EF")},
    {QStringLiteral("&xcup;"), QString::fromUtf16(u"\x22C3")},
    {QStringLiteral("&xdtri;"), QString::fromUtf16(u"\x25BD")},
    {QStringLiteral("&xfr;"), QString::fromUtf16(u"\xD835\xDD35")},
    {QStringLiteral("&xhArr;"), QString::fromUtf16(u"\x27FA")},
    {QStringLiteral("&xharr;"), QString::fromUtf16(u"\x27F7")},
    {QStringLiteral("&xi;"), QString::fromUtf16(u"\x03BE")},
    {QStringLiteral("&xlArr;"), QString::fromUtf16(u"\x27F8")},
    {QStringLiteral("&xlarr;"), QString::fromUtf16(u"\x27F5")},
    {QStringLiteral("&xmap;"), QString::fromUtf16(u"\x27FC")},
    {QStringLiteral("&xnis;"), QString::fromUtf16(u"\x22FB")},
    {QStringLiteral("&xodot;"), QString::fromUtf16(u"\x2A00")},
    {QStringLiteral("&xopf;"), QString::fromUtf16(u"\xD835\xDD69")},
    {QStringLiteral("&xoplus;"), QString::fromUtf16(u"\x2A01")},
    {QStringLiteral("&xotime;"), QString::fromUtf16(u"\x2A02")},
    {QStringLiteral("&xrArr;"), QString::fromUtf16(u"\x27F9")},
    {QStringLiteral("&xrarr;"), QString::fromUtf16(u"\x27F6")},
    {QStringLiteral("&xscr;"), QString::fromUtf16(u"\xD835\xDCCD")},
    {QStringLiteral("&xsqcup;"), QString::fromUtf16(u"\x2A06")},
    {QStringLiteral("&xuplus;"), QString::fromUtf16(u"\x2A04")},
    {QStringLiteral("&xutri;"), QString::fromUtf16(u"\x25B3")},
    {QStringLiteral("&xvee;"), QString::fromUtf16(u"\x22C1")},
    {QStringLiteral("&xwedge;"), QString::fromUtf16(u"\x22C0")},
    {QStringLiteral("&yacute"), QString::fromUtf16(u"\x00FD")},
    {QStringLiteral("&yacute;"), QString::fromUtf16(u"\x00FD")},
    {QStringLiteral("&yacy;"), QString::fromUtf16(u"\x044F")},
    {QStringLiteral("&ycirc;"), QString::fromUtf16(u"\x0177")},
    {QStringLiteral("&ycy;"), QString::fromUtf16(u"\x044B")},
    {QStringLiteral("&yen"), QString::fromUtf16(u"\x00A5")},
    {QStringLiteral("&yen;"), QString::fromUtf16(u"\x00A5")},
    {QStringLiteral("&yfr;"), QString::fromUtf16(u"\xD835\xDD36")},
    {QStringLiteral("&yicy;"), QString::fromUtf16(u"\x0457")},
    {QStringLiteral("&yopf;"), QString::fromUtf16(u"\xD835\xDD6A")},
    {QStringLiteral("&yscr;"), QString::fromUtf16(u"\xD835\xDCCE")},
    {QStringLiteral("&yucy;"), QString::fromUtf16(u"\x044E")},
    {QStringLiteral("&yuml"), QString::fromUtf16(u"\x00FF")},
    {QStringLiteral("&yuml;"), QString::fromUtf16(u"\x00FF")},
    {QStringLiteral("&zacute;"), QString::fromUtf16(u"\x017A")},
    {QStringLiteral("&zcaron;"), QString::fromUtf16(u"\x017E")},
    {QStringLiteral("&zcy;"), QString::fromUtf16(u"\x0437")},
    {QStringLiteral("&zdot;"), QString::fromUtf16(u"\x017C")},
    {QStringLiteral("&zeetrf;"), QString::fromUtf16(u"\x2128")},
    {QStringLiteral("&zeta;"), QString::fromUtf16(u"\x03B6")},
    {QStringLiteral("&zfr;"), QString::fromUtf16(u"\xD835\xDD37")},
    {QStringLiteral("&zhcy;"), QString::fromUtf16(u"\x0436")},
    {QStringLiteral("&zigrarr;"), QString::fromUtf16(u"\x21DD")},
    {QStringLiteral("&zopf;"), QString::fromUtf16(u"\xD835\xDD6B")},
    {QStringLiteral("&zscr;"), QString::fromUtf16(u"\xD835\xDCCF")},
    {QStringLiteral("&zwj;"), QString::fromUtf16(u"\x200D")},
    {QStringLiteral("&zwnj;"), QString::fromUtf16(u"\x200C")}};

} /* namespace MD */
